@@ -2,7 +2,7 @@
 
 """
 #============================================================
-__version__ = "$Revision: 1.35 $"
+__version__ = "$Revision: 1.38 $"
 __author__ = "Carlos Moro <cfmoro1976@yahoo.es>, Karsten Hilbert <Karsten.Hilbert@gmx.net>"
 __license__ = 'GPL (for details see http://gnu.org)'
 
@@ -11,10 +11,10 @@ import sys, logging
 
 if __name__ == '__main__':
 	sys.path.insert(0, '../../')
-from Gnumed.pycommon import gmPG2, gmExceptions, gmBusinessDBObject
+from Gnumed.pycommon import gmPG2, gmExceptions, gmBusinessDBObject, gmTools
 
 try:
-	_('dummy-no-need-to-translate')
+	_('dummy-no-need-to-translate-but-make-epydoc-happy')
 except NameError:
 	_ = lambda x:x
 
@@ -146,13 +146,42 @@ class cNarrative(gmBusinessDBObject.cBusinessDBObject):
 		}
 		gmPG2.run_rw_queries(queries = [{'cmd': cmd, 'args': args}])
 		return True
+	#--------------------------------------------------------
+	def format(self, left_margin=u'', fancy=False, width=75):
+
+		if fancy:
+			# FIXME: add revision
+			txt = gmTools.wrap (
+				text = _('%s: %s by %.8s\n%s') % (
+					self._payload[self._idx['date']].strftime('%x %H:%M'),
+					soap_cat2l10n_str[self._payload[self._idx['soap_cat']]],
+					self._payload[self._idx['provider']],
+					self._payload[self._idx['narrative']]
+				),
+				width = width,
+				initial_indent = u'',
+				subsequent_indent = left_margin + u'   '
+			)
+		else:
+			txt = u'%s [%s]: %s (%.8s)' % (
+				self._payload[self._idx['date']].strftime('%x %H:%M'),
+				soap_cat2l10n[self._payload[self._idx['soap_cat']]],
+				self._payload[self._idx['narrative']],
+				self._payload[self._idx['provider']]
+			)
+			if len(txt) > width:
+				txt = txt[:width] + gmTools.u_ellipsis
+
+		return txt
+
+#		lines.append('-- %s ----------' % gmClinNarrative.soap_cat2l10n_str[soap_cat])
+
 #============================================================
 # convenience functions
 #============================================================
 def create_clin_narrative(narrative=None, soap_cat=None, episode_id=None, encounter_id=None):
-	"""
-		Creates a new clinical narrative entry
-		
+	"""Creates a new clinical narrative entry
+
 		narrative - free text clinical narrative
 		soap_cat - soap category
 		episode_id - episodes's primary key
@@ -197,10 +226,10 @@ select pk_patient from clin.v_pat_encounters where pk_encounter = %(enc)s
 	rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': args}])
 	if len(rows) == 0:
 		_log.error('error checking episode [%s] <-> encounter [%s] consistency' % (episode_id, encounter_id))
-		return (False, _('internal error, check log'))
+		raise ValueError('internal error, check log')
 	if len(rows) > 1:
 		_log.error('episode [%s] and encounter [%s] belong to different patients !?!' % (episode_id, encounter_id))
-		return (False, _('consistency error, check log'))
+		raise ValueError('clinical narrative consistency error, check log')
 
 	# insert new narrative
 	queries = [
@@ -263,6 +292,15 @@ if __name__ == '__main__':
 	
 #============================================================
 # $Log: gmClinNarrative.py,v $
+# Revision 1.38  2009/01/15 11:31:00  ncq
+# - cleanup
+#
+# Revision 1.37  2008/12/27 15:49:21  ncq
+# - raise exception on integrity problems in create_narrative
+#
+# Revision 1.36  2008/12/18 21:25:56  ncq
+# - add format() to cClinNarrative
+#
 # Revision 1.35  2008/08/15 15:55:14  ncq
 # - cleanup
 #
