@@ -4,7 +4,7 @@
 license: GPL
 """
 #============================================================
-__version__ = "$Revision: 1.119.2.4 $"
+__version__ = "$Revision: 1.132 $"
 __author__ = "Carlos Moro <cfmoro1976@yahoo.es>"
 
 import types, sys, string, datetime, logging, time
@@ -12,7 +12,7 @@ import types, sys, string, datetime, logging, time
 
 if __name__ == '__main__':
 	sys.path.insert(0, '../../')
-from Gnumed.pycommon import gmPG2, gmExceptions, gmNull, gmBusinessDBObject, gmDateTime, gmTools, gmI18N
+from Gnumed.pycommon import gmPG2, gmExceptions, gmNull, gmBusinessDBObject, gmDateTime, gmTools
 from Gnumed.business import gmClinNarrative
 
 
@@ -20,12 +20,12 @@ _log = logging.getLogger('gm.emr')
 _log.info(__version__)
 
 #============================================================
-# Foundational Health Issues API
+# Health Issues API
 #============================================================
 class cHealthIssue(gmBusinessDBObject.cBusinessDBObject):
 	"""Represents one health issue."""
 
-	_cmd_fetch_payload = u"select *, xmin from clin.health_issue where pk=%s"
+	_cmd_fetch_payload = u"select *, xmin_health_issue from clin.v_health_issues where pk_health_issue=%s"
 	_cmds_store_payload = [
 		u"""update clin.health_issue set
 				description = %(description)s,
@@ -36,9 +36,9 @@ class cHealthIssue(gmBusinessDBObject.cBusinessDBObject):
 				is_confidential = %(is_confidential)s,
 				is_cause_of_death = %(is_cause_of_death)s
 			where
-				pk = %(pk)s and
-				xmin = %(xmin)s""",
-		u"select xmin from clin.health_issue where pk = %(pk)s"
+				pk = %(pk_health_issue)s and
+				xmin = %(xmin_health_issue)s""",
+		u"select xmin as xmin_health_issue from clin.health_issue where pk = %(pk_health_issue)s"
 	]
 	_updatable_fields = [
 		'description',
@@ -50,22 +50,28 @@ class cHealthIssue(gmBusinessDBObject.cBusinessDBObject):
 		'is_cause_of_death'
 	]
 	#--------------------------------------------------------
-	def __init__(self, aPK_obj=None, patient_id=None, name='xxxDEFAULTxxx', row=None):
+	def __init__(self, aPK_obj=None, encounter=None, name='xxxDEFAULTxxx', row=None):
 		pk = aPK_obj
 		if pk is None and row is None:
-			cmd = u"select *, xmin from clin.health_issue where fk_patient=%s and description=%s"
-			rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': [patient_id, name]}], get_col_idx=True)
+			cmd = u"""select *, xmin_health_issue
+					from clin.v_health_issues
+					where
+						description = %(desc)s
+							and
+						pk_patient = (select fk_patient from clin.encounter where pk = %(enc)s)
+			"""
+			rows, idx = gmPG2.run_ro_queries (
+				queries = [{'cmd': cmd, 'args': {'enc': encounter, 'desc': name}}],
+				get_col_idx = True
+			)
 			if len(rows) == 0:
-				raise gmExceptions.NoSuchBusinessObjectError, 'no health issue for [%s:%s]' % (patient_id, name)
+				raise gmExceptions.NoSuchBusinessObjectError, 'no health issue for [%s:%s]' % (encounter, name)
 			pk = rows[0][0]
-			r = {'idx': idx, 'data': rows[0], 'pk_field': 'pk'}
+			r = {'idx': idx, 'data': rows[0], 'pk_field': 'pk_health_issue'}
 			gmBusinessDBObject.cBusinessDBObject.__init__(self, row=r)
 		else:
 			gmBusinessDBObject.cBusinessDBObject.__init__(self, aPK_obj=pk, row=row)
 	#--------------------------------------------------------
-	def get_patient(self):
-		return self._payload[self._idx['fk_patient']]
-	#--------------------------------------------------------
 	def rename(self, description=None):
 		"""Method for issue renaming.
 
@@ -141,7 +147,7 @@ age (
 )::text || ' ago)'
 """
 		args = {
-			'pat': self._payload[self._idx['fk_patient']],
+			'pat': self._payload[self._idx['pk_patient']],
 			'issue_age': self._payload[self._idx['age_noted']]
 		}
 		rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': args}])
@@ -149,21 +155,21 @@ age (
 	#--------------------------------------------------------
 	def format(self, left_margin=0, patient=None):
 
-		if patient.ID != self._payload[self._idx['fk_patient']]:
+		if patient.ID != self._payload[self._idx['pk_patient']]:
 			msg = '<patient>.ID = %s but health issue %s belongs to patient %s' % (
 				patient.ID,
-				self._payload[self._idx['pk']],
-				self._payload[self._idx['fk_patient']]
+				self._payload[self._idx['pk_health_issue']],
+				self._payload[self._idx['pk_patient']]
 			)
 			raise ValueError(msg)
 
 		lines = []
 
-		lines.append(_('Foundational Health Issue %s%s%s [#%s]') % (
+		lines.append(_('Health Issue %s%s%s [#%s]') % (
 			u'\u00BB',
 			self._payload[self._idx['description']],
 			u'\u00AB',
-			self._payload[self._idx['pk']]
+			self._payload[self._idx['pk_health_issue']]
 		))
 
 		if self._payload[self._idx['is_confidential']]:
@@ -185,7 +191,7 @@ age (
 
 		emr = patient.get_emr()
 
-		epis = emr.get_episodes(issues = [self._payload[self._idx['pk']]])
+		epis = emr.get_episodes(issues = [self._payload[self._idx['pk_health_issue']]])
 		if epis is None:
 			lines.append(_('Error retrieving episodes for this health issue.'))
 		elif len(epis) == 0:
@@ -194,7 +200,7 @@ age (
 			lines.append(_('Episodes: %s') % len(epis))
 			lines.append(_(' Most recent: %s%s%s') % (
 				u'\u00BB',
-				emr.get_most_recent_episode(issue = self._payload[self._idx['pk']])['description'],
+				emr.get_most_recent_episode(issue = self._payload[self._idx['pk_health_issue']])['description'],
 				u'\u00AB'
 			))
 			lines.append('')
@@ -206,13 +212,13 @@ age (
 
 		lines.append('')
 
-		first_encounter = emr.get_first_encounter(issue_id = self._payload[self._idx['pk']])
-		last_encounter = emr.get_last_encounter(issue_id = self._payload[self._idx['pk']])
+		first_encounter = emr.get_first_encounter(issue_id = self._payload[self._idx['pk_health_issue']])
+		last_encounter = emr.get_last_encounter(issue_id = self._payload[self._idx['pk_health_issue']])
 
 		if first_encounter is None or last_encounter is None:
 			lines.append(_('No encounters found for this health issue.'))
 		else:
-			encs = emr.get_encounters(issues = [self._payload[self._idx['pk']]])
+			encs = emr.get_encounters(issues = [self._payload[self._idx['pk_health_issue']]])
 			lines.append(_('Encounters: %s (%s - %s):') % (
 				len(encs),
 				first_encounter['started_original_tz'].strftime('%m/%Y'),
@@ -227,33 +233,32 @@ age (
 		eol_w_margin = u'\n%s' % left_margin
 		return left_margin + eol_w_margin.join(lines) + u'\n'
 #============================================================
-def create_health_issue(patient_id=None, description=None, encounter=None):
+def create_health_issue(description=None, encounter=None):
 	"""Creates a new health issue for a given patient.
 
-	patient_id - given patient PK
 	description - health issue name
 	"""
 	try:
-		h_issue = cHealthIssue(patient_id=patient_id, name=description)
+		h_issue = cHealthIssue(name=description, encounter=encounter)
 		return (True, h_issue)
 	except gmExceptions.ConstructorError:
 		pass
 
 	queries = []
-	cmd = u"insert into clin.health_issue (fk_patient, description, fk_encounter) values (%s, %s, %s)"
-	queries.append({'cmd': cmd, 'args': [patient_id, description, encounter]})
+	cmd = u"insert into clin.health_issue (description, fk_encounter) values (%(desc)s, %(enc)s)"
+	queries.append({'cmd': cmd, 'args': {'desc': description, 'enc': encounter}})
 
 	cmd = u"select currval('clin.health_issue_pk_seq')"
 	queries.append({'cmd': cmd})
 
-	rows, idx = gmPG2.run_rw_queries(queries=queries, return_data=True)
+	rows, idx = gmPG2.run_rw_queries(queries = queries, return_data = True)
 	h_issue = cHealthIssue(aPK_obj = rows[0][0])
 
 	return (True, h_issue)
 #-----------------------------------------------------------
 def delete_health_issue(health_issue=None):
 	if isinstance(health_issue, cHealthIssue):
-		pk = health_issue['pk']
+		pk = health_issue['pk_health_issue']
 	else:
 		pk = int(health_issue)
 
@@ -267,7 +272,7 @@ def delete_health_issue(health_issue=None):
 # use as dummy for unassociated episodes
 def get_dummy_health_issue():
 	issue = {
-		'pk': None,
+		'pk_health_issue': None,
 		'description': _('Unattributed episodes'),
 		'age_noted': None,
 		'laterality': u'na',
@@ -277,7 +282,13 @@ def get_dummy_health_issue():
 		'is_cause_of_death': False
 	}
 	return issue
-
+#-----------------------------------------------------------
+def health_issue2problem(health_issue=None):
+	return cProblem(aPK_obj = {
+		'pk_patient': health_issue['pk_patient'],
+		'pk_health_issue': episode['pk_health_issue'],
+		'pk_episode': None
+	})
 #============================================================
 # episodes API
 #============================================================
@@ -289,8 +300,7 @@ class cEpisode(gmBusinessDBObject.cBusinessDBObject):
 		u"""update clin.episode set
 				fk_health_issue=%(pk_health_issue)s,
 				is_open=%(episode_open)s::boolean,
-				description=%(description)s,
-				fk_patient=%(pk_patient)s
+				description=%(description)s
 			where
 				pk=%(pk_episode)s and
 				xmin=%(xmin_episode)s""",
@@ -299,27 +309,44 @@ class cEpisode(gmBusinessDBObject.cBusinessDBObject):
 	_updatable_fields = [
 		'pk_health_issue',
 		'episode_open',
-		'description',
-		'pk_patient'
+		'description'
 	]
 	#--------------------------------------------------------
-	def __init__(self, aPK_obj=None, id_patient=None, name='xxxDEFAULTxxx', health_issue=None, row=None):
+	def __init__(self, aPK_obj=None, id_patient=None, name='xxxDEFAULTxxx', health_issue=None, row=None, encounter=None):
 		pk = aPK_obj
 		if pk is None and row is None:
-			if health_issue is None:
-				cmd = u"select * from clin.v_pat_episodes where pk_patient=%s and description=%s and pk_health_issue is %s"
-			else:
-				cmd = u"select * from clin.v_pat_episodes where pk_patient=%s and description=%s and pk_health_issue=%s"
-			rows, idx = gmPG2.run_ro_queries(queries = [{
-					'cmd': cmd,
-					'args': [id_patient, name, health_issue]
-				}],
+
+			where_parts = [u'description = %(desc)s']
+
+			if id_patient is not None:
+				where_parts.append(u'pk_patient = %(pat)s')
+
+			if health_issue is not None:
+				where_parts.append(u'pk_health_issue = %(issue)s')
+
+			if encounter is not None:
+				where_parts.append(u'pk_patient = (select fk_patient from clin.encounter where pk = %(enc)s)')
+
+			args = {
+				'pat': id_patient,
+				'issue': health_issue,
+				'enc': encounter,
+				'desc': name
+			}
+
+			cmd = u"select * from clin.v_pat_episodes where %s" % u' and '.join(where_parts)
+
+			rows, idx = gmPG2.run_ro_queries(
+				queries = [{'cmd': cmd, 'args': args}],
 				get_col_idx=True
 			)
+
 			if len(rows) == 0:
-				raise gmExceptions.NoSuchBusinessObjectError, 'no episode for [%s:%s:%s]' % (id_patient, name, health_issue)
+				raise gmExceptions.NoSuchBusinessObjectError, 'no episode for [%s:%s:%s:%s]' % (id_patient, name, health_issue, encounter)
+
 			r = {'idx': idx, 'data': rows[0], 'pk_field': 'pk_episode'}
 			gmBusinessDBObject.cBusinessDBObject.__init__(self, row=r)
+
 		else:
 			gmBusinessDBObject.cBusinessDBObject.__init__(self, aPK_obj=pk, row=row)
 	#--------------------------------------------------------
@@ -423,26 +450,52 @@ from (
 			first_encounter = emr.get_first_encounter(episode_id = self._payload[self._idx['pk_episode']])
 			last_encounter = emr.get_last_encounter(episode_id = self._payload[self._idx['pk_episode']])
 
-			lines.append(_('Last worked on: %s\n') % last_encounter['last_affirmed_original_tz'].strftime('%Y-%m-%d %H:%M'))
+			lines.append(_('Last worked on: %s\n') % last_encounter['last_affirmed_original_tz'].strftime('%x %H:%M'))
 
-			lines.append(_('Encounters: %s (%s - %s):') % (
+			lines.append(_('1st and last 3 of %s (%s - %s) encounters:') % (
 				len(encs),
 				first_encounter['started'].strftime('%m/%Y'),
 				last_encounter['last_affirmed'].strftime('%m/%Y')
 			))
 
-			for enc in encs:
+			lines.append(u' %s - %s (%s):%s' % (
+				first_encounter['started_original_tz'].strftime('%x %H:%M'),
+				first_encounter['last_affirmed_original_tz'].strftime('%H:%M'),
+				first_encounter['l10n_type'],
+				gmTools.coalesce (
+					first_encounter['assessment_of_encounter'],
+					gmTools.coalesce (
+						first_encounter['reason_for_encounter'],
+						u'',
+						u' \u00BB%s\u00AB' + (u' (%s)' % _('RFE'))
+					),
+					u' \u00BB%s\u00AB' + (u' (%s)' % _('AOE'))
+				)
+			))
+
+			if len(encs) > 4:
+				lines.append(_(' ... %s skipped ...') % (len(encs) - 4))
+
+			for enc in encs[1:][-3:]:
 				lines.append(u' %s - %s (%s):%s' % (
-					enc['started_original_tz'].strftime('%Y-%m-%d %H:%M'),
+					enc['started_original_tz'].strftime('%x %H:%M'),
 					enc['last_affirmed_original_tz'].strftime('%H:%M'),
 					enc['l10n_type'],
-					gmTools.coalesce(enc['assessment_of_encounter'], u'', u' \u00BB%s\u00AB')
+					gmTools.coalesce (
+						enc['assessment_of_encounter'],
+						gmTools.coalesce (
+							enc['reason_for_encounter'],
+							u'',
+							u' \u00BB%s\u00AB' + (u' (%s)' % _('RFE'))
+						),
+						u' \u00BB%s\u00AB' + (u' (%s)' % _('AOE'))
+					)
 				))
 
 		# documents
 		doc_folder = patient.get_document_folder()
 		docs = doc_folder.get_documents (
-			episode = self._payload[self._idx['pk_episode']]
+			episodes = [ self._payload[self._idx['pk_episode']] ]
 		)
 
 		if len(docs) > 0:
@@ -451,18 +504,19 @@ from (
 
 		for d in docs:
 			lines.append(u' %s %s:%s%s' % (
-				d['date'].strftime('%Y-%m-%d'),
+				d['clin_when'].strftime('%x'),
 				d['l10n_type'],
 				gmTools.coalesce(d['comment'], u'', u' "%s"'),
 				gmTools.coalesce(d['ext_ref'], u'', u' (%s)')
 			))
+		del docs
 
 		# spell out last encounter
 		if last_encounter is not None:
 			lines.append('')
 			lines.append(_('Progress notes in most recent encounter:'))
 			lines.extend(last_encounter.format_soap (
-				episode = self._payload[self._idx['pk_episode']],
+				episodes = [ self._payload[self._idx['pk_episode']] ],
 				left_margin = left_margin,
 				soap_cats = 'soap',
 				emr = emr
@@ -471,7 +525,7 @@ from (
 		eol_w_margin = u'\n%s' % left_margin
 		return left_margin + eol_w_margin.join(lines) + u'\n'
 #============================================================
-def create_episode(pk_health_issue=None, episode_name=None, patient_id=None, is_open=False, allow_dupes=False, encounter=None):
+def create_episode(pk_health_issue=None, episode_name=None, is_open=False, allow_dupes=False, encounter=None):
 	"""Creates a new episode for a given patient's health issue.
 
 	pk_health_issue - given health issue PK
@@ -479,7 +533,7 @@ def create_episode(pk_health_issue=None, episode_name=None, patient_id=None, is_
 	"""
 	if not allow_dupes:
 		try:
-			episode = cEpisode(id_patient=patient_id, name=episode_name, health_issue=pk_health_issue)
+			episode = cEpisode(name=episode_name, health_issue=pk_health_issue, encounter = encounter)
 			if episode['episode_open'] != is_open:
 				episode['episode_open'] = is_open
 				episode.save_payload()
@@ -488,8 +542,8 @@ def create_episode(pk_health_issue=None, episode_name=None, patient_id=None, is_
 			pass
 
 	queries = []
-	cmd = u"insert into clin.episode (fk_health_issue, fk_patient, description, is_open, fk_encounter) values (%s, %s, %s, %s::boolean, %s)"
-	queries.append({'cmd': cmd, 'args': [pk_health_issue, patient_id, episode_name, is_open, encounter]})
+	cmd = u"insert into clin.episode (fk_health_issue, description, is_open, fk_encounter) values (%s, %s, %s::boolean, %s)"
+	queries.append({'cmd': cmd, 'args': [pk_health_issue, episode_name, is_open, encounter]})
 	queries.append({'cmd': cEpisode._cmd_fetch_payload % u"currval('clin.episode_pk_seq')"})
 	rows, idx = gmPG2.run_rw_queries(queries = queries, return_data=True, get_col_idx=True)
 
@@ -508,7 +562,13 @@ def delete_episode(episode=None):
 		# should be parsing pgcode/and or error message
 		_log.exception('cannot delete episode')
 		raise gmExceptions.DatabaseObjectInUseError('cannot delete episode, it is in use')
-
+#-----------------------------------------------------------
+def episode2problem(episode=None):
+	return cProblem(aPK_obj = {
+		'pk_patient': episode['pk_patient'],
+		'pk_episode': episode['pk_episode'],
+		'pk_health_issue': episode['pk_health_issue']
+	})
 #============================================================
 # encounter API
 #============================================================
@@ -589,8 +649,9 @@ class cEncounter(gmBusinessDBObject.cBusinessDBObject):
 	def has_clinical_data(self):
 		cmd = u"""
 select exists (
-	select 1 from clin.v_pat_items where pk_patient=%(pat)s and pk_encounter=%(enc)s union all
-	select 1 from blobs.doc_med where fk_identity=%(pat)s and fk_encounter=%(enc)s
+	select 1 from clin.v_pat_items where pk_patient = %(pat)s and pk_encounter = %(enc)s
+		union all
+	select 1 from blobs.v_doc_med where pk_patient = %(pat)s and pk_encounter = %(enc)s
 )"""
 		args = {
 			'pat': self._payload[self._idx['pk_patient']],
@@ -624,7 +685,7 @@ select exists (
 	def has_documents(self):
 		cmd = u"""
 select exists (
-	select 1 from blobs.doc_med where fk_identity=%(pat)s and fk_encounter=%(enc)s
+	select 1 from blobs.v_doc_med where pk_patient = %(pat)s and pk_encounter = %(enc)s
 )"""
 		args = {
 			'pat': self._payload[self._idx['pk_patient']],
@@ -638,12 +699,13 @@ select exists (
 		)
 		return rows[0][0]
 	#--------------------------------------------------------
-	def format_soap(self, episode=None, left_margin=0, soap_cats='soap', emr=None):
+	def format_soap(self, episodes=None, left_margin=u'', soap_cats='soap', emr=None, issues=None):
 
 		lines = []
 		for soap_cat in soap_cats:
 			soap_cat_narratives = emr.get_clin_narrative (
-				episodes = [episode],
+				episodes = episodes,
+				issues = issues,
 				encounters = [self._payload[self._idx['pk_encounter']]],
 				soap_cats = [soap_cat]
 			)
@@ -652,58 +714,69 @@ select exists (
 			if len(soap_cat_narratives) == 0:
 				continue
 
-			lines.append('-- %s ----------' % gmClinNarrative.soap_cat2l10n_str[soap_cat])
+			lines.append(u'-- %s ----------' % gmClinNarrative.soap_cat2l10n_str[soap_cat])
 			for soap_entry in soap_cat_narratives:
 				txt = gmTools.wrap (
-					text = '%s  %.8s\n%s' % (
-						soap_entry['date'].strftime('%d.%m. %H:%M'),
+					text = u'%s\n (%.8s %s)' % (
+						soap_entry['narrative'],
 						soap_entry['provider'],
-						soap_entry['narrative']
+						soap_entry['date'].strftime('%x %H:%M')
 					),
 					width = 75,
 					initial_indent = u'',
-					subsequent_indent = left_margin + u'   '
+					subsequent_indent = left_margin + u''
 				)
 				lines.append(txt)
+				lines.append('')
 
 		return lines
 	#--------------------------------------------------------
-	def format(self, episode=None, with_soap=False, left_margin=0, patient=None):
+	def format(self, episodes=None, with_soap=False, left_margin=0, patient=None, issues=None, with_docs=True, with_tests=True, fancy_header=True):
 
 		left_margin = u' ' * left_margin
 
 		lines = []
 
-		lines.append(u'%s%s: %s - %s (@%s)%s [#%s]' % (
-			left_margin,
-			self._payload[self._idx['l10n_type']],
-			self._payload[self._idx['started_original_tz']].strftime('%Y-%m-%d %H:%M'),
-			self._payload[self._idx['last_affirmed_original_tz']].strftime('%H:%M'),
-			self._payload[self._idx['source_time_zone']],
-			gmTools.coalesce(self._payload[self._idx['assessment_of_encounter']], u'', u' \u00BB%s\u00AB'),
-			self._payload[self._idx['pk_encounter']]
-		))
+		if fancy_header:
+			lines.append(u'%s%s: %s - %s (@%s)%s [#%s]' % (
+				left_margin,
+				self._payload[self._idx['l10n_type']],
+				self._payload[self._idx['started_original_tz']].strftime('%x %H:%M'),
+				self._payload[self._idx['last_affirmed_original_tz']].strftime('%H:%M'),
+				self._payload[self._idx['source_time_zone']],
+				gmTools.coalesce(self._payload[self._idx['assessment_of_encounter']], u'', u' \u00BB%s\u00AB'),
+				self._payload[self._idx['pk_encounter']]
+			))
 
-		lines.append(_('  your time: %s - %s  (@%s = %s%s)\n') % (
-			self._payload[self._idx['started']].strftime('%Y-%m-%d %H:%M'),
-			self._payload[self._idx['last_affirmed']].strftime('%H:%M'),
-			gmDateTime.current_local_iso_numeric_timezone_string,
-			gmTools.bool2subst (
-				gmDateTime.dst_currently_in_effect,
-				time.tzname[1].decode(gmI18N.get_encoding(), 'replace'),
-				time.tzname[0].decode(gmI18N.get_encoding(), 'replace')
-			),
-			gmTools.bool2subst(gmDateTime.dst_currently_in_effect, u' - ' + _('daylight savings time in effect'), u'')
-		))
+			lines.append(_('  your time: %s - %s  (@%s = %s%s)\n') % (
+				self._payload[self._idx['started']].strftime('%x %H:%M'),
+				self._payload[self._idx['last_affirmed']].strftime('%H:%M'),
+				gmDateTime.current_local_iso_numeric_timezone_string,
+				gmTools.bool2subst (
+					gmDateTime.dst_currently_in_effect,
+					gmDateTime.py_dst_timezone_name,
+					gmDateTime.py_timezone_name
+				),
+				gmTools.bool2subst(gmDateTime.dst_currently_in_effect, u' - ' + _('daylight savings time in effect'), u'')
+			))
 
-		lines.append(u'%s: %s' % (
-			_('RFE'),
-			gmTools.coalesce(self._payload[self._idx['reason_for_encounter']], u'')
-		))
-		lines.append(u'%s: %s' % (
-			_('AOE'),
-			gmTools.coalesce(self._payload[self._idx['assessment_of_encounter']], u'')
-		))
+			lines.append(u'%s: %s' % (
+				_('RFE'),
+				gmTools.coalesce(self._payload[self._idx['reason_for_encounter']], u'')
+			))
+			lines.append(u'%s: %s' % (
+				_('AOE'),
+				gmTools.coalesce(self._payload[self._idx['assessment_of_encounter']], u'')
+			))
+
+		else:
+			lines.append(u'%s%s: %s - %s%s' % (
+				left_margin,
+				self._payload[self._idx['l10n_type']],
+				self._payload[self._idx['started_original_tz']].strftime('%x %H:%M'),
+				self._payload[self._idx['last_affirmed_original_tz']].strftime('%H:%M'),
+				gmTools.coalesce(self._payload[self._idx['assessment_of_encounter']], u'', u' \u00BB%s\u00AB')
+			))
 
 		if with_soap:
 			lines.append(u'')
@@ -718,52 +791,49 @@ select exists (
 
 			emr = patient.get_emr()
 
-#			if episode['episode_open']:
-#				template = _('Progress notes for ongoing episode %s%s%s:')
-#			else:
-#				template = _('Progress notes for closed episode %s%s%s:')
-#			lines.append(template % (
-#				u'\u00BB',
-#				episode['description'],
-#				u'\u00AB'
-#			))
-
 			lines.extend(self.format_soap (
-				episode = episode['pk_episode'],
+				episodes = episodes,
 				left_margin = left_margin,
 				soap_cats = 'soap',
-				emr = emr
+				emr = emr,
+				issues = issues
 			))
 
 		# test results
-		tests = emr.get_test_results_by_date (
-			episode = episode['pk_episode'],
-			encounter = self._payload[self._idx['pk_encounter']]
-		)
-		if len(tests) > 0:
-			lines.append('')
-			lines.append(_('Measurements and Results:'))
+		if with_tests:
+			tests = emr.get_test_results_by_date (
+				episodes = episodes,
+				encounter = self._payload[self._idx['pk_encounter']]
+			)
+			if len(tests) > 0:
+				lines.append('')
+				lines.append(_('Measurements and Results:'))
+
 			for t in tests:
 				lines.extend(t.format())
 
-		# documents
-		doc_folder = patient.get_document_folder()
-		docs = doc_folder.get_documents (
-			episode = episode['pk_episode'],
-			encounter = self._payload[self._idx['pk_encounter']]
-		)
+			del tests
 
-		if len(docs) > 0:
-			lines.append('')
-			lines.append(_('Documents:'))
+		if with_docs:
+			doc_folder = patient.get_document_folder()
+			docs = doc_folder.get_documents (
+				episodes = episodes,
+				encounter = self._payload[self._idx['pk_encounter']]
+			)
 
-		for d in docs:
-			lines.append(u' %s %s:%s%s' % (
-				d['date'].strftime('%Y-%m-%d'),
-				d['l10n_type'],
-				gmTools.coalesce(d['comment'], u'', u' "%s"'),
-				gmTools.coalesce(d['ext_ref'], u'', u' (%s)')
-			))
+			if len(docs) > 0:
+				lines.append('')
+				lines.append(_('Documents:'))
+
+			for d in docs:
+				lines.append(u' %s %s:%s%s' % (
+					d['clin_when'].strftime('%x'),
+					d['l10n_type'],
+					gmTools.coalesce(d['comment'], u'', u' "%s"'),
+					gmTools.coalesce(d['ext_ref'], u'', u' (%s)')
+				))
+
+			del docs
 
 		eol_w_margin = u'\n%s' % left_margin
 		return u'%s\n' % eol_w_margin.join(lines)
@@ -978,9 +1048,9 @@ if __name__ == '__main__':
 			print field, ':', h_issue[field]
 		print "has open episode:", h_issue.has_open_episode()
 		print "open episode:", h_issue.get_open_episode()
-		print "updatable:", h_issue.get_updatable_fields()
+		print "updateable:", h_issue.get_updatable_fields()
 		h_issue.close_expired_episode(ttl=7300)
-		h_issue = cHealthIssue(patient_id=12, name=u'post appendectomy/peritonitis')
+		h_issue = cHealthIssue(encounter = 1, name = u'post appendectomy/peritonitis')
 		print h_issue
 	#--------------------------------------------------------	
 	def test_episode():
@@ -1025,25 +1095,57 @@ if __name__ == '__main__':
 		print "updatable:", encounter.get_updatable_fields()
 
 	#--------------------------------------------------------
-	# run them
-	test_episode()
-	test_problem()
-	test_encounter()
-	test_health_issue()
+	if (len(sys.argv) > 1) and (sys.argv[1] == 'test'):
+		# run them
+		#test_episode()
+		#test_problem()
+		#test_encounter()
+		test_health_issue()
 
 #============================================================
 # $Log: gmEMRStructItems.py,v $
-# Revision 1.119.2.4  2009/01/15 08:53:12  ncq
-# - cleanup
+# Revision 1.132  2009/02/27 12:38:03  ncq
+# - improved SOAP formatting
 #
-# Revision 1.119.2.3  2008/11/25 11:57:42  ncq
-# - missing gmI18N import
+# Revision 1.131  2009/02/23 08:46:01  ncq
+# - fix faulty column label
 #
-# Revision 1.119.2.2  2008/11/20 18:23:18  ncq
-# - fix spelling
+# Revision 1.130  2009/02/17 17:45:53  ncq
+# - fix create_health_issue
 #
-# Revision 1.119.2.1  2008/11/11 21:00:12  ncq
-# - need to encode tzname on Windows
+# Revision 1.129  2008/12/18 21:26:20  ncq
+# - u''ify some strings
+#
+# Revision 1.128  2008/12/09 23:21:00  ncq
+# - .date -> .clin_when in documents
+# - no more fk_patient in episode
+#
+# Revision 1.127  2008/12/01 12:36:13  ncq
+# - much improved formatting
+#
+# Revision 1.126  2008/11/24 11:09:01  ncq
+# - health issues now stem from a view
+# - no more fk_patient in clin.health_issue
+# - no more patient id in create_episode
+#
+# Revision 1.125  2008/11/20 18:40:53  ncq
+# - health_issue/episode2problem
+# - improved formatting
+#
+# Revision 1.124  2008/10/22 12:04:55  ncq
+# - use %x in strftime
+#
+# Revision 1.123  2008/10/12 15:13:30  ncq
+# - no more "foundational" in health issue
+#
+# Revision 1.122  2008/09/09 19:55:07  ncq
+# - Jerzy found a misspelling
+#
+# Revision 1.121  2008/09/04 11:52:17  ncq
+# - append an empty line per soap category
+#
+# Revision 1.120  2008/09/02 18:58:27  ncq
+# - fk_patient dropped from clin.health_issue
 #
 # Revision 1.119  2008/08/17 18:13:39  ncq
 # - add CRLF after date/time/provider in soap formatting as
