@@ -7,8 +7,8 @@ license: GPL
 """
 #============================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/business/gmForms.py,v $
-# $Id: gmForms.py,v 1.58.2.1 2008/08/31 14:19:55 ncq Exp $
-__version__ = "$Revision: 1.58.2.1 $"
+# $Id: gmForms.py,v 1.61 2009/02/18 13:43:37 ncq Exp $
+__version__ = "$Revision: 1.61 $"
 __author__ ="Ian Haywood <ihaywood@gnu.org>, karsten.hilbert@gmx.net"
 
 
@@ -143,7 +143,7 @@ class cFormTemplate(gmBusinessDBObject.cBusinessDBObject):
 			filename = gmTools.get_unique_filename (
 				prefix = 'gm-%s-Template-' % self._payload[self._idx['engine']],
 				suffix = suffix,
-				dir = os.path.expanduser(os.path.join('~', '.gnumed', 'tmp'))
+				tmp_dir = os.path.expanduser(os.path.join('~', '.gnumed', 'tmp'))
 			)
 
 		data_query = {
@@ -262,7 +262,7 @@ class gmOOoConnector(gmBorg.cBorg):
 
 		init_ooo()
 
-		self.ooo_start_cmd = 'oowriter -accept="socket,host=localhost,port=2002;urp;"'
+		self.ooo_start_cmd = 'oowriter -invisible -accept="socket,host=localhost,port=2002;urp;"'
 		self.resolver_uri = "com.sun.star.bridge.UnoUrlResolver"
 		self.remote_context_uri = "uno:socket,host=localhost,port=2002;urp;StarOffice.ComponentContext"
 		self.desktop_uri = "com.sun.star.frame.Desktop"
@@ -274,13 +274,13 @@ class gmOOoConnector(gmBorg.cBorg):
 	#--------------------------------------------------------
 	def open_document(self, filename=None):
 		"""<filename> must be absolute"""
-		document_uri = uno.systemPathToFileUrl(os.path.abspath(os.path.expanduser(filename)))
-		desk = self.desktop
-
-		if desk is None:
+		# make sure we have a desktop
+		if self.desktop is None:
 			return None
 
-		doc = desk.loadComponentFromURL(document_uri, "_blank", 0, ())
+		document_uri = uno.systemPathToFileUrl(os.path.abspath(os.path.expanduser(filename)))
+
+		doc = self.desktop.loadComponentFromURL(document_uri, "_blank", 0, ())
 		return doc
 	#--------------------------------------------------------
 	# properties
@@ -816,8 +816,14 @@ if __name__ == '__main__':
 
 #============================================================
 # $Log: gmForms.py,v $
-# Revision 1.58.2.1  2008/08/31 14:19:55  ncq
-# - fix faulty variable naming
+# Revision 1.61  2009/02/18 13:43:37  ncq
+# - get_unique_filename API change
+#
+# Revision 1.60  2008/09/02 18:59:01  ncq
+# - add "invisible" to ooo startup command as suggested by Jerzy
+#
+# Revision 1.59  2008/08/29 20:54:28  ncq
+# - cleanup
 #
 # Revision 1.58  2008/04/29 18:27:44  ncq
 # - cOOoConnector -> gmOOoConnector
