@@ -4,8 +4,8 @@
 """
 #============================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/business/gmMedDoc.py,v $
-# $Id: gmMedDoc.py,v 1.105 2008/06/26 21:19:15 ncq Exp $
-__version__ = "$Revision: 1.105 $"
+# $Id: gmMedDoc.py,v 1.112.2.2 2009/08/04 14:43:44 ncq Exp $
+__version__ = "$Revision: 1.112.2.2 $"
 __author__ = "Karsten Hilbert <Karsten.Hilbert@gmx.net>"
 
 import sys, os, shutil, os.path, types, time, logging
@@ -78,15 +78,15 @@ class cDocumentFolder:
 		else:
 			cmd = u"""
 				select
-					dm.pk as pk_doc,
+					vdm.pk_doc as pk_doc,
 					dobj.pk as pk_obj
 				from
-					blobs.doc_med dm
+					blobs.v_doc_med vdm
 					blobs.doc_obj dobj
 				where
-					dm.fk_type = (select pk from blobs.doc_type where name='patient photograph') and
-					dm.fk_identity=%s and
-					and dobj.fk_doc = dm.pk
+					vdm.pk_type = (select pk from blobs.doc_type where name = 'patient photograph')
+					and vdm.pk_patient = %s
+					and dobj.fk_doc = vdm.pk_doc
 			"""
 		rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': [self.pk_patient]}])
 		return rows
@@ -99,28 +99,28 @@ class cDocumentFolder:
 		}
 		# FIXME: might have to order by on modified_when, date is a string
 		if doc_type is None:
-			cmd = u"""select pk from blobs.doc_med where fk_identity=%(ID)s"""
+			cmd = u"select pk_doc from blobs.v_doc_med where pk_patient = %(ID)s"
 		elif type(doc_type) == types.StringType:
 			cmd = u"""
-				select dm.pk
-				from blobs.doc_med dm
+				select vdm.pk_doc
+				from blobs.v_doc_med vdm
 				where
-					dm.fk_identity = %(ID)s and
-					dm.fk_type = (select pk from blobs.doc_type where name=%(TYP)s)"""
+					vdm.pk_patient = %(ID)s and
+					vdm.pk_type = (select pk from blobs.doc_type where name = %(TYP)s)"""
 		else:
 			cmd = u"""
-				select dm.pk
-				from blobs.doc_med dm
+				select vdm.pk_doc
+				from blobs.v_doc_med vdm
 				where
-					dm.fk_identity = %(ID)s and
-					dm.fk_type = %(TYP)s"""
+					vdm.pk_patient = %(ID)s and
+					vdm.pk_type = %(TYP)s"""
 		rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': args}])
 		doc_ids = []
 		for row in rows:
 			doc_ids.append(row[0])
 		return doc_ids
 	#--------------------------------------------------------
-	def get_documents(self, doc_type=None, episode=None, encounter=None):
+	def get_documents(self, doc_type=None, episodes=None, encounter=None):
 		"""Return list of documents."""
 		doc_ids = self.get_doc_list(doc_type=doc_type)
 
@@ -132,15 +132,16 @@ class cDocumentFolder:
 				_log.exception('document error on [%s] for patient [%s]' % (doc_id, self.pk_patient))
 				continue
 
-		if episode is not None:
-			docs = [ d for d in docs if d['pk_episode'] == episode ]
+		if episodes is not None:
+			docs = [ d for d in docs if d['pk_episode'] in episodes ]
+
 		if encounter is not None:
 			docs = [ d for d in docs if d['pk_encounter'] == encounter ]
 
 		return docs
 	#--------------------------------------------------------
 	def add_document(self, document_type=None, encounter=None, episode=None):
-		return create_document(patient_id=self.pk_patient, document_type=document_type, encounter=encounter, episode=episode)
+		return create_document(document_type = document_type, encounter = encounter, episode = episode)
 #============================================================
 class cMedDocPart(gmBusinessDBObject.cBusinessDBObject):
 	"""Represents one part of a medical document."""
@@ -183,7 +184,7 @@ class cMedDocPart(gmBusinessDBObject.cBusinessDBObject):
 			filename = gmTools.get_unique_filename (
 				prefix = 'gm-doc_obj-page_%s-' % self._payload[self._idx['seq_idx']],
 				suffix = suffix,
-				dir = aTempDir
+				tmp_dir = aTempDir
 			)
 
 		success = gmPG2.bytea2file (
@@ -328,21 +329,21 @@ class cMedDoc(gmBusinessDBObject.cBusinessDBObject):
 	_cmd_fetch_payload = u"""select * from blobs.v_doc_med where pk_doc=%s"""
 	_cmds_store_payload = [
 		u"""update blobs.doc_med set
-				fk_type=%(pk_type)s,
-				comment=%(comment)s,
-				date=%(date)s,
-				ext_ref=%(ext_ref)s,
-				fk_episode=%(pk_episode)s
+				fk_type = %(pk_type)s,
+				comment = %(comment)s,
+				clin_when = %(clin_when)s,
+				ext_ref = %(ext_ref)s,
+				fk_episode = %(pk_episode)s
 			where
-				pk=%(pk_doc)s and
-				xmin=%(xmin_doc_med)s""",
-		u"""select xmin_doc_med from blobs.v_doc_med where pk_doc=%(pk_doc)s"""
+				pk = %(pk_doc)s and
+				xmin = %(xmin_doc_med)s""",
+		u"""select xmin_doc_med from blobs.v_doc_med where pk_doc = %(pk_doc)s"""
 		]
 
 	_updatable_fields = [
 		'pk_type',
 		'comment',
-		'date',
+		'clin_when',
 		'ext_ref',
 		'pk_episode'
 	]
@@ -350,23 +351,30 @@ class cMedDoc(gmBusinessDBObject.cBusinessDBObject):
 	def get_descriptions(self, max_lng=250):
 		"""Get document descriptions.
 
-		- will return a list of strings
+		- will return a list of rows
 		"""
 		if max_lng is None:
-			cmd = u"SELECT text FROM blobs.doc_desc WHERE fk_doc=%s"
+			cmd = u"SELECT pk, text FROM blobs.doc_desc WHERE fk_doc = %s"
 		else:
-			cmd = u"SELECT substring(text from 1 for %s) FROM blobs.doc_desc WHERE fk_doc=%%s" % max_lng
+			cmd = u"SELECT pk, substring(text from 1 for %s) FROM blobs.doc_desc WHERE fk_doc=%%s" % max_lng
 		rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': [self.pk_obj]}])
-		if len(rows) == 0:
-			return [_('no descriptions available')]
-		data = []
-		for desc in rows:
-			data.extend(desc)
-		return data
+		return rows
 	#--------------------------------------------------------
-	def add_description(self, description):
+	def add_description(self, description=None):
 		cmd = u"insert into blobs.doc_desc (fk_doc, text) values (%s, %s)"
-		gmPG2.run_rw_queries(queries = [{'cmd': cmd, 'args': [self.pk_obj, str(description)]}])
+		gmPG2.run_rw_queries(queries = [{'cmd': cmd, 'args': [self.pk_obj, description]}])
+		return True
+	#--------------------------------------------------------
+	def update_description(self, pk=None, description=None):
+		cmd = u"update blobs.doc_desc set text = %(desc)s where fk_doc = %(doc)s and pk = %(pk_desc)s"
+		gmPG2.run_rw_queries(queries = [
+			{'cmd': cmd, 'args': {'doc': self.pk_obj, 'pk_desc': pk, 'desc': description}}
+		])
+		return True
+	#--------------------------------------------------------
+	def delete_description(self, pk=None):
+		cmd = u"delete from blobs.doc_desc where fk_doc = %(doc)s and pk = %(desc)s"
+		gmPG2.run_rw_queries(queries = [{'cmd': cmd, 'args': {'doc': self.pk_obj, 'desc': pk}}])
 		return True
 	#--------------------------------------------------------
 	def get_parts(self):
@@ -496,7 +504,7 @@ class cDocumentType(gmBusinessDBObject.cBusinessDBObject):
 		rows, idx = gmPG2.run_rw_queries (
 			queries = [
 				{'cmd': u'select i18n.i18n(%s)', 'args': [self._payload[self._idx['type']]]},
-				{'cmd': u'select i18n.upd_tx((select lang from i18n.curr_lang where user = CURRENT_USER), %(orig)s, %(tx)s)',
+				{'cmd': u'select i18n.upd_tx((select i18n.get_curr_lang()), %(orig)s, %(tx)s)',
 				 'args': {
 				 	'orig': self._payload[self._idx['type']],
 					'tx': translation
@@ -513,14 +521,14 @@ class cDocumentType(gmBusinessDBObject.cBusinessDBObject):
 #============================================================
 # convenience functions
 #============================================================
-def create_document(patient_id=None, document_type=None, encounter=None, episode=None):
+def create_document(document_type=None, encounter=None, episode=None):
 	"""Returns new document instance or raises an exception.
 	"""
-	cmd1 = u"""insert into blobs.doc_med (fk_identity, fk_type, fk_encounter, fk_episode) VALUES (%s, %s, %s, %s)"""
+	cmd1 = u"""insert into blobs.doc_med (fk_type, fk_encounter, fk_episode) VALUES (%(type)s, %(enc)s, %(epi)s)"""
 	cmd2 = u"""select currval('blobs.doc_med_pk_seq')"""
 	rows, idx = gmPG2.run_rw_queries (
 		queries = [
-			{'cmd': cmd1, 'args': [patient_id, document_type, encounter, episode]},
+			{'cmd': cmd1, 'args': {'type': document_type, 'enc': encounter, 'epi': episode}},
 			{'cmd': cmd2}
 		],
 		return_data = True
@@ -536,13 +544,13 @@ def search_for_document(patient_id=None, type_id=None):
 	"""
 	# sanity checks
 	if patient_id is None:
-		raise ValueError('need patient id to create document')
+		raise ValueError('need patient id to search for document')
 
 	args = {'pat_id': patient_id, 'type_id': type_id}
 	if type_id is None:
-		cmd = u"SELECT pk from blobs.doc_med WHERE fk_identity=%(pat_id)s"
+		cmd = u"SELECT pk_doc from blobs.v_doc_med WHERE pk_patient = %(pat_id)s"
 	else:
-		cmd = u"SELECT pk from blobs.doc_med WHERE fk_identity=%(pat_id)s and fk_type=%(type_id)s"
+		cmd = u"SELECT pk_doc from blobs.v_doc_med WHERE pk_patient = %(pat_id)s and pk_type = %(type_id)s"
 
 	rows, idx = gmPG2.run_ro_queries(queries = [{'cmd': cmd, 'args': args}])
 
@@ -575,7 +583,7 @@ def get_document_types():
 #------------------------------------------------------------
 def create_document_type(document_type=None):
 	# check for potential dupes:
-	cmd = u'select pk from blobs.doc_type where name=%s'
+	cmd = u'select pk from blobs.doc_type where name = %s'
 	rows, idx = gmPG2.run_ro_queries (
 		queries = [{'cmd': cmd, 'args': [document_type]}]
 	)
@@ -702,6 +710,34 @@ if __name__ == '__main__':
 
 #============================================================
 # $Log: gmMedDoc.py,v $
+# Revision 1.112.2.2  2009/08/04 14:43:44  ncq
+# - add missing )
+#
+# Revision 1.112.2.1  2009/06/04 14:21:46  ncq
+# - fix an fk_type that needs to be pk_type
+#
+# Revision 1.112  2009/02/18 13:43:38  ncq
+# - get_unique_filename API change
+#
+# Revision 1.111  2009/01/15 11:31:58  ncq
+# - implement description handling
+#
+# Revision 1.110  2009/01/11 19:16:05  ncq
+# - pseudo method
+#
+# Revision 1.109  2009/01/08 16:42:01  ncq
+# - get_descriptions now includes pks of rows
+#
+# Revision 1.108  2008/12/09 23:21:54  ncq
+# - no more fk_identity in doc_med
+# - date -> clin_when in doc_med
+#
+# Revision 1.107  2008/11/20 18:41:36  ncq
+# - rename arg in get_documents
+#
+# Revision 1.106  2008/10/12 15:14:14  ncq
+# - use i18n.get_curr_lang
+#
 # Revision 1.105  2008/06/26 21:19:15  ncq
 # - enhance get_documents with episode/encounter filters
 #
