@@ -4,10 +4,11 @@ license: GPL
 """
 #============================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/business/gmPathLab.py,v $
-# $Id: gmPathLab.py,v 1.64 2008/07/14 13:45:08 ncq Exp $
-__version__ = "$Revision: 1.64 $"
+# $Id: gmPathLab.py,v 1.68 2009/02/27 12:38:16 ncq Exp $
+__version__ = "$Revision: 1.68 $"
 __author__ = "K.Hilbert <Karsten.Hilbert@gmx.net>"
 
+
 import types, sys, logging
 
 
@@ -113,7 +114,7 @@ def create_test_type(lab=None, code=None, unit=None, name=None):
 #		# yes but ambigous
 #		if name != db_lname:
 #			_log.error('test type found for [%s:%s] but long name mismatch: expected [%s], in DB [%s]' % (lab, code, name, db_lname))
-#			me = '$RCSfile: gmPathLab.py,v $ $Revision: 1.64 $'
+#			me = '$RCSfile: gmPathLab.py,v $ $Revision: 1.68 $'
 #			to = 'user'
 #			prob = _('The test type already exists but the long name is different. '
 #					'The test facility may have changed the descriptive name of this test.')
@@ -233,25 +234,31 @@ class cTestResult(gmBusinessDBObject.cBusinessDBObject):
 
 		lines = []
 
-		lines.append(u' %s %s (%s): %s %s (%s)' % (
+		lines.append(u' %s %s (%s): %s %s%s' % (
 			self._payload[self._idx['clin_when']].strftime('%d.%m. %H:%M'),
 			self._payload[self._idx['unified_code']],
 			self._payload[self._idx['unified_name']],
 			self._payload[self._idx['unified_val']],
 			self._payload[self._idx['val_unit']],
-			self._payload[self._idx['abnormality_indicator']]
+			gmTools.coalesce(self._payload[self._idx['abnormality_indicator']], u'', u' (%s)')
 		))
 		if gmTools.coalesce(self._payload[self._idx['comment']], u'').strip() != u'':
 			lines.append(_('   Doc: %s') % self._payload[self._idx['comment']].strip())
-		if gmTools.coalesce(self._payload[self._idx['comment']], u'').strip() != u'':
+		if gmTools.coalesce(self._payload[self._idx['note_test_org']], u'').strip() != u'':
 			lines.append(_('   MTA: %s') % self._payload[self._idx['note_test_org']].strip())
 		if self._payload[self._idx['reviewed']]:
-			lines.append(u'   %s @ %s: %s, %s' % (
-				self._payload[self._idx['last_reviewer']],
-				self._payload[self._idx['last_reviewed']].strftime('%Y-%m-%d %H:%M'),
-				gmTools.bool2subst(self._payload[self._idx['is_technically_abnormal']], _('abnormal'), _('normal')),
-				gmTools.bool2subst(self._payload[self._idx['is_clinically_relevant']], _('relevant'), _('not relevant'))
-			))
+			if self._payload[self._idx['is_clinically_relevant']]:
+				lines.append(u'   %s  %s: %s' % (
+					self._payload[self._idx['last_reviewer']],
+					self._payload[self._idx['last_reviewed']].strftime('%x %H:%M'),
+					gmTools.bool2subst (
+						self._payload[self._idx['is_technically_abnormal']],
+						_('abnormal and relevant'),
+						_('normal but relevant')
+					)
+				))
+		else:
+			lines.append(_('   unreviewed'))
 
 		return lines
 	#--------------------------------------------------------
@@ -684,7 +691,7 @@ def create_lab_request(lab=None, req_id=None, pat_id=None, encounter_id=None, ep
 		# yes but ambigous
 		if pat_id != db_pat[0]:
 			_log.error('lab request found for [%s:%s] but patient mismatch: expected [%s], in DB [%s]' % (lab, req_id, pat_id, db_pat))
-			me = '$RCSfile: gmPathLab.py,v $ $Revision: 1.64 $'
+			me = '$RCSfile: gmPathLab.py,v $ $Revision: 1.68 $'
 			to = 'user'
 			prob = _('The lab request already exists but belongs to a different patient.')
 			sol = _('Verify which patient this lab request really belongs to.')
@@ -967,6 +974,18 @@ if __name__ == '__main__':
 
 #============================================================
 # $Log: gmPathLab.py,v $
+# Revision 1.68  2009/02/27 12:38:16  ncq
+# - improved results formatting
+#
+# Revision 1.67  2009/02/18 19:17:56  ncq
+# - properly test for NULLness when formatting results
+#
+# Revision 1.66  2009/01/02 11:34:50  ncq
+# - cleanup
+#
+# Revision 1.65  2008/10/22 12:04:55  ncq
+# - use %x in strftime
+#
 # Revision 1.64  2008/07/14 13:45:08  ncq
 # - add .format to test results
 #
