@@ -10,8 +10,8 @@ TODO:
 """
 #============================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/exporters/gmPatientExporter.py,v $
-# $Id: gmPatientExporter.py,v 1.127 2008/07/28 15:42:30 ncq Exp $
-__version__ = "$Revision: 1.127 $"
+# $Id: gmPatientExporter.py,v 1.134 2009/01/02 11:36:43 ncq Exp $
+__version__ = "$Revision: 1.134 $"
 __author__ = "Carlos Moro"
 __license__ = 'GPL'
 
@@ -119,9 +119,8 @@ class cEmrExport:
         """
         emr = self.__patient.get_emr()
         # patient dob
-        
         patient_dob = self.__patient['dob']
-        date_length = len(patient_dob.strftime('%Y-%m-%d')) + 2 # (YYYY-mm-dd)
+        date_length = len(patient_dob.strftime('%x')) + 2
 
         # dictionary of pairs indication : scheduled vaccination
         vaccinations4regimes = {}
@@ -152,9 +151,9 @@ class cEmrExport:
             else:
                 column_widths.append(date_length)  # date -> column width at least
             vaccinations[a_vacc_regime['indication']] = emr.get_vaccinations(indications=[a_vacc_regime['indication']]) # given shots 4 indication
-                
+
         # patient dob in top of vaccination chart 
-        txt = '\nDOB: %s' %(patient_dob.strftime('%Y-%m-%d')) + '\n'         
+        txt = '\nDOB: %s' %(patient_dob.strftime('%x')) + '\n'
 
         # vacc chart table headers
         # top ---- header line
@@ -192,9 +191,9 @@ class cEmrExport:
                 elif row_index < seq_no: # vaccination scheduled
                     try:
                         vacc_date = vaccinations[indication][row_index]['date'] # vaccination given                           
-                        vacc_date_str = vacc_date.strftime('%Y-%m-%d')                        
-                        txt +=    vacc_date_str + (column_widths[col_index] - len(vacc_date_str)) * ' ' + '|'                           
-                        prev_displayed_date[col_index] = vacc_date                                                  
+                        vacc_date_str = vacc_date.strftime('%x')
+                        txt +=    vacc_date_str + (column_widths[col_index] - len(vacc_date_str)) * ' ' + '|'
+                        prev_displayed_date[col_index] = vacc_date
                     except:
                         if row_index == 0: # due first shot
                             due_date = prev_displayed_date[col_index] + vaccinations4regimes[indication][row_index]['age_due_min'] # FIXME 'age_due_min' not properly retrieved
@@ -499,9 +498,9 @@ class cEmrExport:
         if len(unlinked_episodes) > 0:
             h_issues.insert(0, {
                 'description': _('Unattributed episodes'),
-                'pk': None
+                'pk_health_issue': None
             })
-        # existing issues        
+        # existing issues
         for a_health_issue in h_issues:
             health_issue_action( emr_tree, a_health_issue)
 
@@ -513,7 +512,7 @@ class cEmrExport:
             root_node = emr_tree.GetRootItem()
             issue_node =  emr_tree.AppendItem(root_node, a_health_issue['description'])
             emr_tree.SetPyData(issue_node, a_health_issue)
-            episodes = emr.get_episodes(id_list=self.__constraints['episodes'], issues = [a_health_issue['pk']])
+            episodes = emr.get_episodes(id_list=self.__constraints['episodes'], issues = [a_health_issue['pk_health_issue']])
             for an_episode in episodes:
                 self._add_episode_to_tree( emr, emr_tree, issue_node,a_health_issue,  an_episode)
             emr_tree.SortChildren(issue_node)
@@ -528,12 +527,22 @@ class cEmrExport:
         self._add_encounters_to_tree( encounters,  emr_tree, episode_node )
         emr_tree.SortChildren(episode_node)
         return episode_node
-    #--------------------------------------------------------             
+    #--------------------------------------------------------
     def _add_encounters_to_tree( self, encounters, emr_tree, episode_node):
         for an_encounter in encounters:
-            label = '%s: %s' % (an_encounter['started'].strftime('%Y-%m-%d'), an_encounter['l10n_type'])
-            encounter_node = emr_tree.AppendItem(episode_node, label)
-            emr_tree.SetPyData(encounter_node, an_encounter)
+#            label = u'%s: %s' % (an_encounter['started'].strftime('%Y-%m-%d'), an_encounter['l10n_type'])
+            label = u'%s: %s' % (
+                an_encounter['started'].strftime('%Y-%m-%d'),
+                gmTools.coalesce (
+                    gmTools.coalesce (
+                        an_encounter['assessment_of_encounter'],
+                        an_encounter['reason_for_encounter']
+                    ),
+                    an_encounter['l10n_type']
+                )[:40]
+            )
+            encounter_node_id = emr_tree.AppendItem(episode_node, label)
+            emr_tree.SetPyData(encounter_node_id, an_encounter)
     #--------------------------------------------------------
     def _get_encounters ( self, an_episode, emr ):
                encounters = emr.get_encounters (
@@ -556,7 +565,7 @@ class cEmrExport:
 			_log.error("health issue %s should exist in tree already", a_health_issue['description'] )
 			return
 		issue_node = id
-		episodes = emr.get_episodes(id_list=self.__constraints['episodes'], issues = [a_health_issue['pk']])
+		episodes = emr.get_episodes(id_list=self.__constraints['episodes'], issues = [a_health_issue['pk_health_issue']])
 
 		#check for removed episode and update tree
 		tree_episodes = {} 
@@ -617,63 +626,6 @@ class cEmrExport:
             txt += self.get_item_summary(an_item, left_margin)
         return txt
     #--------------------------------------------------------
-    def get_issue_info(self, issue=None, left_margin=0):
-        """Dumps health issue specific data
-        """
-        # dummy issue for unlinked episodes ?
-        # FIXME: turn into "proper" dummy episode
-        if issue['pk'] is None:
-            txt = _('Active health issue "%s"') % issue['description']
-            return txt
-
-        if issue['is_active']:
-            status = _('Active health issue')
-        else:
-            status = _('Inactive health issue')
-        txt = _('%s "%s"\n noted at age %s\n') % (
-            status,
-            issue['description'],
-#            issue['age_noted']
-            issue.age_noted_human_readable()
-        )
-#        print issue.age_noted_human_readable()
-        if issue['clinically_relevant']:
-            txt += _('clinically relevant: yes\n')
-        else:
-            txt += _('clinically relevant: no\n')
-        if issue['is_cause_of_death']:
-            txt += _('health issue caused death of patient\n')
-        if issue['is_confidential']:
-            txt += _('\n***** CONFIDENTIAL *****\n\n')
-
-        emr = self.__patient.get_emr()
-        epis = emr.get_episodes(issues=[issue['pk']])
-        if epis is None:
-            txt += left_margin * ' ' + _('Error retrieving episodes for health issue\n%s') % str(issue)
-            return txt
-        no_epis = len(epis)
-        if no_epis == 0:
-            txt += left_margin * ' ' + _('There are no episodes for this health issue.\n')
-            return txt
-
-        first_encounter = emr.get_first_encounter(issue_id = issue['pk'])
-        last_encounter = emr.get_last_encounter(issue_id = issue['pk'])
-        if first_encounter is None or last_encounter is None:
-            txt += _('%s%s episode(s)\n\n%sNo encounters found for this health issue.\n') % (
-                left_margin * ' ',
-                str(no_epis),
-                left_margin * ' ')
-            return txt
-        txt += _('%s%s episode(s) between %s and %s\n') % (
-            left_margin * ' ',
-            str(no_epis),
-            first_encounter['started'].strftime('%m/%Y'),
-            last_encounter['last_affirmed'].strftime('%m/%Y')
-        )
-        txt += _('%sLast seen: %s\n\n') % (left_margin * ' ', last_encounter['last_affirmed'].strftime('%Y-%m-%d %H:%M'))
-        # FIXME: list each episode with range of time
-        return txt
-    #--------------------------------------------------------
     def get_episode_summary (self, episode, left_margin = 0):
         """Dumps episode specific data"""
         emr = self.__patient.get_emr()
@@ -786,16 +738,16 @@ class cEmrExport:
         # unlinked episodes
         unlinked_episodes = emr.get_episodes(issues = [None])
         if len(unlinked_episodes) > 0:
-            h_issues.insert(0, {'description':_('Unattributed episodes'), 'pk':None})        
+            h_issues.insert(0, {'description':_('Unattributed episodes'), 'pk_health_issue':None})        
         for a_health_issue in h_issues:
             self.__target.write('\n' + 3*' ' + 'Health Issue: ' + a_health_issue['description'] + '\n')
-            episodes = emr.get_episodes(id_list=self.__constraints['episodes'], issues = [a_health_issue['pk']])
+            episodes = emr.get_episodes(id_list=self.__constraints['episodes'], issues = [a_health_issue['pk_health_issue']])
             for an_episode in episodes:
                self.__target.write('\n' + 6*' ' + 'Episode: ' + an_episode['description'] + '\n')
-               if a_health_issue['pk'] is None:
+               if a_health_issue['pk_health_issue'] is None:
                   issues = None
                else:
-                  issues = [a_health_issue['pk']]
+                  issues = [a_health_issue['pk_health_issue']]
                encounters = emr.get_encounters (
                   since = self.__constraints['since'],
                   until = self.__constraints['until'],
@@ -820,7 +772,6 @@ class cEmrExport:
     def dump_clinical_record(self):
         """
         Dumps in ASCII format patient's clinical record
-        
         """
         emr = self.__patient.get_emr()
         if emr is None:
@@ -859,7 +810,7 @@ class cEmrExport:
         docs = doc_folder.get_documents()
         for doc in docs:
             self.__target.write('\n\n    (%s) %s - %s "%s"' % (
-                doc['date'].strftime('%Y-%m-%d'),
+                doc['clin_when'].strftime('%Y-%m-%d'),
                 doc['ext_ref'],
                 doc['l10n_type'],
                 doc['comment'])
@@ -994,9 +945,9 @@ class cEMRJournalExporter:
 		target.write(u'=' * (len(txt)-1))
 		target.write('\n')
 		target.write(_('Patient: %s (%s), No: %s\n') % (patient['description'], patient['gender'], patient['pk_identity']))
-		target.write(_('Born   : %s, age: %s\n\n') % (patient['dob'].strftime('%Y-%m-%d'), patient.get_medical_age()))
+		target.write(_('Born   : %s, age: %s\n\n') % (patient['dob'].strftime('%x'), patient.get_medical_age()))
 		target.write(u'.-%10.10s---%9.9s-------%72.72s\n' % (u'-' * 10, u'-' * 9, u'-' * self.__part_len))
-		target.write(u'| %10.10s | %9.9s |     | %s\n' % (_('Entered'), _('Doc'), _('Narrative')))
+		target.write(u'| %10.10s | %9.9s |     | %s\n' % (_('Happened'), _('Doc'), _('Narrative')))
 		target.write(u'|-%10.10s---%9.9s-------%72.72s\n' % (u'-' * 10, u'-' * 9, u'-' * self.__part_len))
 
 		# get data
@@ -1004,7 +955,8 @@ class cEMRJournalExporter:
 select
 	to_char(vemrj.clin_when, 'YYYY-MM-DD') as date,
 	vemrj.*,
-	(select rank from clin.soap_cat_ranks where soap_cat=vemrj.soap_cat) as scr
+	(select rank from clin.soap_cat_ranks where soap_cat = vemrj.soap_cat) as scr,
+	to_char(vemrj.modified_when, 'YYYY-MM-DD HH24:MI') as date_modified
 from clin.v_emr_journal vemrj
 where pk_patient = %s
 order by date, pk_episode, scr, src_table"""
@@ -1020,7 +972,7 @@ order by date, pk_episode, scr, src_table"""
 				continue
 
 			txt = gmTools.wrap (
-				text = row['narrative'].replace(u'\r', u''),
+				text = row['narrative'].replace(u'\r', u'') + (u' (%s)' % row['date_modified']),
 				width = self.__part_len
 			).split('\n')
 
@@ -1221,6 +1173,27 @@ if __name__ == "__main__":
 
 #============================================================
 # $Log: gmPatientExporter.py,v $
+# Revision 1.134  2009/01/02 11:36:43  ncq
+# - cleanup
+#
+# Revision 1.133  2008/12/18 21:26:45  ncq
+# - missing H in HH24 in date formatting in journal exporter
+#
+# Revision 1.132  2008/12/09 23:24:29  ncq
+# - .date -> .clin_when in doc_med
+#
+# Revision 1.131  2008/12/01 12:36:57  ncq
+# - improved encounter node label
+#
+# Revision 1.130  2008/10/22 12:06:05  ncq
+# - use %x in strftime
+#
+# Revision 1.129  2008/10/12 15:32:18  ncq
+# - support "mod date" in journal
+#
+# Revision 1.128  2008/09/02 18:59:30  ncq
+# - no more fk_patient in clin.health_issue and related changes
+#
 # Revision 1.127  2008/07/28 15:42:30  ncq
 # - cleanup
 # - enhance medistar exporter
