@@ -1,7 +1,7 @@
 #!/bin/bash
 
 # $Source: /sources/gnumed/gnumed/gnumed/client/gm-from-cvs.sh,v $
-# $Revision: 1.13 $
+# $Revision: 1.15 $
 
 # maybe force some locale setting here
 #export LANGUAGE=fr
@@ -25,6 +25,8 @@ fi
 
 
 # run
+PSYCOPG_DEBUG="on"		# should actually be done within gnumed.py based on --debug
 LOG="gm-from-cvs.log"
-python wxpython/gnumed.py --log-file=$LOG --conf-file=gm-from-cvs.conf --override-schema-check --debug --local-import
+python wxpython/gnumed.py --log-file=$LOG --conf-file=gm-from-cvs.conf --override-schema-check --debug --local-import $@
+# --hipaa
 # --profile=gm-from-cvs.prof
