@@ -2,14 +2,14 @@
 __doc__ = """GNUmed general tools."""
 
 #===========================================================================
-# $Id: gmTools.py,v 1.65.2.2 2008/11/20 18:25:26 ncq Exp $
+# $Id: gmTools.py,v 1.75.2.3 2009/04/21 17:04:23 ncq Exp $
 # $Source: /sources/gnumed/gnumed/gnumed/client/pycommon/gmTools.py,v $
-__version__ = "$Revision: 1.65.2.2 $"
+__version__ = "$Revision: 1.75.2.3 $"
 __author__ = "K. Hilbert <Karsten.Hilbert@gmx.net>"
 __license__ = "GPL (details at http://www.gnu.org)"
 
 # std libs
-import datetime as pydt, re as regex, sys, os, os.path, csv, tempfile, logging, codecs, urllib2 as wget
+import datetime as pydt, re as regex, sys, os, os.path, csv, tempfile, logging, codecs, urllib2 as wget, decimal
 
 
 # GNUmed libs
@@ -42,7 +42,9 @@ default_mail_server = u'mail.gmx.net'
 
 
 u_registered_trademark = u'\u00ae'
+u_plus_minus = u'\u00B1'
 u_ellipsis = u'\u2026'
+u_left_arrow = u'\u2190'
 u_diameter = u'\u2300'
 u_checkmark_crossed_out = u'\u237B'
 u_checkmark_thin = u'\u2713'
@@ -65,7 +67,7 @@ def check_for_update(url=None, current_branch=None, current_version=None, consid
 		remote_file = wget.urlopen(url)
 	except (wget.URLError, ValueError, OSError):
 		_log.exception("cannot retrieve version file from [%s]", url)
-		return (None, _('Cannot retrieve version information.'))
+		return (None, _('Cannot retrieve version information from:\n\n%s') % url)
 
 	_log.debug('retrieving version information from [%s]', url)
 
@@ -75,7 +77,7 @@ def check_for_update(url=None, current_branch=None, current_version=None, consid
 	remote_file.close()
 
 	latest_branch = cfg.get('latest branch', 'branch', source_order = [('gm-versions', 'return')])
-	latest_release_on_latest_branch = cfg.get('latest branch', 'latest release', source_order = [('gm-versions', 'return')])
+	latest_release_on_latest_branch = cfg.get('branch %s' % latest_branch, 'latest release', source_order = [('gm-versions', 'return')])
 	latest_release_on_current_branch = cfg.get('branch %s' % current_branch, 'latest release', source_order = [('gm-versions', 'return')])
 
 	_log.info('current release: %s', current_version)
@@ -95,26 +97,33 @@ def check_for_update(url=None, current_branch=None, current_version=None, consid
 		)
 	)
 	if no_release_information_available:
-		msg = _('There is no version information available from:\n\n %s') % url
+		_log.warning('no release information available')
+		msg = _('There is no version information available from:\n\n%s') % url
 		return (None, msg)
 
 	# up to date ?
-	if not consider_latest_branch:
-		if current_version >= latest_release_on_current_branch:
-			return (False, None)
-	else:
+	if consider_latest_branch:
+		_log.debug('latest branch taken into account')
 		if current_version >= latest_release_on_latest_branch:
+			_log.debug('up to date: current version >= latest version on latest branch')
 			return (False, None)
 		if latest_release_on_latest_branch is None:
 			if current_version >= latest_release_on_current_branch:
+				_log.debug('up to date: current version >= latest version on current branch and no latest branch available')
 				return (False, None)
+	else:
+		_log.debug('latest branch not taken into account')
+		if current_version >= latest_release_on_current_branch:
+			_log.debug('up to date: current version >= latest version on current branch')
+			return (False, None)
 
-	current_branch_release_available = (
+	new_release_on_current_branch_available = (
 		(latest_release_on_current_branch is not None) and
 		(latest_release_on_current_branch > current_version)
 	)
+	_log.info('%snew release on current branch available', bool2str(new_release_on_current_branch_available, '', 'no '))
 
-	latest_branch_release_available = (
+	new_release_on_latest_branch_available = (
 		(latest_branch is not None)
 			and
 		(
@@ -124,30 +133,44 @@ def check_for_update(url=None, current_branch=None, current_version=None, consid
 			)
 		)
 	)
+	_log.info('%snew release on latest branch available', bool2str(new_release_on_latest_branch_available, '', 'no '))
 
-	if not (current_branch_release_available or latest_branch_release_available):
+	if not (new_release_on_current_branch_available or new_release_on_latest_branch_available):
+		_log.debug('up to date: no new releases available')
 		return (False, None)
 
 	# not up to date
 	msg = _('A new version of GNUmed is available.\n\n')
-	msg += _(' Your version: "%s"\n') % current_version
+	msg += _(' Your current version: "%s"\n') % current_version
 	if consider_latest_branch:
-		if current_branch_release_available:
-			msg += _(' New version: "%s"\n') % latest_release_on_current_branch
+		if new_release_on_current_branch_available:
+			msg += u'\n'
+			msg += _(' New version: "%s"') % latest_release_on_current_branch
+			msg += u'\n'
 			msg += _(' - bug fixes only\n')
 			msg += _(' - no database upgrade needed\n')
-		if latest_branch_release_available:
-			if latest_release_on_latest_branch != latest_release_on_current_branch:
-				msg += _(' New version: "%s"\n') % latest_release_on_latest_branch
+		if new_release_on_latest_branch_available:
+			if current_branch != latest_branch:
+				msg += u'\n'
+				msg += _(' New version: "%s"') % latest_release_on_latest_branch
+				msg += u'\n'
 				msg += _(' - bug fixes and new features\n')
 				msg += _(' - database upgrade required\n')
 	else:
-		msg += _(' New version: "%s"\n') % latest_release_on_current_branch
+		msg += u'\n'
+		msg += _(' New version: "%s"') % latest_release_on_current_branch
+		msg += u'\n'
 		msg += _(' - bug fixes only\n')
 		msg += _(' - no database upgrade needed\n')
 
-	msg += '\n\n'
-	msg += _('Version information loaded from:\n [%s]') % url
+	msg += u'\n\n'
+	msg += _(
+		'Note, however, that this version may not yet\n'
+		'be available *pre-packaged* for your system.'
+	)
+
+	msg += u'\n\n'
+	msg += _('Version information loaded from:\n\n %s') % url
 
 	return (True, msg)
 #===========================================================================
@@ -199,7 +222,7 @@ class gmPaths(gmBorg.cBorg):
 		else:
 			_log.info('app name passed in as [%s]', app_name)
 
-		self.local_base_dir = os.path.abspath(os.path.join(os.path.dirname(sys.argv[0]), '..'))
+		self.local_base_dir = os.path.abspath(os.path.join(os.path.dirname(sys.argv[0]), '..', '.'))
 		self.working_dir = os.path.abspath(os.curdir)
 
 		try:
@@ -240,16 +263,15 @@ class gmPaths(gmBorg.cBorg):
 		except ValueError:
 			pass
 
-		try:
-			# Robin attests that the following doesn't give
-			# sane values on Windows, so IFDEF it
-			if 'wxMSW' in wx.PlatformInfo:
-				_log.warning('this platform (wxMSW) returns a broken value for the system-wide application data dir')
-				self.system_app_data_dir = self.local_base_dir
-			else:
+		# Robin attests that the following gives existing
+		# but faulty paths on Windows, so IFDEF it
+		if 'wxMSW' in wx.PlatformInfo:
+			_log.warning('this platform (wxMSW) returns a broken value for the system-wide application data dir')
+		else:
+			try:
 				self.system_app_data_dir = std_paths.GetDataDir()
-		except ValueError:
-			pass
+			except ValueError:
+				pass
 
 		self.__log_paths()
 		return True
@@ -351,13 +373,22 @@ def mkdir(directory=None):
 			raise
 	return True
 #---------------------------------------------------------------------------
-def get_unique_filename(prefix=None, suffix=None, dir=None):
+def get_unique_filename(prefix=None, suffix=None, tmp_dir=None):
 	"""This introduces a race condition between the file.close() and
 	actually using the filename.
 
 	The file will not exist after calling this function.
 	"""
-	kwargs = {'dir': dir}
+	if tmp_dir is not None:
+		if (
+			not os.access(tmp_dir, os.F_OK)
+				or
+			not os.access(tmp_dir, os.X_OK | os.W_OK)
+		):
+			_log.info('cannot use temporary dir [%s]', tmp_dir)
+			tmp_dir = None
+
+	kwargs = {'dir': tmp_dir}
 
 	if prefix is None:
 		kwargs['prefix'] = 'gnumed-'
@@ -392,13 +423,12 @@ def import_module_from_directory(module_path=None, module_name=None):
 
 	try:
 		module = __import__(module_name)
-		_log.info('imported module [%s] as [%s]' % (module_name, module))
 	except StandardError:
 		_log.exception('cannot __import__() module [%s] from [%s]' % (module_name, module_path))
-		if remove_path:
-			sys.path.remove(module_path)
+		sys.path.remove(module_path)
 		raise
 
+	_log.info('imported module [%s] as [%s]' % (module_name, module))
 	if remove_path:
 		sys.path.remove(module_path)
 
@@ -621,6 +651,28 @@ def capitalize(text=None, mode=CAPS_NAMES):
 	print "ERROR: invalid capitalization mode: [%s], leaving input as is" % mode
 	return text
 #---------------------------------------------------------------------------
+def input2decimal(initial=None):
+
+	val = initial
+
+	# float ? -> to string first
+	if type(val) == type(1.4):
+		val = str(val)
+
+	# string ? -> "," to "."
+	if isinstance(val, basestring):
+		val = val.replace(',', '.', 1)
+		val = val.strip()
+#		val = val.lstrip('0')
+#		if val.startswith('.'):
+#			val = '0' + val
+
+	try:
+		d = decimal.Decimal(val)
+		return True, d
+	except (TypeError, decimal.InvalidOperation):
+		return False, val
+#---------------------------------------------------------------------------
 def wrap(text=None, width=None, initial_indent=u'', subsequent_indent=u'', eol=u'\n'):
 	"""A word-wrap function that preserves existing line breaks
 	and most spaces in the text. Expects that existing line
@@ -648,6 +700,62 @@ def wrap(text=None, width=None, initial_indent=u'', subsequent_indent=u'', eol=u
 if __name__ == '__main__':
 
 	#-----------------------------------------------------------------------
+	def test_input2decimal():
+
+		tests = [
+			[None, False],
+
+			['', False],
+			[' 0 ', True, 0],
+
+			[0, True, 0],
+			[0.0, True, 0],
+			[.0, True, 0],
+			['0', True, 0],
+			['0.0', True, 0],
+			['0,0', True, 0],
+			['00.0', True, 0],
+			['.0', True, 0],
+			[',0', True, 0],
+
+			[0.1, True, decimal.Decimal('0.1')],
+			[.01, True, decimal.Decimal('0.01')],
+			['0.1', True, decimal.Decimal('0.1')],
+			['0,1', True, decimal.Decimal('0.1')],
+			['00.1', True, decimal.Decimal('0.1')],
+			['.1', True, decimal.Decimal('0.1')],
+			[',1', True, decimal.Decimal('0.1')],
+
+			[1, True, 1],
+			[1.0, True, 1],
+			['1', True, 1],
+			['1.', True, 1],
+			['1,', True, 1],
+			['1.0', True, 1],
+			['1,0', True, 1],
+			['01.0', True, 1],
+			['01,0', True, 1],
+			[' 01, ', True, 1],
+		]
+		for test in tests:
+			conversion_worked, result = input2decimal(initial = test[0])
+
+			expected2work = test[1]
+
+			if conversion_worked:
+				if expected2work:
+					if result == test[2]:
+						continue
+					else:
+						print "ERROR (conversion result wrong): >%s<, expected >%s<, got >%s<" % (test[0], test[2], result)
+				else:
+					print "ERROR (conversion worked but was expected to fail): >%s<, got >%s<" % (test[0], result)
+			else:
+				if not expected2work:
+					continue
+				else:
+					print "ERROR (conversion failed but was expected to work): >%s<, expected >%s<" % (test[0], test[2])
+	#-----------------------------------------------------------------------
 	def test_str2interval():
 		print "testing str2interval()"
 		print "----------------------"
@@ -821,7 +929,7 @@ This is a test mail from the gmTools.py module.
 		print get_unique_filename(prefix='test-')
 		print get_unique_filename(suffix='tst')
 		print get_unique_filename(prefix='test-', suffix='tst')
-		print get_unique_filename(dir='/home/ncq/Archiv/')
+		print get_unique_filename(tmp_dir='/home/ncq/Archiv/')
 	#-----------------------------------------------------------------------
 	def test_size2str():
 		print "testing size2str()"
@@ -885,7 +993,7 @@ This is a test mail from the gmTools.py module.
 
 		#test_check_for_update()
 		#test_str2interval()
-		test_coalesce()
+		#test_coalesce()
 		#test_capitalize()
 		#test_import_module()
 		#test_mkdir()
@@ -897,14 +1005,52 @@ This is a test mail from the gmTools.py module.
 		#test_get_unique_filename()
 		#test_size2str()
 		#test_wrap()
+		test_input2decimal()
 
 #===========================================================================
 # $Log: gmTools.py,v $
-# Revision 1.65.2.2  2008/11/20 18:25:26  ncq
-# - do not announce new version twice
+# Revision 1.75.2.3  2009/04/21 17:04:23  ncq
+# - fix setting sys app data dir on non-Windows
 #
-# Revision 1.65.2.1  2008/10/28 13:58:18  ncq
-# - fix logic reversal when detecting new client version
+# Revision 1.75.2.2  2009/04/20 12:04:13  ncq
+# - back to previous behaviour for app data dir on Windows
+#
+# Revision 1.75.2.1  2009/03/24 10:31:24  ncq
+# - improved app data dir on Windows
+#
+# Revision 1.75  2009/03/01 18:10:50  ncq
+# - improve update-avail message
+#
+# Revision 1.74  2009/02/18 13:45:25  ncq
+# - get_unique_filename API change
+#
+# Revision 1.73  2009/01/02 11:38:09  ncq
+# - input2decimal + tests
+#
+# Revision 1.72  2008/12/22 18:58:53  ncq
+# - cleanup
+#
+# Revision 1.71  2008/12/09 23:28:15  ncq
+# - better logging
+# - always remove aux module path if importing fails
+#
+# Revision 1.70  2008/11/20 18:47:40  ncq
+# - add left arrow unicode
+# - fix logging in update check
+#
+# Revision 1.69  2008/11/03 10:28:55  ncq
+# - check_for_update
+#   - improved logging and wording
+#   - logic reversal fix
+#
+# Revision 1.68  2008/10/12 15:48:33  ncq
+# - improved wording when checking for updates
+#
+# Revision 1.67  2008/08/31 16:13:15  ncq
+# - cleanup
+#
+# Revision 1.66  2008/08/28 18:32:24  ncq
+# - read latest branch then latest release from branch group
 #
 # Revision 1.65  2008/08/20 13:53:57  ncq
 # - add some coalesce tests
