@@ -5,8 +5,8 @@ functions for authenticating users.
 """
 #================================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gmAuthWidgets.py,v $
-# $Id: gmAuthWidgets.py,v 1.25.2.3 2008/11/07 11:08:06 ncq Exp $
-__version__ = "$Revision: 1.25.2.3 $"
+# $Id: gmAuthWidgets.py,v 1.35 2009/02/05 13:03:08 ncq Exp $
+__version__ = "$Revision: 1.35 $"
 __author__ = "karsten.hilbert@gmx.net, H.Herb, H.Berger, R.Terry"
 __license__ = "GPL (details at http://www.gnu.org)"
 
@@ -32,10 +32,14 @@ _log.info(__version__)
 _cfg = gmCfg2.gmCfgData()
 
 try:
-	_('do-not-translate-but-make-epydoc-happy')
+	_('dummy-no-need-to-translate-but-make-epydoc-happy')
 except NameError:
 	_ = lambda x:x
 
+
+current_db_name = 'gnumed_v10'
+
+
 msg_generic = _("""
 GNUmed database version mismatch.
 
@@ -94,11 +98,10 @@ There may be schema related errors. Please report and/or
 fix them. Do not rely on this database to work properly
 in all cases !""")
 
-current_db_name = 'gnumed_v9'
 #================================================================
 # convenience functions
 #----------------------------------------------------------------
-def connect_to_database(max_attempts=3, expected_version=None, require_version=True, client_version=u'*** unknown ***'):
+def connect_to_database(max_attempts=3, expected_version=None, require_version=True):
 	"""Display the login dialog and try to log into the backend.
 
 	- up to max_attempts times
@@ -106,6 +109,7 @@ def connect_to_database(max_attempts=3, expected_version=None, require_version=T
 	"""
 	# force programmer to set a valid expected_version
 	expected_hash = gmPG2.known_schema_hashes[expected_version]
+	client_version = _cfg.get(option = u'client_version')
 
 	attempt = 0
 
@@ -114,6 +118,8 @@ def connect_to_database(max_attempts=3, expected_version=None, require_version=T
 
 	while attempt < max_attempts:
 
+		_log.debug('login attempt %s of %s', (attempt+1), max_attempts)
+
 		connected = False
 
 		dlg.ShowModal()
@@ -135,7 +141,7 @@ def connect_to_database(max_attempts=3, expected_version=None, require_version=T
 			connected = True
 		except gmPG2.cAuthenticationError, e:
 			attempt += 1
-			_log.error(u"login attempt %s/%s failed: %s", attempt, max_attempts, e)
+			_log.error(u"login attempt failed: %s", e)
 			if attempt < max_attempts:
 				gmGuiHelpers.gm_show_error (_(
 					"Unable to connect to database:\n\n"
@@ -147,17 +153,17 @@ def connect_to_database(max_attempts=3, expected_version=None, require_version=T
 				)
 			continue
 		except gmPG2.dbapi.OperationalError, e:
-			_log.error(u"login attempt %s/%s failed: %s", attempt+1, max_attempts, e)
+			_log.error(u"login attempt failed: %s", e)
 			gmGuiHelpers.gm_show_error (_(
-				"Unable to connect to database:\n\n"
-				"%s\n\n"
-				"Please retry with another profile !\n"
-				) % e,
+					"Unable to connect to database:\n\n"
+					"%s\n\n"
+					"Please retry with another profile !\n"
+				) % gmPG2.extract_msg_from_pg_exception(e),
 				_('Connecting to backend')
 			)
 			continue
 
-		# connect was successful:
+		# connect was successful
 		gmPG2.set_default_login(login = login)
 		gmPG2.set_default_client_encoding(encoding = dlg.panel.backend_profile.encoding)
 
@@ -460,6 +466,7 @@ class cLoginPanel(wx.Panel):
 			),
 			['any-doc']
 		)
+		# FIXME: make unique
 
 		return accounts
 	#----------------------------------------------------
@@ -473,6 +480,7 @@ class cLoginPanel(wx.Panel):
 		as a profile in the system file will override the
 		system file.
 		"""
+		# find active profiles
 		src_order = [
 			(u'explicit', u'extend'),
 			(u'system', u'extend'),
@@ -484,7 +492,9 @@ class cLoginPanel(wx.Panel):
 			_cfg.get(group = u'backend', option = u'profiles', source_order = src_order),
 			[]
 		)
+		# FIXME: make unique
 
+		# find data for active profiles
 		src_order = [
 			(u'explicit', u'return'),
 			(u'workbase', u'return'),
@@ -496,9 +506,11 @@ class cLoginPanel(wx.Panel):
 
 		for profile_name in profile_names:
 			# FIXME: once the profile has been found always use the corresponding source !
+			# FIXME: maybe not or else we cannot override parts of the profile
 			profile = cBackendProfile()
-			profile.name = profile_name
 			profile_section = 'profile %s' % profile_name
+
+			profile.name = profile_name
 			profile.host = gmTools.coalesce(_cfg.get(profile_section, u'host', src_order), u'').strip()
 			port = gmTools.coalesce(_cfg.get(profile_section, u'port', src_order), 5432)
 			try:
@@ -515,7 +527,9 @@ class cLoginPanel(wx.Panel):
 			profile.encoding = gmTools.coalesce(_cfg.get(profile_section, u'encoding', src_order), u'UTF8')
 			profile.public_db = bool(_cfg.get(profile_section, u'public/open access', src_order))
 			profile.helpdesk = _cfg.get(profile_section, u'help desk', src_order)
-			profiles[profile_name] = profile
+
+			label = u'%s (%s@%s)' % (profile_name, profile.database, profile.host)
+			profiles[label] = profile
 
 		if len(profiles) == 0:
 			host = u'salaam.homeunix.com'
@@ -534,7 +548,6 @@ class cLoginPanel(wx.Panel):
 
 		src_order = [
 			(u'explicit', u'return'),
-			(u'workbase', u'return'),
 			(u'user', u'return'),
 		]
 
@@ -545,11 +558,11 @@ class cLoginPanel(wx.Panel):
 			)
 		)
 
-		prefs_profile = _cfg.get(u'preferences', u'profile', src_order)
-		try:
-			self._CBOX_profile.SetValue(self.__backend_profiles[prefs_profile].name)
-		except KeyError:
-			self._CBOX_profile.SetValue(self.__backend_profiles[self.__backend_profiles.keys()[0]].name)
+		last_used_profile_label = _cfg.get(u'preferences', u'profile', src_order)
+		if last_used_profile_label in self.__backend_profiles.keys():
+			self._CBOX_profile.SetValue(last_used_profile_label)
+		else:
+			self._CBOX_profile.SetValue(self.__backend_profiles.keys()[0])
 
 		self._CHBOX_debug.SetValue(_cfg.get(option = 'debug'))
 		self._CHBOX_slave.SetValue(_cfg.get(option = 'slave'))
@@ -557,7 +570,7 @@ class cLoginPanel(wx.Panel):
 	def save_state(self):
 		"""Save parameter settings to standard configuration file"""
 		prefs_name = _cfg.get(option = 'user_preferences_file')
-		_log.debug(u'saving login choices in [%s]', prefs_name)
+		_log.debug(u'saving login preferences in [%s]', prefs_name)
 
 		gmCfg2.set_option_in_INI_file (
 			filename = prefs_name,
@@ -579,7 +592,18 @@ class cLoginPanel(wx.Panel):
 		"""convenience function for compatibility with gmLoginInfo.LoginInfo"""
 		if not self.cancelled:
 			# FIXME: do not assume conf file is latin1 !
-			profile = self.__backend_profiles[self._CBOX_profile.GetValue().encode('latin1').strip()]
+			#profile = self.__backend_profiles[self._CBOX_profile.GetValue().encode('latin1').strip()]
+			profile = self.__backend_profiles[self._CBOX_profile.GetValue().encode('utf8').strip()]
+			_log.debug(u'backend profile "%s" selected', profile.name)
+			_log.debug(u' details: <%s> on %s@%s:%s (%s, %s)',
+				self._CBOX_user.GetValue(),
+				profile.database,
+				profile.host,
+				profile.port,
+				profile.encoding,
+				gmTools.bool2subst(profile.public_db, u'public', u'private')
+			)
+			_log.debug(u' helpdesk: "%s"', profile.helpdesk)
 			login = gmLoginInfo.LoginInfo (
 				user = self._CBOX_user.GetValue(),
 				password = self.pwdentry.GetValue(),
@@ -684,14 +708,37 @@ if __name__ == "__main__":
 
 #================================================================
 # $Log: gmAuthWidgets.py,v $
-# Revision 1.25.2.3  2008/11/07 11:08:06  ncq
-# - need to set help desk on default profile, too
+# Revision 1.35  2009/02/05 13:03:08  ncq
+# - cleanup
 #
-# Revision 1.25.2.2  2008/09/09 17:26:21  ncq
-# - default to any-doc for previously used accounts
+# Revision 1.34  2009/01/15 11:35:41  ncq
+# - cleanup
 #
-# Revision 1.25.2.1  2008/08/31 22:15:48  ncq
-# - properly set src_order and return policy on retrieving backend profile data
+# Revision 1.33  2008/12/25 17:46:09  ncq
+# - better logging
+# - work around PG unknown initial encoding problem
+#
+# Revision 1.32  2008/11/20 18:48:15  ncq
+# - add default help desk to builtin default backend profile
+#
+# Revision 1.31  2008/10/22 12:13:09  ncq
+# - bump db version
+#
+# Revision 1.30  2008/10/12 16:06:07  ncq
+# - make profile label show db@host
+# - log profile used
+#
+# Revision 1.29  2008/09/09 20:18:51  ncq
+# - default to any-doc if no previous logins found
+#
+# Revision 1.28  2008/08/31 16:47:48  ncq
+# - proper policy when retrieving previous logins
+#
+# Revision 1.27  2008/08/31 16:34:12  ncq
+# - properly set src_order and policy when retrieving profile *data*
+#
+# Revision 1.26  2008/08/31 16:15:02  ncq
+# - use "extend" policy when retrieving backend profiles
 #
 # Revision 1.25  2008/07/30 12:50:34  ncq
 # - cleanup
