@@ -2,8 +2,8 @@
 """
 #================================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gmEMRBrowser.py,v $
-# $Id: gmEMRBrowser.py,v 1.93.2.2 2008/10/12 17:02:59 ncq Exp $
-__version__ = "$Revision: 1.93.2.2 $"
+# $Id: gmEMRBrowser.py,v 1.100.2.1 2009/04/20 12:05:03 ncq Exp $
+__version__ = "$Revision: 1.100.2.1 $"
 __author__ = "cfmoro1976@yahoo.es, sjtan@swiftdsl.com.au, Karsten.Hilbert@gmx.net"
 __license__ = "GPL"
 
@@ -94,6 +94,8 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 		self.__curr_node = None
 		self.__exporter = gmPatientExporter.cEmrExport(patient = self.__pat)
 
+		self._old_cursor_pos = None
+
 		self.__make_popup_menus()
 		self.__register_events()
 	#--------------------------------------------------------
@@ -119,6 +121,10 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 		wx.EVT_TREE_SEL_CHANGED (self, self.GetId(), self._on_tree_item_selected)
 		wx.EVT_TREE_ITEM_RIGHT_CLICK (self, self.GetId(), self._on_tree_item_right_clicked)
 
+		# handle tooltips
+#		wx.EVT_MOTION(self, self._on_mouse_motion)
+		wx.EVT_TREE_ITEM_GETTOOLTIP(self, -1, self._on_tree_item_gettooltip)
+
 		gmDispatcher.connect(signal = 'narrative_mod_db', receiver = self._on_narrative_mod_db)
 		gmDispatcher.connect(signal = 'episode_mod_db', receiver = self._on_episode_mod_db)
 		gmDispatcher.connect(signal = 'health_issue_mod_db', receiver = self._on_issue_mod_db)
@@ -140,10 +146,10 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 
 		# have the tree filled by the exporter
 		self.__exporter.get_historical_tree(self)
+		self.__curr_node = root_item
 
 		self.SelectItem(root_item)
 		self.Expand(root_item)
-		self.__curr_node = root_item
 		self.__update_text_for_selected_node()
 
 		self.restore_expansion()
@@ -165,7 +171,7 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 		# update displayed text
 		if isinstance(node_data, (gmEMRStructItems.cHealthIssue, types.DictType)):
 			# FIXME: turn into real dummy issue
-			if node_data['pk'] is None:
+			if node_data['pk_health_issue'] is None:
 				txt = _('Pool of unassociated episodes:\n\n  "%s"') % node_data['description']
 			else:
 				txt = node_data.format(left_margin=1, patient = self.__pat)
@@ -175,7 +181,7 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 
 		elif isinstance(node_data, gmEMRStructItems.cEncounter):
 			epi = self.GetPyData(self.GetItemParent(self.__curr_node))
-			txt = node_data.format(episode = epi, with_soap = True, left_margin = 1, patient = self.__pat)
+			txt = node_data.format(episodes = [epi['pk_episode']], with_soap = True, left_margin = 1, patient = self.__pat)
 
 		else:
 			emr = self.__pat.get_emr()
@@ -207,7 +213,10 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 		# - edit encounter details
 		menu_id = wx.NewId()
 		self.__enc_context_popup.AppendItem(wx.MenuItem(self.__enc_context_popup, menu_id, _('Edit details')))
-		wx.EVT_MENU(self.__enc_context_popup, menu_id, self.__edit_consultation_details)
+		wx.EVT_MENU(self.__enc_context_popup, menu_id, self.__edit_encounter_details)
+
+		item = self.__enc_context_popup.Append(-1, _('Edit progress notes'))
+		self.Bind(wx.EVT_MENU, self.__edit_progress_notes, item)
 
 		item = self.__enc_context_popup.Append(-1, _('Export for Medistar'))
 		self.Bind(wx.EVT_MENU, self.__export_encounter_for_medistar, item)
@@ -304,7 +313,14 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 			gmDispatcher.send(signal = 'statustext', msg = _('Cannot delete episode. There is still clinical data recorded for it.'))
 			return
 	#--------------------------------------------------------
-	def __edit_consultation_details(self, event):
+	def __edit_progress_notes(self, event):
+		encounter = self.GetPyData(self.__curr_node)
+		node_parent = self.GetItemParent(self.__curr_node)
+		owning_episode = self.GetPyData(node_parent)
+
+		gmNarrativeWidgets.edit_progress_notes(parent = self, encounters = [encounter['pk_encounter']], episodes = [owning_episode['pk_episode']])
+	#--------------------------------------------------------
+	def __edit_encounter_details(self, event):
 		node_data = self.GetPyData(self.__curr_node)
 		dlg = gmEMRStructWidgets.cEncounterEditAreaDlg(parent=self, encounter=node_data)
 		dlg.ShowModal()
@@ -465,6 +481,64 @@ class cEMRTree(wx.TreeCtrl, gmGuiHelpers.cTreeExpansionHistoryMixin):
 		self.__curr_node = sel_item
 		self.__update_text_for_selected_node()
 		return True
+#	#--------------------------------------------------------
+#	def _on_mouse_motion(self, event):
+#
+#		cursor_pos = (event.GetX(), event.GetY())
+#
+#		self.SetToolTipString(u'')
+#
+#		if cursor_pos != self._old_cursor_pos:
+#			self._old_cursor_pos = cursor_pos
+#			(item, flags) = self.HitTest(cursor_pos)
+#			#if flags != wx.TREE_HITTEST_NOWHERE:
+#			if flags == wx.TREE_HITTEST_ONITEMLABEL:
+#				data = self.GetPyData(item)
+#
+#				if not isinstance(data, gmEMRStructItems.cEncounter):
+#					return
+#
+#				self.SetToolTip(u'%s  %s  %s - %s\n\nRFE: %s\nAOE: %s' % (
+#					data['started'].strftime('%x'),
+#					data['l10n_type'],
+#					data['started'].strftime('%H:%m'),
+#					data['last_affirmed'].strftime('%H:%m'),
+#					gmTools.coalesce(data['reason_for_encounter'], u''),
+#					gmTools.coalesce(data['assessment_of_encounter'], u'')
+#				))
+	#--------------------------------------------------------
+	def _on_tree_item_gettooltip(self, event):
+
+		item = event.GetItem()
+
+		if not item.IsOk():
+			event.SetToolTip(u' ')
+			return
+
+		data = self.GetPyData(item)
+
+		if isinstance(data, gmEMRStructItems.cEncounter):
+			event.SetToolTip(u'%s  %s  %s - %s\n\nRFE: %s\nAOE: %s' % (
+				data['started'].strftime('%x'),
+				data['l10n_type'],
+				data['started'].strftime('%H:%M'),
+				data['last_affirmed'].strftime('%H:%M'),
+				gmTools.coalesce(data['reason_for_encounter'], u''),
+				gmTools.coalesce(data['assessment_of_encounter'], u'')
+			))
+		else:
+			event.SetToolTip(u' ')
+			#self.SetToolTipString(u'')
+
+		# doing this prevents the tooltip from showing at all
+		#event.Skip()
+
+#widgetXY.GetToolTip().Enable(False)
+#
+#seems to work, supposing the tooltip is actually set for the widget,
+#otherwise a test would be needed
+#if widgetXY.GetToolTip():
+#    widgetXY.GetToolTip().Enable(False)
 	#--------------------------------------------------------
 	def _on_tree_item_right_clicked(self, event):
 		"""Right button clicked: display the popup for the tree"""
@@ -672,11 +746,32 @@ if __name__ == '__main__':
 
 #================================================================
 # $Log: gmEMRBrowser.py,v $
-# Revision 1.93.2.2  2008/10/12 17:02:59  ncq
-# - wording of EMR browser root node as per Jim
+# Revision 1.100.2.1  2009/04/20 12:05:03  ncq
+# - properly format encounter timeframe
 #
-# Revision 1.93.2.1  2008/08/31 22:17:01  ncq
-# - don't crash on getting narrative change signal before tree has been populated
+# Revision 1.100  2009/01/21 18:03:53  ncq
+# - comment on tooltip handling
+#
+# Revision 1.99  2008/12/18 21:27:56  ncq
+# - add editing progress notes from encounter context menu
+#
+# Revision 1.98  2008/12/01 12:37:37  ncq
+# - generate encounter node tooltips
+#
+# Revision 1.97  2008/11/20 19:50:19  ncq
+# - use improved data formatting
+#
+# Revision 1.96  2008/10/12 16:13:23  ncq
+# - rename EMR tree root node, per Jim
+#
+# Revision 1.95  2008/09/02 19:01:11  ncq
+# - adjust to clin health_issue fk_patient drop and related changes
+#
+# Revision 1.94  2008/08/31 18:39:47  ncq
+# - if narrative is added, say a test result with comment, before
+#   the tree was ever displayed (hence not populated) for that patient
+#   there is not yet a currently selected node, so don't update
+#   the narrative display either
 #
 # Revision 1.93  2008/08/15 15:56:38  ncq
 # - properly handle context click on pseudo-issue
