@@ -8,8 +8,8 @@
 """
 #================================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gmEMRStructWidgets.py,v $
-# $Id: gmEMRStructWidgets.py,v 1.79.2.1 2008/10/15 14:45:07 ncq Exp $
-__version__ = "$Revision: 1.79.2.1 $"
+# $Id: gmEMRStructWidgets.py,v 1.84.2.1 2009/04/20 12:05:37 ncq Exp $
+__version__ = "$Revision: 1.84.2.1 $"
 __author__ = "cfmoro1976@yahoo.es, karsten.hilbert@gmx.net"
 __license__ = "GPL"
 
@@ -39,7 +39,21 @@ _log.info(__version__)
 #================================================================
 # encounter related widgets/functions
 #----------------------------------------------------------------
-def ask_for_encounter_continuation(msg=None, caption=None):
+def ask_for_encounter_continuation(msg=None, caption=None, encounter=None, parent=None):
+
+	if parent is None:
+		parent = wx.GetApp().GetTopWindow()
+
+#	dlg = cEncounterEditAreaDlg (
+#		parent = parent,
+#		encounter = encounter,
+#		button_defs = [
+#			[_('Continue'), _('Continue this encounter saving any changes.')],
+#			[_('Start new'), _('Start a new encounter. The one shown here will be closed.')]
+#		],
+#		msg = msg
+#	)
+
 	dlg = gmGuiHelpers.c2ButtonQuestionDlg (
 		parent = None,
 		id = -1,
@@ -51,9 +65,14 @@ def ask_for_encounter_continuation(msg=None, caption=None):
 		],
 		show_checkbox = False
 	)
+
 	result = dlg.ShowModal()
+	dlg.Destroy()
+
 	if result == wx.ID_YES:
+#	if result == wx.ID_OK:
 		return True
+
 	return False
 #----------------------------------------------------------------
 def manage_encounter_types(parent=None):
@@ -243,39 +262,33 @@ class cEncounterEditAreaPnl(wxgEncounterEditAreaPnl.wxgEncounterEditAreaPnl):
 		except KeyError:
 			self.__encounter = None
 
+		try:
+			msg = kwargs['msg']
+			del kwargs['msg']
+		except KeyError:
+			msg = None
+
 		wxgEncounterEditAreaPnl.wxgEncounterEditAreaPnl.__init__(self, *args, **kwargs)
 
-		self.__init_ui()
-		if self.__encounter is not None:
-			self.refresh()
-	#--------------------------------------------------------
-	def __init_ui(self):
-		self._LCTRL_problems.InsertColumn(0, _('Episode'))
-#		self._LCTRL_problems.InsertColumn(1, _('Foundational Issue'))
-#		self._LCTRL_problems.InsertColumn(2, _('Assessment'))
-		self._LCTRL_problems.InsertColumn(3, _('Narrative'))
+		self.refresh(msg = msg)
 	#--------------------------------------------------------
 	# external API
 	#--------------------------------------------------------
-	def refresh(self, encounter = None):
+	def refresh(self, encounter=None, msg=None):
+
+		if msg is not None:
+			self._LBL_instructions.SetLabel(msg)
 
 		if encounter is not None:
 			self.__encounter = encounter
 
+		if self.__encounter is None:
+			return True
+
 		# getting the patient via the encounter allows us to act
 		# on any encounter regardless of the currently active patient
 		pat = gmPerson.cPatient(aPK_obj = self.__encounter['pk_patient'])
-		emr = pat.get_emr()
-		episodes = emr.get_episodes_by_encounter(pk_encounter = self.__encounter['pk_encounter'])
-		pos = len(episodes) + 1
-
-		self._LCTRL_problems.DeleteAllItems()
-		for episode in episodes:
-			row_num = self._LCTRL_problems.InsertStringItem(pos, label = episode['description'])
-#			self._LCTRL_problems.SetStringItem(index = row_num, col = 1, label = gmTools.coalesce(episode['health_issue'], ''))
-		if len(episodes) > 0:
-			self._LCTRL_problems.SetColumnWidth(col=0, width=wx.LIST_AUTOSIZE)
-#			self._LCTRL_problems.SetColumnWidth(col=1, width=wx.LIST_AUTOSIZE)		# wx.LIST_AUTOSIZE_USEHEADER
+		self._LBL_patient.SetLabel(pat.get_description_gender())
 
 		self._PRW_encounter_type.SetText(self.__encounter['l10n_type'], data=self.__encounter['pk_type'])
 
@@ -299,8 +312,6 @@ class cEncounterEditAreaPnl(wxgEncounterEditAreaPnl.wxgEncounterEditAreaPnl):
 		else:
 			self._TCTRL_aoe.SetFocus()
 
-		self._TCTRL_patient.SetLabel(pat.get_description())
-
 		return True
 	#--------------------------------------------------------
 	def __is_valid_for_save(self):
@@ -330,13 +341,8 @@ class cEncounterEditAreaPnl(wxgEncounterEditAreaPnl.wxgEncounterEditAreaPnl):
 		self.__encounter['pk_type'] = self._PRW_encounter_type.GetData()
 		self.__encounter['started'] = self._PRW_start.GetData().get_pydt()
 		self.__encounter['last_affirmed'] = self._PRW_end.GetData().get_pydt()
-		rfe = self._TCTRL_rfe.GetValue().strip()
-		if len(rfe) != 0:
-			self.__encounter['reason_for_encounter'] = rfe
-		aoe = self._TCTRL_aoe.GetValue().strip()
-		if len(aoe) != 0:
-			self.__encounter['assessment_of_encounter'] = aoe
-
+		self.__encounter['reason_for_encounter'] = gmTools.none_if(self._TCTRL_rfe.GetValue().strip(), u'')
+		self.__encounter['assessment_of_encounter'] = gmTools.none_if(self._TCTRL_aoe.GetValue().strip(), u'')
 		self.__encounter.save_payload()			# FIXME: error checking
 
 		return True
@@ -347,9 +353,28 @@ class cEncounterEditAreaDlg(wxgEncounterEditAreaDlg.wxgEncounterEditAreaDlg):
 		encounter = kwargs['encounter']
 		del kwargs['encounter']
 
+		try:
+			button_defs = kwargs['button_defs']
+			del kwargs['button_defs']
+		except KeyError:
+			button_defs = None
+
+		try:
+			msg = kwargs['msg']
+			del kwargs['msg']
+		except KeyError:
+			msg = None
+
 		wxgEncounterEditAreaDlg.wxgEncounterEditAreaDlg.__init__(self, *args, **kwargs)
 
-		self._PNL_edit_area.refresh(encounter=encounter)
+		if button_defs is not None:
+			self._BTN_save.SetLabel(button_defs[0][0])
+			self._BTN_save.SetToolTipString(button_defs[0][1])
+			self._BTN_close.SetLabel(button_defs[1][0])
+			self._BTN_close.SetToolTipString(button_defs[1][1])
+			self.Refresh()
+
+		self._PNL_edit_area.refresh(encounter = encounter, msg = msg)
 
 		self.Fit()
 	#--------------------------------------------------------
@@ -372,7 +397,7 @@ def move_episode_to_issue(episode=None, target_issue=None, save_to_backend=False
 	"""
 	# episode is closed: should always work
 	if not episode['episode_open']:
-		episode['pk_health_issue'] = target_issue['pk']
+		episode['pk_health_issue'] = target_issue['pk_health_issue']
 		if save_to_backend:
 			episode.save_payload()
 		return True
@@ -398,14 +423,14 @@ def move_episode_to_issue(episode=None, target_issue=None, save_to_backend=False
 
 	# no more open episode on target issue: should work now
 	if existing_epi is None:
-		episode['pk_health_issue'] = target_issue['pk']
+		episode['pk_health_issue'] = target_issue['pk_health_issue']
 		if save_to_backend:
 			episode.save_payload()
 		return True
 
 	# don't conflict on SELF ;-)
 	if existing_epi['pk_episode'] == episode['pk_episode']:
-		episode['pk_health_issue'] = target_issue['pk']
+		episode['pk_health_issue'] = target_issue['pk_health_issue']
 		if save_to_backend:
 			episode.save_payload()
 		return True
@@ -416,13 +441,13 @@ def move_episode_to_issue(episode=None, target_issue=None, save_to_backend=False
 	question = _(
 		'You want to associate the running episode:\n\n'
 		' "%(new_epi_name)s" (%(new_epi_start)s - %(new_epi_end)s)\n\n'
-		'with the foundational health issue:\n\n'
+		'with the health issue:\n\n'
 		' "%(issue_name)s"\n\n'
 		'There already is another episode running\n'
-		'for this foundational isssue:\n\n'
+		'for this health issue:\n\n'
 		' "%(old_epi_name)s" (%(old_epi_start)s - %(old_epi_end)s)\n\n'
 		'However, there can only be one running\n'
-		'episode per foundational health issue.\n\n'
+		'episode per health issue.\n\n'
 		'Which episode do you want to close ?'
 	) % {
 		'new_epi_name': episode['description'],
@@ -461,7 +486,7 @@ def move_episode_to_issue(episode=None, target_issue=None, save_to_backend=False
 	else:
 		raise ValueError('invalid result from c3ButtonQuestionDlg: [%s]' % decision)
 
-	episode['pk_health_issue'] = target_issue['pk']
+	episode['pk_health_issue'] = target_issue['pk_health_issue']
 	if save_to_backend:
 		episode.save_payload()
 	return True
@@ -661,7 +686,7 @@ class cEpisodeEditAreaPnl(wxgEpisodeEditAreaPnl.wxgEpisodeEditAreaPnl):
 			return
 
 		ident = gmPerson.cIdentity(aPK_obj = self.__episode['pk_patient'])
-		self._TCTRL_patient.SetValue(ident.get_description())
+		self._TCTRL_patient.SetValue(ident.get_description_gender())
 
 		if self.__episode['pk_health_issue'] is not None:
 			self._PRW_issue.SetText(self.__episode['health_issue'], data=self.__episode['pk_health_issue'])
@@ -718,7 +743,7 @@ class cEpisodeEditAreaDlg(wxgEpisodeEditAreaDlg.wxgEpisodeEditAreaDlg):
 	def _on_clear_button_pressed(self, evt):
 		self._PNL_edit_area.refresh()
 #================================================================
-# foundational issue related widgets/functions
+# health issue related widgets/functions
 #----------------------------------------------------------------
 class cIssueListSelectorDlg(gmListWidgets.cGenericListSelectorDlg):
 
@@ -769,13 +794,13 @@ class cIssueSelectionPhraseWheel(gmPhraseWheel.cPhraseWheel):
 	"""
 	def __init__(self, *args, **kwargs):
 
-		ctxt = {'ctxt_pat': {'where_part': u'fk_patient=%(pat)s', 'placeholder': u'pat'}}
+		ctxt = {'ctxt_pat': {'where_part': u'pk_patient=%(pat)s', 'placeholder': u'pat'}}
 
 		mp = gmMatchProvider.cMatchProvider_SQL2 (
 			# FIXME: consider clin.health_issue.clinically_relevant
 			queries = [u"""
-(select pk, description, 1
-	from clin.health_issue where
+(select pk_health_issue, description, 1
+	from clin.v_health_issues where
 		is_active is true and
 		description %(fragment_condition)s and
 		%(ctxt_pat)s
@@ -783,8 +808,8 @@ class cIssueSelectionPhraseWheel(gmPhraseWheel.cPhraseWheel):
 
 union
 
-(select pk, description || _(' (inactive)'), 2
-	from clin.health_issue where
+(select pk_health_issue, description || _(' (inactive)'), 2
+	from clin.v_health_issues where
 		is_active is false and
 		description %(fragment_condition)s and
 		%(ctxt_pat)s
@@ -840,7 +865,7 @@ union
 				if issue is None:
 					self.data = None
 				else:
-					self.data = issue['pk']
+					self.data = issue['pk_health_issue']
 
 		return gmPhraseWheel.cPhraseWheel.GetData(self)
 	#--------------------------------------------------------
@@ -936,7 +961,7 @@ class cHealthIssueEditAreaPnl(wxgHealthIssueEditAreaPnl.wxgHealthIssueEditAreaPn
 			gmDispatcher.send (
 				signal = 'statustext',
 				msg = _(
-					'Foundational health issue cannot have been noted at age %s. Patient is only %s old.'
+					'Health issue cannot have been noted at age %s. Patient is only %s old.'
 				) % (age, pat.get_medical_age())
 			)
 			self._PRW_age_noted.SetBackgroundColour('pink')
@@ -1128,7 +1153,7 @@ class cHealthIssueEditAreaPnl(wxgHealthIssueEditAreaPnl.wxgHealthIssueEditAreaPn
 		if narr != '':
 			pat = gmPerson.gmCurrentPatient()
 			emr = pat.get_emr()
-			epi = emr.add_episode(episode_name = _('inception notes'), pk_health_issue = self.__issue['pk'], is_open=None)
+			epi = emr.add_episode(episode_name = _('inception notes'), pk_health_issue = self.__issue['pk_health_issue'], is_open = None)
 			if epi is not None:
 				epi['episode_open'] = False
 				epi.save_payload()			# FIXME: error handling
@@ -1303,8 +1328,23 @@ if __name__ == '__main__':
 
 #================================================================
 # $Log: gmEMRStructWidgets.py,v $
-# Revision 1.79.2.1  2008/10/15 14:45:07  ncq
-# - rename pseudo episode for health issue
+# Revision 1.84.2.1  2009/04/20 12:05:37  ncq
+# - enable removing RFE/AOE
+#
+# Revision 1.84  2009/01/02 11:39:48  ncq
+# - support custom message/buttons in encounter edit area/dlg
+#
+# Revision 1.83  2008/12/09 23:28:51  ncq
+# - use description_gender
+#
+# Revision 1.82  2008/10/22 12:19:10  ncq
+# - rename pseudo episode on health issue creation to "inceptio notes"
+#
+# Revision 1.81  2008/10/12 16:15:17  ncq
+# - no more "foundational" health issue
+#
+# Revision 1.80  2008/09/02 19:01:12  ncq
+# - adjust to clin health_issue fk_patient drop and related changes
 #
 # Revision 1.79  2008/07/24 13:58:40  ncq
 # - manage encounter types
