@@ -11,8 +11,8 @@ to anybody else.
 """
 # ========================================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gmGuiHelpers.py,v $
-# $Id: gmGuiHelpers.py,v 1.96 2008/08/08 13:30:12 ncq Exp $
-__version__ = "$Revision: 1.96 $"
+# $Id: gmGuiHelpers.py,v 1.101 2009/02/24 11:19:54 ncq Exp $
+__version__ = "$Revision: 1.101 $"
 __author__  = "K. Hilbert <Karsten.Hilbert@gmx.net>"
 __license__ = "GPL (details at http://www.gnu.org)"
 
@@ -23,7 +23,7 @@ import wx
 
 
 from Gnumed.business import gmSurgery
-from Gnumed.wxGladeWidgets import wxg3ButtonQuestionDlg, wxg2ButtonQuestionDlg, wxgGreetingEditorDlg
+from Gnumed.wxGladeWidgets import wxg3ButtonQuestionDlg, wxg2ButtonQuestionDlg, wxgGreetingEditorDlg, wxgMultilineTextEntryDlg
 
 # ========================================================================
 class c2ButtonQuestionDlg(wxg2ButtonQuestionDlg.wxg2ButtonQuestionDlg):
@@ -139,54 +139,64 @@ class c3ButtonQuestionDlg(wxg3ButtonQuestionDlg.wxg3ButtonQuestionDlg):
 		else:
 			self.Close()
 # ========================================================================
-class cStartupProgressBar(wx.ProgressDialog):
-	def __init__(self, nr_actions):
+class cMultilineTextEntryDlg(wxgMultilineTextEntryDlg.wxgMultilineTextEntryDlg):
+	"""Editor for a bit of text."""
 
-		wx.ProgressDialog.__init__(
-			self,
-			parent = None,
-			title = _('GNUmed: Starting up ...'),
-			message = u' ' * 80 + u'\n\n\n',
-			maximum = nr_actions,
-			style = wx.PD_ELAPSED_TIME | wx.PD_CAN_ABORT
-		)
+	def __init__(self, *args, **kwargs):
 
-		# set window icon
-		paths = gmTools.gmPaths(app_name = u'gnumed', wx = wx)
-		png_fname = os.path.join(paths.system_app_data_dir, 'bitmaps', 'serpent.png')
-		icon = wx.EmptyIcon()
 		try:
-			icon.LoadFile(png_fname, wx.BITMAP_TYPE_PNG)
-		except:
-			pass
-#			_log2.warning('wx.Icon.LoadFile() not supported')
-		self.SetIcon(icon)
-		self.idx = 0
-#		self.nr_plugins = nr_plugins
-#		self.prev_plugin = ""
-	#----------------------------------------------------------
-	def Update (self, msg = None):
-#		if result == -1:
-#			result = ""
-#		elif result == 0:
-#			result = _("failed")
-#		else:
-#			result = _("success")
+			title = kwargs['title']
+			del kwargs['title']
+		except KeyError:
+			title = None
 
-#_("GNUmed: configuring [%s] (%s plugins)") % (gmSurgery.gmCurrentPractice().active_workplace, nr_plugins),
-#_("loading list of plugins                               "),
-		wx.ProgressDialog.Update(self, self.idx, msg)
-#		self.prev_plugin = plugin
-		self.idx += 1
+		try:
+			msg = kwargs['msg']
+			del kwargs['msg']
+		except KeyError:
+			msg = None
 
-#			_("previous: %s (%s)\ncurrent (%s/%s): %s") % (
-#				self.prev_plugin,
-#				result,
-#				(self.idx+1),
-#				self.nr_plugins,
-#				plugin
-#			)
+		try:
+			self.original_text = kwargs['text']
+			del kwargs['text']
+		except KeyError:
+			self.original_text = None
 
+		wxgMultilineTextEntryDlg.wxgMultilineTextEntryDlg.__init__(self, *args, **kwargs)
+
+		if title is not None:
+			self.SetTitle(title)
+
+		if msg is None:
+			self._LBL_msg.Hide()
+		else:
+			self._LBL_msg.SetLabel(msg)
+			self.Refresh()
+
+		if self.original_text is not None:
+			self._TCTRL_text.SetValue(self.original_text)
+			self._BTN_restore.Enable(True)
+	#--------------------------------------------------------
+	def _get_value(self):
+		return self._TCTRL_text.GetValue()
+
+	value = property(_get_value, lambda x:x)
+	#--------------------------------------------------------
+	# event handlers
+	#--------------------------------------------------------
+	def _on_save_button_pressed(self, evt):
+
+		if self.IsModal():
+			self.EndModal(wx.ID_SAVE)
+		else:
+			self.Close()
+	#--------------------------------------------------------
+	def _on_clear_button_pressed(self, evt):
+		self._TCTRL_text.SetValue(u'')
+	#--------------------------------------------------------
+	def _on_restore_button_pressed(self, evt):
+		if self.original_text is not None:
+			self._TCTRL_text.SetValue(self.original_text)
 # ========================================================================
 class cGreetingEditorDlg(wxgGreetingEditorDlg.wxgGreetingEditorDlg):
 
@@ -387,7 +397,7 @@ def gm_show_question(aMessage='programmer forgot to specify question', aTitle='g
 def makePageTitle(wizPg, title):
 	"""
 	Utility function to create the main sizer of a wizard's page.
-	
+
 	@param wizPg The wizard page widget
 	@type wizPg A wx.WizardPageSimple instance	
 	@param title The wizard page's descriptive title
@@ -508,6 +518,21 @@ class cTextWidgetValidator(wx.PyValidator):
 
 # ========================================================================
 # $Log: gmGuiHelpers.py,v $
+# Revision 1.101  2009/02/24 11:19:54  ncq
+# - cleanup
+#
+# Revision 1.100  2009/01/15 11:37:06  ncq
+# - no more save callback in multiline text editor
+#
+# Revision 1.99  2009/01/11 19:17:17  ncq
+# - support new action buttons in text editor
+#
+# Revision 1.98  2008/12/18 21:28:26  ncq
+# - cMultilineTextEntryDlg
+#
+# Revision 1.97  2008/11/21 13:06:09  ncq
+# - cleanup
+#
 # Revision 1.96  2008/08/08 13:30:12  ncq
 # - needs gmSurgery
 #
