@@ -13,8 +13,8 @@ TODO:
 """
 #================================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gmListWidgets.py,v $
-# $Id: gmListWidgets.py,v 1.25 2008/08/06 13:22:14 ncq Exp $
-__version__ = "$Revision: 1.25 $"
+# $Id: gmListWidgets.py,v 1.28 2009/01/17 23:07:29 ncq Exp $
+__version__ = "$Revision: 1.28 $"
 __author__ = "Karsten Hilbert <Karsten.Hilbert@gmx.net>"
 __license__ = "GPL"
 
@@ -34,13 +34,16 @@ from Gnumed.wxpython import gmGuiHelpers
 from Gnumed.wxGladeWidgets import wxgGenericListSelectorDlg, wxgGenericListManagerPnl
 
 #================================================================
-def get_choices_from_list(parent=None, msg=None, caption=None, choices=None, selections=None, columns=None, data=None, edit_callback=None, new_callback=None, delete_callback=None, refresh_callback=None, single_selection=False):
+def get_choices_from_list(parent=None, msg=None, caption=None, choices=None, selections=None, columns=None, data=None, edit_callback=None, new_callback=None, delete_callback=None, refresh_callback=None, single_selection=False, can_return_empty=False):
 	"""Let user select item(s) from a list.
 
 	- edit_callback: (item data)
 	- new_callback: ()
 	- delete_callback: (item data)
 	- refresh_callback: (listctrl)
+
+	returns None if cancelled
+	returns list (may be empty) of selected items
 	"""
 	if caption is None:
 		caption = _('generic multi choice dialog')
@@ -59,12 +62,15 @@ def get_choices_from_list(parent=None, msg=None, caption=None, choices=None, sel
 		dlg.set_selections(selections = selections)
 	if data is not None:
 		dlg.set_data(data=data)
+	dlg.can_return_empty = can_return_empty
 
 	btn_pressed = dlg.ShowModal()
 	sels = dlg.get_selected_item_data(only_one = single_selection)
 	dlg.Destroy()
 
 	if btn_pressed == wx.ID_OK:
+		if can_return_empty and (sels is None):
+			return []
 		return sels
 
 	return None
@@ -90,6 +96,8 @@ class cGenericListSelectorDlg(wxgGenericListSelectorDlg.wxgGenericListSelectorDl
 		self.edit_callback = None				# called when EDIT button pressed, data of topmost selected item passed in
 		self.delete_callback = None				# called when DELETE button pressed, data of topmost selected item passed in
 		self.refresh_callback = None			# called when new/edit/delete callbacks return True (IOW were not cancelled)
+
+		self.can_return_empty = False
 	#------------------------------------------------------------
 	def set_columns(self, columns=None):
 		self._LCTRL_items.set_columns(columns = columns)
@@ -120,8 +128,9 @@ class cGenericListSelectorDlg(wxgGenericListSelectorDlg.wxgGenericListSelectorDl
 	#------------------------------------------------------------
 	def _on_list_item_deselected(self, event):
 		if self._LCTRL_items.get_selected_items(only_one=True) == -1:
-			self._BTN_ok.Enable(False)
-			self._BTN_cancel.SetDefault()
+			if not self.can_return_empty:
+				self._BTN_ok.Enable(False)
+				self._BTN_cancel.SetDefault()
 			self._BTN_edit.Enable(False)
 			self._BTN_delete.Enable(False)
 	#------------------------------------------------------------
@@ -145,8 +154,11 @@ class cGenericListSelectorDlg(wxgGenericListSelectorDlg.wxgGenericListSelectorDl
 	#------------------------------------------------------------
 	def _on_delete_button_pressed(self, event):
 		# if the delete button *can* be pressed there are *supposed*
-		# to be both an item selected and an deletor configured
-		if not self.delete_callback(self._LCTRL_items.get_selected_item_data(only_one=True)):
+		# to be both an item selected and a deletor configured
+		item_data = self._LCTRL_items.get_selected_item_data(only_one=True)
+		if item_data is None:
+			return
+		if not self.delete_callback(item_data):
 			return
 		if self.refresh_callback is None:
 			return
@@ -270,6 +282,8 @@ class cReportListCtrl(wx.ListCtrl, listmixins.ListCtrlAutoWidthMixin):
 
 		wx.ListCtrl.__init__(self, *args, **kwargs)
 		listmixins.ListCtrlAutoWidthMixin.__init__(self)
+
+		self.__widths = None
 	#------------------------------------------------------------
 	# setters
 	#------------------------------------------------------------
@@ -285,17 +299,35 @@ class cReportListCtrl(wx.ListCtrl, listmixins.ListCtrlAutoWidthMixin):
 			self.InsertColumn(idx, columns[idx])
 	#------------------------------------------------------------
 	def set_column_widths(self, widths=None):
-		if widths is None:
-			if self.GetItemCount() == 0:
-				width_type = wx.LIST_AUTOSIZE_USEHEADER
-			else:
-				width_type = wx.LIST_AUTOSIZE
-			for idx in range(self.GetColumnCount()):
-				self.SetColumnWidth(col = idx, width = width_type)
+		"""Set the column width policy.
+
+		widths = None:
+			use previous policy if any or default policy
+		widths != None:
+			use this policy and remember it for later calls
+
+		This means there is no way to *revert* to the default policy :-(
+		"""
+		# explicit policy ?
+		if widths is not None:
+			self.__widths = widths
+			for idx in range(len(self.__widths)):
+				self.SetColumnWidth(col = idx, width = self.__widths[idx])
 			return
 
-		for idx in range(len(widths)):
-			self.SetColumnWidth(col = idx, width = widths[idx])
+		# previous policy ?
+		if self.__widths is not None:
+			for idx in range(len(self.__widths)):
+				self.SetColumnWidth(col = idx, width = self.__widths[idx])
+			return
+
+		# default policy !
+		if self.GetItemCount() == 0:
+			width_type = wx.LIST_AUTOSIZE_USEHEADER
+		else:
+			width_type = wx.LIST_AUTOSIZE
+		for idx in range(self.GetColumnCount()):
+			self.SetColumnWidth(col = idx, width = width_type)
 	#------------------------------------------------------------
 	def set_string_items(self, items = None):
 		"""All item members must be unicode()able or None."""
@@ -435,6 +467,15 @@ if __name__ == '__main__':
 
 #================================================================
 # $Log: gmListWidgets.py,v $
+# Revision 1.28  2009/01/17 23:07:29  ncq
+# - support remembering previous widths policy
+#
+# Revision 1.27  2009/01/15 11:39:59  ncq
+# - cleanup
+#
+# Revision 1.26  2008/12/25 16:55:36  ncq
+# - allow returniny empty list = no item selected if desired
+#
 # Revision 1.25  2008/08/06 13:22:14  ncq
 # - fix detection of item list type
 #
