@@ -2,13 +2,13 @@
 """
 #================================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gmMeasurementWidgets.py,v $
-# $Id: gmMeasurementWidgets.py,v 1.28.2.1 2008/08/31 22:20:13 ncq Exp $
-__version__ = "$Revision: 1.28.2.1 $"
+# $Id: gmMeasurementWidgets.py,v 1.39.2.1 2009/08/04 14:47:29 ncq Exp $
+__version__ = "$Revision: 1.39.2.1 $"
 __author__ = "Karsten Hilbert <Karsten.Hilbert@gmx.net>"
 __license__ = "GPL"
 
 
-import sys, logging, datetime as pyDT
+import sys, logging, datetime as pyDT, decimal
 
 
 import wx, wx.grid
@@ -17,7 +17,7 @@ import wx, wx.grid
 if __name__ == '__main__':
 	sys.path.insert(0, '../../')
 from Gnumed.business import gmPerson, gmPathLab
-from Gnumed.pycommon import gmTools, gmDispatcher, gmMatchProvider, gmDateTime
+from Gnumed.pycommon import gmTools, gmDispatcher, gmMatchProvider, gmDateTime, gmI18N
 from Gnumed.wxpython import gmRegetMixin, gmPhraseWheel, gmEditArea, gmGuiHelpers, gmListWidgets
 from Gnumed.wxGladeWidgets import wxgMeasurementsPnl, wxgMeasurementsReviewDlg
 from Gnumed.wxGladeWidgets import wxgMeasurementEditAreaPnl
@@ -37,6 +37,9 @@ def edit_measurement(parent=None, measurement=None):
 	if dlg.ShowModal() == wx.ID_OK:
 		return True
 	return False
+#================================================================
+#from Gnumed.wxGladeWidgets import wxgPrimaryCareVitalsInputPnl
+
 #================================================================
 # display widgets
 #================================================================
@@ -85,8 +88,8 @@ class cMeasurementsGrid(wx.grid.Grid):
 			) % len(selected_cells)
 		else:
 			results = self.__cells_to_data(cells = selected_cells, exclude_multi_cells = False)
-			txt = u'\n'.join([ '%s %s (%s): %s %s%s' % (
-					r['clin_when'].strftime('%Y-%m-%d %H:%M'),
+			txt = u'\n'.join([ u'%s %s (%s): %s %s%s' % (
+					r['clin_when'].strftime('%x %H:%M').decode(gmI18N.get_encoding()),
 					r['unified_code'],
 					r['unified_name'],
 					r['unified_val'],
@@ -179,6 +182,42 @@ class cMeasurementsGrid(wx.grid.Grid):
 	#------------------------------------------------------------
 	def get_selected_cells(self):
 
+		sel_block_top_left = self.GetSelectionBlockTopLeft()
+		sel_block_bottom_right = self.GetSelectionBlockBottomRight()
+		sel_cols = self.GetSelectedCols()
+		sel_rows = self.GetSelectedRows()
+
+		selected_cells = []
+
+		# individually selected cells (ctrl-click)
+		selected_cells += self.GetSelectedCells()
+
+		# selected rows
+		selected_cells += list (
+			(row, col)
+				for row in sel_rows
+				for col in xrange(self.GetNumberCols())
+		)
+
+		# selected columns
+		selected_cells += list (
+			(row, col)
+				for row in xrange(self.GetNumberRows())
+				for col in sel_cols
+		)
+
+		# selection blocks
+		for top_left, bottom_right in zip(self.GetSelectionBlockTopLeft(), self.GetSelectionBlockBottomRight()):
+			selected_cells += [
+				(row, col)
+					for row in xrange(top_left[0], bottom_right[0] + 1)
+					for col in xrange(top_left[1], bottom_right[1] + 1)
+			]
+
+		return set(selected_cells)
+	#------------------------------------------------------------
+	def get_selected_cells_faulty(self):
+
 		sel_block_top_left = self.GetSelectionBlockTopLeft()
 		sel_block_bottom_right = self.GetSelectionBlockBottomRight()
 		sel_cols = self.GetSelectedCols()
@@ -226,15 +265,21 @@ class cMeasurementsGrid(wx.grid.Grid):
 
 		for col_idx in self.__cell_data.keys():
 			for row_idx in self.__cell_data[col_idx].keys():
-				# skip multi-value cells for now
-				if len(self.__cell_data[col_idx][row_idx]) > 1:
+				# loop over results in cell and only include
+				# this multi-value cells that are not ambigous
+				do_not_include = False
+				for result in self.__cell_data[col_idx][row_idx]:
+					if unsigned_only:
+						if result['reviewed']:
+							do_not_include = True
+							break
+					if accountables_only:
+						if not result['you_are_responsible']:
+							do_not_include = True
+							break
+				if do_not_include:
 					continue
-				if unsigned_only:
-					if self.__cell_data[col_idx][row_idx][0]['reviewed']:
-						continue
-				if accountables_only:
-					if not self.__cell_data[col_idx][row_idx][0]['you_are_responsible']:
-						continue
+
 				self.SelectBlock(row_idx, col_idx, row_idx, col_idx, addToSelected = True)
 
 		self.EndBatch()
@@ -286,6 +331,7 @@ class cMeasurementsGrid(wx.grid.Grid):
 			except KeyError:
 				self.__cell_data[col] = {}
 
+			# the tooltip always shows the youngest sub result details
 			rebuild_tooltip = False
 			if self.__cell_data[col].has_key(row):
 				if result['clin_when'] < self.__cell_data[col][row][0]['clin_when']:
@@ -298,58 +344,58 @@ class cMeasurementsGrid(wx.grid.Grid):
 
 			# rebuild cell display string
 			vals2display = []
-			for result in self.__cell_data[col][row]:
+			for sub_result in self.__cell_data[col][row]:
 
-				# is the result technically abnormal ?
-				ind = gmTools.coalesce(result['abnormality_indicator'], u'').strip()
+				# is the sub_result technically abnormal ?
+				ind = gmTools.coalesce(sub_result['abnormality_indicator'], u'').strip()
 				if ind != u'':
 					lab_abnormality_indicator = u' (%s)' % ind[:3]
 				else:
 					lab_abnormality_indicator = u''
 				# - if noone reviewed - use what the lab thinks
-				if result['is_technically_abnormal'] is None:
+				if sub_result['is_technically_abnormal'] is None:
 					abnormality_indicator = lab_abnormality_indicator
 				# - if someone reviewed and decreed normality - use that
-				elif result['is_technically_abnormal'] is False:
+				elif sub_result['is_technically_abnormal'] is False:
 					abnormality_indicator = u''
 				# - if someone reviewed and decreed abnormality ...
 				else:
 					# ... invent indicator if the lab did't use one
 					if lab_abnormality_indicator == u'':
 						# FIXME: calculate from min/max/range
-						abnormality_indicator = u' (\u00B1)'
+						abnormality_indicator = u' (%s)' % gmTools.u_plus_minus
 					# ... else use indicator the lab used
 					else:
 						abnormality_indicator = lab_abnormality_indicator
 
-				# is the result relevant clinically ?
+				# is the sub_result relevant clinically ?
 				# FIXME: take into account primary_GP once we support that
-				result_relevant = result['is_clinically_relevant']
-				if result_relevant is None:
+				sub_result_relevant = sub_result['is_clinically_relevant']
+				if sub_result_relevant is None:
 					# FIXME: calculate from clinical range
-					result_relevant = False
+					sub_result_relevant = False
 
 				missing_review = False
 				# warn on missing review if
 				# a) no review at all exists or
-				if not result['reviewed']:
+				if not sub_result['reviewed']:
 					missing_review = True
 				# b) there is a review but
 				else:
 					# current user is reviewer and hasn't reviewed
-					if result['you_are_responsible'] and not result['review_by_you']:
+					if sub_result['you_are_responsible'] and not sub_result['review_by_you']:
 						missing_review = True
 
-				# can we display the full result information ?
-				has_result_comment = gmTools.coalesce (
-					gmTools.coalesce(result['note_test_org'], result['comment']),
+				# can we display the full sub_result information ?
+				has_sub_result_comment = gmTools.coalesce (
+					gmTools.coalesce(sub_result['note_test_org'], sub_result['comment']),
 					u''
 				).strip() != u''
 
 				# no - display ... and truncate to 7 chars
-				if (len(result['unified_val']) > 8) or (has_result_comment):
+				if (len(sub_result['unified_val']) > 8) or (has_sub_result_comment):
 					tmp = u'%.7s%s%.6s%.2s' % (
-						result['unified_val'][:7],
+						sub_result['unified_val'][:7],
 						gmTools.u_ellipsis,
 						abnormality_indicator,
 						gmTools.bool2subst(missing_review, u' ' + gmTools.u_writing_hand, u'')
@@ -357,20 +403,21 @@ class cMeasurementsGrid(wx.grid.Grid):
 				# yes - display fully up to 8 chars
 				else:
 					tmp = u'%.8s%.6s%.2s' % (
-						result['unified_val'][:8],
+						sub_result['unified_val'][:8],
 						abnormality_indicator,
 						gmTools.bool2subst(missing_review, u' ' + gmTools.u_writing_hand, u'')
 					)
 				if len(self.__cell_data[col][row]) > 1:
-					tmp = '%s %s' % (result['clin_when'].strftime('%H:%M'), tmp)
+					tmp = u'%s %s' % (sub_result['clin_when'].strftime('%H:%M'), tmp)
 				vals2display.append(tmp)
 
-			self.SetCellValue(row, col, '\n'.join(vals2display))
+			self.SetCellValue(row, col, u'\n'.join(vals2display))
 			self.SetCellAlignment(row, col, horiz = wx.ALIGN_RIGHT, vert = wx.ALIGN_CENTRE)
 #			font = self.GetCellFont(row, col)
 #			if not font.IsFixedWidth():
 #				font.SetFamily(family = wx.FONTFAMILY_MODERN)
-			if result_relevant:
+			# FIXME: what about partial sub results being relevant ??
+			if sub_result_relevant:
 				font = self.GetCellFont(row, col)
 				self.SetCellTextColour(row, col, 'firebrick')
 				font.SetWeight(wx.FONTWEIGHT_BOLD)
@@ -398,7 +445,7 @@ class cMeasurementsGrid(wx.grid.Grid):
 					clinical_min_max = u''
 
 				if result['reviewed']:
-					review_status = result['last_reviewed'].strftime('%c')
+					review_status = result['last_reviewed'].strftime('%c').decode(gmI18N.get_encoding())
 				else:
 					review_status = _('not yet')
 
@@ -407,35 +454,35 @@ class cMeasurementsGrid(wx.grid.Grid):
 				except KeyError:
 					self.__cell_tooltips[col] = {}
 				self.__cell_tooltips[col][row] = _(
-					'Measurement details of most recent result:               \n'
-					' Date: %(clin_when)s\n'
-					' Type: "%(name)s" (%(code)s)\n'
-					' Result: %(val)s%(unit)s%(ind)s\n'
-					' Standard normal range: %(norm_min_max)s%(norm_range)s  \n'
-					' Reference group: %(ref_group)s\n'
-					' Clinical target range: %(clin_min_max)s%(clin_range)s  \n'
-					' Doc: %(comment_doc)s\n'
-					' Lab: %(comment_lab)s\n'	# note_test_org
-					' Episode: %(epi)s\n'
-					' Issue: %(issue)s\n'
-					' Material: %(material)s\n'
-					' Details: %(mat_detail)s\n'
-					'\n'
-					'Signed (%(sig_hand)s): %(reviewed)s\n'
-					' Last reviewer: %(reviewer)s\n'
-					'  Technically abnormal: %(abnormal)s\n'
-					'  Clinically relevant: %(relevant)s\n'
-					'  Comment: %(rev_comment)s\n'
-					' Responsible clinician: %(responsible_reviewer)s\n'
-					'\n'
-					'Test type details:\n'
-					' Grouped under "%(name_unified)s" (%(code_unified)s)  \n'
-					' Type comment: %(comment_type)s\n'
-					' Group comment: %(comment_type_unified)s\n'
-					'\n'
-					'Revisions: %(row_ver)s, last %(mod_when)s by %(mod_by)s.'
+					u'Measurement details of most recent result:               \n'
+					u' Date: %(clin_when)s\n'
+					u' Type: "%(name)s" (%(code)s)\n'
+					u' Result: %(val)s%(unit)s%(ind)s\n'
+					u' Standard normal range: %(norm_min_max)s%(norm_range)s  \n'
+					u' Reference group: %(ref_group)s\n'
+					u' Clinical target range: %(clin_min_max)s%(clin_range)s  \n'
+					u' Doc: %(comment_doc)s\n'
+					u' Lab: %(comment_lab)s\n'	# note_test_org
+					u' Episode: %(epi)s\n'
+					u' Issue: %(issue)s\n'
+					u' Material: %(material)s\n'
+					u' Details: %(mat_detail)s\n'
+					u'\n'
+					u'Signed (%(sig_hand)s): %(reviewed)s\n'
+					u' Last reviewer: %(reviewer)s\n'
+					u'  Technically abnormal: %(abnormal)s\n'
+					u'  Clinically relevant: %(relevant)s\n'
+					u'  Comment: %(rev_comment)s\n'
+					u' Responsible clinician: %(responsible_reviewer)s\n'
+					u'\n'
+					u'Test type details:\n'
+					u' Grouped under "%(name_unified)s" (%(code_unified)s)  \n'
+					u' Type comment: %(comment_type)s\n'
+					u' Group comment: %(comment_type_unified)s\n'
+					u'\n'
+					u'Revisions: %(row_ver)s, last %(mod_when)s by %(mod_by)s.'
 				) % ({
-					'clin_when': result['clin_when'].strftime('%c'),
+					'clin_when': result['clin_when'].strftime('%c').decode(gmI18N.get_encoding()),
 					'code': result['code_tt'],
 					'name': result['name_tt'],
 					'val': result['unified_val'],
@@ -462,8 +509,8 @@ class cMeasurementsGrid(wx.grid.Grid):
 							u'%s'
 						)
 					),
-					'comment_doc': u'\n Doc: '.join(gmTools.coalesce(result['comment'], u'').split('\n')),
-					'comment_lab': u'\n Lab: '.join(gmTools.coalesce(result['note_test_org'], u'').split('\n')),
+					'comment_doc': u'\n Doc: '.join(gmTools.coalesce(result['comment'], u'').split(u'\n')),
+					'comment_lab': u'\n Lab: '.join(gmTools.coalesce(result['note_test_org'], u'').split(u'\n')),
 					'epi': result['episode'],
 					'issue': gmTools.coalesce(result['health_issue'], u''),
 					'material': gmTools.coalesce(result['material'], u''),
@@ -476,12 +523,12 @@ class cMeasurementsGrid(wx.grid.Grid):
 					'rev_comment': gmTools.coalesce(result['review_comment'], u''),
 					'responsible_reviewer': gmTools.bool2subst(result['you_are_responsible'], _('you'), result['responsible_reviewer']),
 
-					'comment_type': u'\n Type comment:'.join(gmTools.coalesce(result['comment_tt'], u'').split('\n')),
+					'comment_type': u'\n Type comment:'.join(gmTools.coalesce(result['comment_tt'], u'').split(u'\n')),
 					'name_unified': gmTools.coalesce(result['name_unified'], u''),
 					'code_unified': gmTools.coalesce(result['code_unified'], u''),
-					'comment_type_unified': u'\n Group comment: '.join(gmTools.coalesce(result['comment_unified'], u'').split('\n')),
+					'comment_type_unified': u'\n Group comment: '.join(gmTools.coalesce(result['comment_unified'], u'').split(u'\n')),
 
-					'mod_when': result['modified_when'].strftime('%c'),
+					'mod_when': result['modified_when'].strftime('%c').decode(gmI18N.get_encoding()),
 					'mod_by': result['modified_by'],
 					'row_ver': result['row_version'],
 
@@ -495,7 +542,8 @@ class cMeasurementsGrid(wx.grid.Grid):
 	def empty_grid(self):
 		self.BeginBatch()
 		self.ClearGrid()
-		# Windows bullsh*t
+		# Windows cannot do nothing, it rather decides to assert()
+		# on thinking it is supposed to do nothing
 		if self.GetNumberRows() > 0:
 			self.DeleteRows(pos = 0, numRows = self.GetNumberRows())
 		if self.GetNumberCols() > 0:
@@ -576,10 +624,12 @@ class cMeasurementsGrid(wx.grid.Grid):
 			# FIXME: invoke (unified) test type editor
 			return
 
-		# empty ?
+		# empty cell, perhaps ?
 		try:
 			self.__cell_data[col][row]
 		except KeyError:
+			# FIXME: invoke editor for adding value for day of that column
+			# FIMXE: and test of that row
 			return
 
 		if len(self.__cell_data[col][row]) > 1:
@@ -729,7 +779,7 @@ class cMeasurementsReviewDlg(wxgMeasurementsReviewDlg.wxgMeasurementsReviewDlg):
 						t['unified_code'],
 						t['unified_val'],
 						t['val_unit'],
-						t['clin_when'].strftime('%Y-%m-%d')
+						t['clin_when'].strftime('%x').decode(gmI18N.get_encoding())
 					) for t in tests
 				]
 			)
@@ -863,6 +913,7 @@ class cMeasurementEditAreaPnl(wxgMeasurementEditAreaPnl.wxgMeasurementEditAreaPn
 
 		if self._PRW_problem.GetValue().strip() == u'':
 			self._PRW_problem.display_as_valid(False)
+			validity = False
 		else:
 			self._PRW_problem.display_as_valid(True)
 
@@ -890,14 +941,14 @@ class cMeasurementEditAreaPnl(wxgMeasurementEditAreaPnl.wxgMeasurementEditAreaPn
 			if val == u'':
 				continue
 			try:
-				int(val)
+				decimal.Decimal(val.replace(',', u'.', 1))
 				widget.SetBackgroundColour(gmPhraseWheel.color_prw_valid)
 			except:
 				widget.SetBackgroundColour(gmPhraseWheel.color_prw_invalid)
 				validity = False
 
 		if validity is False:
-			gmDispatcher.send(signal = 'statustext', msg = _('Cannot save result. Missing essential input.'))
+			gmDispatcher.send(signal = 'statustext', msg = _('Cannot save result. Invalid or missing essential input.'))
 
 		return validity
 	#--------------------------------------------------------
@@ -906,7 +957,7 @@ class cMeasurementEditAreaPnl(wxgMeasurementEditAreaPnl.wxgMeasurementEditAreaPn
 		emr = gmPerson.gmCurrentPatient().get_emr()
 
 		try:
-			v_num = int(self._TCTRL_result.GetValue().strip())
+			v_num = decimal.Decimal(self._TCTRL_result.GetValue().strip().replace(',', '.', 1))
 			v_al = None
 		except:
 			v_num = None
@@ -966,10 +1017,11 @@ class cMeasurementEditAreaPnl(wxgMeasurementEditAreaPnl.wxgMeasurementEditAreaPn
 	#--------------------------------------------------------
 	def _save_as_update(self):
 
-		try:
-			v_num = int(self._TCTRL_result.GetValue().strip())
+		success, result = gmTools.input2decimal(self._TCTRL_result.GetValue())
+		if success:
+			v_num = result
 			v_al = None
-		except:
+		else:
 			v_num = None
 			v_al = self._TCTRL_result.GetValue().strip()
 
@@ -1122,6 +1174,7 @@ limit 50""" % {'in_house': _('in house lab')}
 
 		mp = gmMatchProvider.cMatchProvider_SQL2(queries=query)
 		mp.setThresholds(1, 2, 4)
+		mp.word_separators = '[ \t:@]+'
 		gmPhraseWheel.cPhraseWheel.__init__ (
 			self,
 			*args,
@@ -1205,7 +1258,7 @@ limit 25"""
 #----------------------------------------------------------------
 if __name__ == '__main__':
 
-	from Gnumed.pycommon import gmLog2, gmI18N
+	from Gnumed.pycommon import gmLog2
 
 	gmI18N.activate_locale()
 	gmI18N.install_domain()
@@ -1228,17 +1281,57 @@ if __name__ == '__main__':
 		app.frame.Show()
 		app.MainLoop()
 	#------------------------------------------------------------
+#	def test_primary_care_vitals_pnl():
+#		app = wx.PyWidgetTester(size = (500, 300))
+#		pnl = wxgPrimaryCareVitalsInputPnl.wxgPrimaryCareVitalsInputPnl(parent = app.frame, id = -1)
+#		app.frame.Show()
+#		app.MainLoop()
+	#------------------------------------------------------------
 	if (len(sys.argv) > 1) and (sys.argv[1] == 'test'):
 		#test_grid()
 		test_test_ea_pnl()
+		#test_primary_care_vitals_pnl()
 
 #================================================================
 # $Log: gmMeasurementWidgets.py,v $
-# Revision 1.28.2.1  2008/08/31 22:20:13  ncq
-# - ignore dclick in empty grid cell
-# - properly display non-NULL val_normal/target_min/max
-# - properly handle cell data being list when selecting cells programmatically
-# - work around Windows not being able to do nothing when there's nothing to do
+# Revision 1.39.2.1  2009/08/04 14:47:29  ncq
+# - fix faulty cell selection
+# - properly check for problem field when adding measurement type
+#
+# Revision 1.39  2009/03/01 18:15:55  ncq
+# - lots of missing u'', decode strftime results
+# - adjust word separators in test type match provider
+#
+# Revision 1.38  2009/02/20 15:43:21  ncq
+# - u''ify
+#
+# Revision 1.37  2009/02/17 17:47:31  ncq
+# - comment out primary care vitals
+#
+# Revision 1.36  2009/02/12 16:23:39  ncq
+# - start work on primary care vitals input
+#
+# Revision 1.35  2009/01/28 11:27:56  ncq
+# - slightly better naming and comments
+#
+# Revision 1.34  2009/01/02 11:40:27  ncq
+# - properly check for numericity of value/range input
+#
+# Revision 1.33  2008/10/22 12:21:57  ncq
+# - use %x in strftime where appropriate
+#
+# Revision 1.32  2008/08/31 18:21:54  ncq
+# - work around Windows' inability to do nothing when
+#   there's nothing to do
+#
+# Revision 1.31  2008/08/31 18:04:30  ncq
+# - properly handle cell data now being list in select_cells()
+#
+# Revision 1.30  2008/08/31 17:13:50  ncq
+# - don't crash on double-clicking empty test results cell
+#
+# Revision 1.29  2008/08/31 17:04:17  ncq
+# - need to cast val_normal/target_min/max to unicode before display
 #
 # Revision 1.28  2008/08/15 15:57:10  ncq
 # - indicate data revisions in tooltip
