@@ -2,8 +2,8 @@
 """
 #================================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gmMedDocWidgets.py,v $
-# $Id: gmMedDocWidgets.py,v 1.166.2.4 2008/11/21 16:11:31 ncq Exp $
-__version__ = "$Revision: 1.166.2.4 $"
+# $Id: gmMedDocWidgets.py,v 1.175 2009/02/04 21:47:17 ncq Exp $
+__version__ = "$Revision: 1.175 $"
 __author__ = "Karsten Hilbert <Karsten.Hilbert@gmx.net>"
 
 import os.path, sys, re as regex, logging
@@ -26,6 +26,80 @@ _log.info(__version__)
 
 default_chunksize = 1 * 1024 * 1024		# 1 MB
 #============================================================
+def manage_document_descriptions(parent=None, document=None):
+
+	#-----------------------------------
+	def refresh_list(lctrl):
+		descriptions = document.get_descriptions()
+
+		lctrl.set_string_items(items = [
+			u'%s%s' % ( (u' '.join(regex.split('\r\n+|\r+|\n+|\t+', desc[1])))[:30], gmTools.u_ellipsis )
+			for desc in descriptions
+		])
+		lctrl.set_data(data = descriptions)
+	#-----------------------------------
+	def delete_item(item):
+		doit = gmGuiHelpers.gm_show_question (
+			_(	'Are you sure you want to delete this\n'
+				'description from the document ?\n'
+			),
+			_('Deleting document description')
+		)
+		if not doit:
+			return True
+
+		document.delete_description(pk = item[0])
+		return True
+	#-----------------------------------
+	def add_item():
+		dlg = gmGuiHelpers.cMultilineTextEntryDlg (
+			parent,
+			-1,
+			title = _('Adding document description'),
+			msg = _('Below you can add a document description.\n')
+		)
+		result = dlg.ShowModal()
+		if result == wx.ID_SAVE:
+			document.add_description(dlg.value)
+
+		dlg.Destroy()
+		return True
+	#-----------------------------------
+	def edit_item(item):
+		dlg = gmGuiHelpers.cMultilineTextEntryDlg (
+			parent,
+			-1,
+			title = _('Editing document description'),
+			msg = _('Below you can edit the document description.\n'),
+			text = item[1]
+		)
+		result = dlg.ShowModal()
+		if result == wx.ID_SAVE:
+			document.update_description(pk = item[0], description = dlg.value)
+
+		dlg.Destroy()
+		return True
+	#-----------------------------------
+	descriptions = document.get_descriptions()
+
+	gmListWidgets.get_choices_from_list (
+		parent = parent,
+		msg = _('Select the description you are interested in.\n'),
+		caption = _('Managing document descriptions'),
+		choices = [ u'%s%s' % ( (u' '.join(regex.split('\r\n+|\r+|\n+|\t+', desc[1])))[:30], gmTools.u_ellipsis ) for desc in descriptions ],
+		selections = None,
+		columns = [_('Description')],
+		data = descriptions,
+		edit_callback = edit_item,
+		new_callback = add_item,
+		delete_callback = delete_item,
+		refresh_callback = refresh_list,
+		single_selection = True,
+		can_return_empty = True
+	)
+
+	return True
+#============================================================
 def _save_file_as_new_document(**kwargs):
 	wx.CallAfter(save_file_as_new_document, **kwargs)
 #----------------------
@@ -394,7 +468,7 @@ class cReviewDocPartDlg(wxgReviewDocPartDlg.wxgReviewDocPartDlg):
 			row_num = self._LCTRL_existing_reviews.InsertStringItem(sys.maxint, label=review_by_responsible_doc[0])
 			self._LCTRL_existing_reviews.SetItemTextColour(row_num, col=wx.BLUE)
 			self._LCTRL_existing_reviews.SetStringItem(index = row_num, col=0, label=review_by_responsible_doc[0])
-			self._LCTRL_existing_reviews.SetStringItem(index = row_num, col=1, label=review_by_responsible_doc[1].strftime('%Y-%m-%d %H:%M'))
+			self._LCTRL_existing_reviews.SetStringItem(index = row_num, col=1, label=review_by_responsible_doc[1].strftime('%x %H:%M'))
 			if review_by_responsible_doc['is_technically_abnormal']:
 				self._LCTRL_existing_reviews.SetStringItem(index = row_num, col=2, label=u'X')
 			if review_by_responsible_doc['clinically_relevant']:
@@ -404,7 +478,7 @@ class cReviewDocPartDlg(wxgReviewDocPartDlg.wxgReviewDocPartDlg):
 		for rev in reviews_by_others:
 			row_num = self._LCTRL_existing_reviews.InsertStringItem(sys.maxint, label=rev[0])
 			self._LCTRL_existing_reviews.SetStringItem(index = row_num, col=0, label=rev[0])
-			self._LCTRL_existing_reviews.SetStringItem(index = row_num, col=1, label=rev[1].strftime('%Y-%m-%d %H:%M'))
+			self._LCTRL_existing_reviews.SetStringItem(index = row_num, col=1, label=rev[1].strftime('%x %H:%M'))
 			if rev['is_technically_abnormal']:
 				self._LCTRL_existing_reviews.SetStringItem(index = row_num, col=2, label=u'X')
 			if rev['clinically_relevant']:
@@ -440,7 +514,7 @@ class cReviewDocPartDlg(wxgReviewDocPartDlg.wxgReviewDocPartDlg):
 		self.__doc['pk_type'] = doc_type
 		if self.__reviewing_doc:
 			self.__doc['comment'] = self._PRW_doc_comment.GetValue().strip()
-		self.__doc['date'] = self._PhWheel_doc_date.GetData().get_pydt()
+		self.__doc['clin_when'] = self._PhWheel_doc_date.GetData().get_pydt()
 		self.__doc['ext_ref'] = self._TCTRL_reference.GetValue().strip()
 
 		success, data = self.__doc.save_payload()
@@ -879,7 +953,7 @@ from your computer.""") % page_fname,
 
 		# update business object with metadata
 		# - date of generation
-		new_doc['date'] = self._PhWheel_doc_date.GetData().get_pydt()
+		new_doc['clin_when'] = self._PhWheel_doc_date.GetData().get_pydt()
 		# - external reference
 		ref = gmMedDoc.get_ext_ref()
 		if ref is not None:
@@ -925,6 +999,9 @@ from your computer.""") % page_fname,
 			):
 				msg = _('Error setting "reviewed" status of new document.')
 
+		gmHooks.run_hook_script(hook = u'after_new_doc_created')
+
+		# inform user
 		cfg = gmCfg.cCfgSQL()
 		show_id = bool (
 			cfg.get2 (
@@ -949,10 +1026,10 @@ off this message in the GNUmed configuration.""") % ref
 				aMessage = msg,
 				aTitle = _('saving document')
 			)
+		else:
+			gmDispatcher.send(signal='statustext', msg=_('Successfully saved new document.'))
 
-		# prepare for next document
 		self.__init_ui_data()
-		gmDispatcher.send(signal='statustext', msg=_('Successfully saved new document.'))
 		return True
 	#--------------------------------------------------------
 	def _startover_btn_pressed(self, evt):
@@ -1120,8 +1197,7 @@ class cDocTree(wx.TreeCtrl, gmRegetMixin.cRegetOnPaintMixin):
 		self.__part_context_menu.Append(ID, _('Mail part'))
 		wx.EVT_MENU(self.__part_context_menu, ID, self.__mail_part)
 
-		self.__part_context_menu.AppendSeparator()
-
+		self.__part_context_menu.AppendSeparator()			# so we can append some items
 
 		# --- doc context menu ---
 		self.__doc_context_menu = wx.Menu(title = _('document menu'))
@@ -1151,15 +1227,33 @@ class cDocTree(wx.TreeCtrl, gmRegetMixin.cRegetOnPaintMixin):
 		wx.EVT_MENU(self.__doc_context_menu, ID, self.__access_external_original)
 
 		ID = wx.NewId()
-		self.__doc_context_menu.Append(ID, _('Edit corresponding consultation'))
-		wx.EVT_MENU(self.__doc_context_menu, ID, self.__edit_consultation_details)
+		self.__doc_context_menu.Append(ID, _('Edit corresponding encounter'))
+		wx.EVT_MENU(self.__doc_context_menu, ID, self.__edit_encounter_details)
 
 		ID = wx.NewId()
 		self.__doc_context_menu.Append(ID, _('Delete'))
 		wx.EVT_MENU(self.__doc_context_menu, ID, self.__delete_document)
 
-		self.__doc_context_menu.AppendSeparator()
+#		self.__doc_context_menu.AppendSeparator()
 
+		ID = wx.NewId()
+		self.__doc_context_menu.Append(ID, _('Manage descriptions'))
+		wx.EVT_MENU(self.__doc_context_menu, ID, self.__manage_document_descriptions)
+
+		# document / description
+#		self.__desc_menu = wx.Menu()
+#		ID = wx.NewId()
+#		self.__doc_context_menu.AppendMenu(ID, _('Descriptions ...'), self.__desc_menu)
+
+#		ID = wx.NewId()
+#		self.__desc_menu.Append(ID, _('Add new description'))
+#		wx.EVT_MENU(self.__desc_menu, ID, self.__add_doc_desc)
+
+#		ID = wx.NewId()
+#		self.__desc_menu.Append(ID, _('Delete description'))
+#		wx.EVT_MENU(self.__desc_menu, ID, self.__del_doc_desc)
+
+#		self.__desc_menu.AppendSeparator()
 	#--------------------------------------------------------
 	def __populate_tree(self):
 
@@ -1178,9 +1272,8 @@ class cDocTree(wx.TreeCtrl, gmRegetMixin.cRegetOnPaintMixin):
 		docs_folder = curr_pat.get_document_folder()
 		docs = docs_folder.get_documents()
 		if docs is None:
-			name = curr_pat.get_names()
 			gmGuiHelpers.gm_show_error (
-				aMessage = _('Error searching documents for patient\n[%s %s].') % (name['firstnames'], name['lastnames']),
+				aMessage = _('Error searching documents.'),
 				aTitle = _('loading document list')
 			)
 			# avoid recursion of GUI updating
@@ -1202,7 +1295,7 @@ class cDocTree(wx.TreeCtrl, gmRegetMixin.cRegetOnPaintMixin):
 
 			cmt = gmTools.coalesce(doc['comment'], _('no comment available'))
 			page_num = len(parts)
-			ref = gmTools.coalesce(initial = doc['ext_ref'], instead = _('no reference ID found'), template_initial = u'\u00BB%s\u00AB')
+			ref = gmTools.coalesce(initial = doc['ext_ref'], instead = _('no reference ID'), template_initial = u'\u00BB%s\u00AB')
 
 			if doc.has_unreviewed_parts():
 				review = u'\u270D'
@@ -1211,7 +1304,7 @@ class cDocTree(wx.TreeCtrl, gmRegetMixin.cRegetOnPaintMixin):
 
 			label = _('%s%7s %s: %s (%s part(s), %s)') % (
 				review,
-				doc['date'].strftime('%m/%Y'),
+				doc['clin_when'].strftime('%m/%Y'),
 				doc['l10n_type'][:26],
 				cmt,
 				page_num,
@@ -1260,7 +1353,7 @@ class cDocTree(wx.TreeCtrl, gmRegetMixin.cRegetOnPaintMixin):
 				part_node = self.AppendItem(parent = doc_node, text = label)
 				self.SetPyData(part_node, part)
 
-		self.SortChildren(self.root)
+		self.__sort_nodes()
 		self.SelectItem(self.root)
 
 		# FIXME: apply expansion state if available or else ...
@@ -1286,7 +1379,7 @@ class cDocTree(wx.TreeCtrl, gmRegetMixin.cRegetOnPaintMixin):
 		# doc node
 		if isinstance(item1, gmMedDoc.cMedDoc):
 
-			date_field = 'date'
+			date_field = 'clin_when'
 			#date_field = 'modified_when'
 
 			if self.__sort_mode == 'age':
@@ -1346,6 +1439,7 @@ class cDocTree(wx.TreeCtrl, gmRegetMixin.cRegetOnPaintMixin):
 		# part node
 		if isinstance(item1, gmMedDoc.cMedDocPart):
 			# compare sequence IDs (= "page" numbers)
+			# FIXME: wrong order ?
 			if item1['seq_idx'] < item2['seq_idx']:
 				return -1
 			if item1['seq_idx'] == item2['seq_idx']:
@@ -1353,10 +1447,16 @@ class cDocTree(wx.TreeCtrl, gmRegetMixin.cRegetOnPaintMixin):
 			return 1
 
 		# else sort alphabetically
-		if item1 < item2:
-			return -1
-		if item1 == item2:
-			return 0
+		if None in [item1, item2]:
+			if node1 < node2:
+				return -1
+			if node1 == node2:
+				return 0
+		else:
+			if item1 < item2:
+				return -1
+			if item1 == item2:
+				return 0
 		return 1
 	#------------------------------------------------------------------------
 	# event handlers
@@ -1429,38 +1529,33 @@ class cDocTree(wx.TreeCtrl, gmRegetMixin.cRegetOnPaintMixin):
 		self.__display_part(part=self.__curr_node_data)
 	#--------------------------------------------------------
 	def __review_curr_part(self, evt):
-		self.__review_part(part=self.__curr_node_data)
+		self.__review_part(part = self.__curr_node_data)
 	#--------------------------------------------------------
-	def __show_description(self, evt):
-		print "showing description"
+	def __manage_document_descriptions(self, evt):
+		manage_document_descriptions(parent = self, document = self.__curr_node_data)
 	#--------------------------------------------------------
 	# internal API
 	#--------------------------------------------------------
+	def __sort_nodes(self, start_node=None):
+		if start_node is None:
+			start_node = self.root
+
+		# protect against empty tree where not even
+		# a root node exists
+		if not start_node.IsOk():
+			return True
+
+		self.SortChildren(start_node)
+
+		child_node, cookie = self.GetFirstChild(start_node)
+		while child_node.IsOk():
+			self.__sort_nodes(start_node = child_node)
+			child_node, cookie = self.GetNextChild(start_node, cookie)
+
+		return
+	#--------------------------------------------------------
 	def __handle_doc_context(self):
-
-		descriptions = self.__curr_node_data.get_descriptions()
-		desc_menu = wx.Menu()
-		for desc in descriptions:
-			d_id = wx.NewId()
-			# contract string
-			tmp = regex.split('\r\n+|\r+|\n+|\s+|\t+', desc)
-			tmp = ' '.join(tmp)
-			# but only use first 30 characters
-			tmp = "%s%s" % (tmp[:30], u'\u2026')
-			desc_menu.Append(d_id, tmp)
-			# connect handler
-			wx.EVT_MENU(desc_menu, d_id, self.__show_description)
-		ID = wx.NewId()
-		self.__doc_context_menu.AppendMenu(ID, _('descriptions ...'), desc_menu)
-
 		self.PopupMenu(self.__doc_context_menu, wx.DefaultPosition)
-
-		self.__doc_context_menu.Delete(ID)
-		try:
-			desc_menu.Destroy()
-		# the C++ object has been observed to have been destroyed already
-		except wx._core.PyDeadObjectError:
-			pass
 	#--------------------------------------------------------
 	def __handle_part_context(self):
 
@@ -1507,7 +1602,8 @@ class cDocTree(wx.TreeCtrl, gmRegetMixin.cRegetOnPaintMixin):
 		_log.debug("temporary directory [%s]", tmp_dir)
 
 		# determine database export chunk size
-		chunksize = int(cfg.get2 (
+		chunksize = int(
+		cfg.get2 (
 			option = "horstspace.blob_export_chunk_size",
 			workplace = gmSurgery.gmCurrentPractice().active_workplace,
 			bias = 'workplace',
@@ -1649,7 +1745,7 @@ class cDocTree(wx.TreeCtrl, gmRegetMixin.cRegetOnPaintMixin):
 	#--------------------------------------------------------
 	# document level context menu handlers
 	#--------------------------------------------------------
-	def __edit_consultation_details(self, evt):
+	def __edit_encounter_details(self, evt):
 		enc = gmEMRStructItems.cEncounter(aPK_obj=self.__curr_node_data['pk_encounter'])
 		dlg = gmEMRStructWidgets.cEncounterEditAreaDlg(parent=self, encounter=enc)
 		dlg.ShowModal()
@@ -1792,7 +1888,7 @@ class cDocTree(wx.TreeCtrl, gmRegetMixin.cRegetOnPaintMixin):
 		pat = gmPerson.gmCurrentPatient()
 		dname = '%s-%s%s' % (
 			self.__curr_node_data['l10n_type'],
-			self.__curr_node_data['date'].strftime('%Y-%m-%d'),
+			self.__curr_node_data['clin_when'].strftime('%Y-%m-%d'),
 			gmTools.coalesce(self.__curr_node_data['ext_ref'], '', '-%s').replace(' ', '_')
 		)
 		def_dir = os.path.expanduser(os.path.join('~', 'gnumed', 'export', 'docs', pat['dirname'], dname))
@@ -1857,19 +1953,36 @@ if __name__ == '__main__':
 
 #============================================================
 # $Log: gmMedDocWidgets.py,v $
-# Revision 1.166.2.4  2008/11/21 16:11:31  ncq
-# - apply the "comment" to the document or part when the review/details editor is
-#   invoked from a document or part, respectively
+# Revision 1.175  2009/02/04 21:47:17  ncq
+# - properly sort tree
 #
-# Revision 1.166.2.3  2008/11/20 21:57:48  ncq
-# - missing cfg =
-# - confirmation before deleting documents
+# Revision 1.174  2009/01/30 12:11:02  ncq
+# - comment
 #
-# Revision 1.166.2.2  2008/10/15 14:46:22  ncq
-# - PyDeadObjectError is in wx._core
+# Revision 1.173  2009/01/15 11:40:54  ncq
+# - implement managing document descriptions
 #
-# Revision 1.166.2.1  2008/09/09 17:34:09  ncq
-# - fix faulty column access in review
+# Revision 1.172  2009/01/11 19:19:19  ncq
+# - start supporting editing of document descriptions
+#
+# Revision 1.171  2008/12/09 23:33:14  ncq
+# - doc_med.date -> clin_when
+#
+# Revision 1.170  2008/11/23 12:46:03  ncq
+# - apply comment to doc or part, respectively, when
+#   reviewing/signing docs or parts
+# - add hook after new doc was created
+# - only inform user in statusline of new doc created if not new id shown anyway
+#
+# Revision 1.169  2008/11/21 13:06:36  ncq
+# - missing cfg in doc deletion
+#
+# Revision 1.168  2008/10/22 12:21:57  ncq
+# - use %x in strftime where appropriate
+#
+# Revision 1.167  2008/10/12 16:23:19  ncq
+# - consultation -> encounter
+# - adjust to changed review view
 #
 # Revision 1.166  2008/08/20 14:54:46  ncq
 # - carefully work around wxMenu.Remove() doing something other
