@@ -10,12 +10,12 @@ generator.
 """
 #============================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gmPatSearchWidgets.py,v $
-# $Id: gmPatSearchWidgets.py,v 1.110.2.2 2009/01/15 08:58:19 ncq Exp $
-__version__ = "$Revision: 1.110.2.2 $"
+# $Id: gmPatSearchWidgets.py,v 1.122 2009/02/05 14:30:36 ncq Exp $
+__version__ = "$Revision: 1.122 $"
 __author__ = "K.Hilbert <Karsten.Hilbert@gmx.net>"
 __license__ = 'GPL (for details see http://www.gnu.org/)'
 
-import sys, os.path, glob, datetime as pyDT, re as regex, logging
+import sys, os.path, glob, datetime as pyDT, re as regex, logging, webbrowser
 
 
 import wx
@@ -26,8 +26,8 @@ if __name__ == '__main__':
 	from Gnumed.pycommon import gmLog2
 from Gnumed.pycommon import gmDispatcher, gmPG2, gmI18N, gmCfg, gmTools, gmDateTime, gmMatchProvider, gmCfg2
 from Gnumed.business import gmPerson, gmKVK, gmSurgery
-from Gnumed.wxpython import gmGuiHelpers, gmDemographicsWidgets
-from Gnumed.wxGladeWidgets import wxgSelectPersonFromListDlg, wxgSelectPersonDTOFromListDlg
+from Gnumed.wxpython import gmGuiHelpers, gmDemographicsWidgets, gmAuthWidgets, gmRegetMixin, gmPhraseWheel, gmEditArea
+from Gnumed.wxGladeWidgets import wxgSelectPersonFromListDlg, wxgSelectPersonDTOFromListDlg, wxgMergePatientsDlg
 
 
 _log = logging.getLogger('gm.person')
@@ -38,6 +38,120 @@ _cfg = gmCfg2.gmCfgData()
 ID_PatPickList = wx.NewId()
 ID_BTN_AddNew = wx.NewId()
 
+#============================================================
+def merge_patients(parent=None):
+	dlg = cMergePatientsDlg(parent, -1)
+	result = dlg.ShowModal()
+#============================================================
+class cMergePatientsDlg(wxgMergePatientsDlg.wxgMergePatientsDlg):
+
+	def __init__(self, *args, **kwargs):
+		wxgMergePatientsDlg.wxgMergePatientsDlg.__init__(self, *args, **kwargs)
+
+		curr_pat = gmPerson.gmCurrentPatient()
+		if curr_pat.connected:
+			self._TCTRL_patient1.person = curr_pat
+			self._TCTRL_patient1._display_name()
+			self._RBTN_patient1.SetValue(True)
+	#--------------------------------------------------------
+	def _on_merge_button_pressed(self, event):
+
+		if self._TCTRL_patient1.person is None:
+			return
+
+		if self._TCTRL_patient2.person is None:
+			return
+
+		if self._RBTN_patient1.GetValue():
+			patient2keep = self._TCTRL_patient1.person
+			patient2merge = self._TCTRL_patient2.person
+		else:
+			patient2keep = self._TCTRL_patient2.person
+			patient2merge = self._TCTRL_patient1.person
+
+		if patient2merge['lastnames'] == u'Kirk':
+			if _cfg.get(option = 'debug'):
+				webbrowser.open (
+					url = 'http://en.wikipedia.org/wiki/File:Picard_as_Locutus.jpg',
+					new = False,
+					autoraise = True
+				)
+				gmGuiHelpers.gm_show_info(_('\n\nYou will be assimilated.\n\n'), _('The Borg'))
+				return
+			else:
+				gmDispatcher.send(signal = 'statustext', msg = _('Cannot merge Kirk into another patient.'), beep = True)
+				return
+
+		doit = gmGuiHelpers.gm_show_question (
+			aMessage = _(
+				'Are you positively sure you want to merge patient\n\n'
+				' #%s: %s (%s, %s)\n\n'
+				'into patient\n\n'
+				' #%s: %s (%s, %s) ?\n\n'
+				'Note that this action can ONLY be reversed by a laborious\n'
+				'manual process requiring in-depth knowledge about databases\n'
+				'and the patients in question !\n'
+			) % (
+				patient2merge.ID,
+				patient2merge['description_gender'],
+				patient2merge['gender'],
+				patient2merge['dob'].strftime('%x'),
+				patient2keep.ID,
+				patient2keep['description_gender'],
+				patient2keep['gender'],
+				patient2keep['dob'].strftime('%x')
+			),
+			aTitle = _('Merging patients: confirmation'),
+			cancel_button = False
+		)
+		if not doit:
+			return
+
+		conn = gmAuthWidgets.get_dbowner_connection(procedure = _('Merging patients'))
+		if conn is None:
+			return
+
+		success, msg = patient2keep.assimilate_identity(other_identity = patient2merge, link_obj = conn)
+		conn.close()
+		if not success:
+			gmDispatcher.send(signal = 'statustext', msg = msg, beep = True)
+			return
+
+		# announce success, offer to activate kept patient if not active
+		doit = gmGuiHelpers.gm_show_question (
+			aMessage = _(
+				'The patient\n'
+				'\n'
+				' #%s: %s (%s, %s)\n'
+				'\n'
+				'has successfully been merged into\n'
+				'\n'
+				' #%s: %s (%s, %s)\n'
+				'\n'
+				'\n'
+				'Do you want to activate that patient\n'
+				'now for further modifications ?\n'
+			) % (
+				patient2merge.ID,
+				patient2merge['description_gender'],
+				patient2merge['gender'],
+				patient2merge['dob'].strftime('%x'),
+				patient2keep.ID,
+				patient2keep['description_gender'],
+				patient2keep['gender'],
+				patient2keep['dob'].strftime('%x')
+			),
+			aTitle = _('Merging patients: success'),
+			cancel_button = False
+		)
+		if doit:
+			if not isinstance(patient2keep, gmPerson.gmCurrentPatient):
+				wx.CallAfter(gmPerson.set_active_patient, patient = patient2keep)
+
+		if self.IsModal():
+			self.EndModal(wx.ID_OK)
+		else:
+			self.Close()
 #============================================================
 class cSelectPersonFromListDlg(wxgSelectPersonFromListDlg.wxgSelectPersonFromListDlg):
 
@@ -293,6 +407,7 @@ def load_persons_from_pracsoft_au():
 		drive, filename = os.path.splitdrive(candidate)
 		pracsoft_files.append({'file': candidate, 'source': 'PracSoft (AU): drive %s' % drive})
 
+	# add configured one(s)
 	src_order = [
 		('explicit', 'append'),
 		('workbase', 'append'),
@@ -300,12 +415,12 @@ def load_persons_from_pracsoft_au():
 		('user', 'append'),
 		('system', 'append')
 	]
-	# add configured one
 	fnames = _cfg.get (
 		group = 'AU PracSoft PATIENTS.IN',
 		option = 'filename',
 		source_order = src_order
 	)
+
 	src_order = [
 		('explicit', 'return'),
 		('user', 'return'),
@@ -540,7 +655,7 @@ class cPersonSearchCtrl(wx.TextCtrl):
 
 #		- select all text in the field so that the next
 #		  character typed will delete it
-		
+
 #		- or set cursor to text position in case more left
 #		  clicks follow
 #		"""
@@ -550,7 +665,7 @@ class cPersonSearchCtrl(wx.TextCtrl):
 #			self._lclick_count = 1
 #			evt.Skip()
 #			return None
-			
+
 		# has been clicked before - should be highlighted
 #		start, end = self.GetSelection()
 #		self.SetSelection(start, end)
@@ -706,11 +821,14 @@ class cPersonSearchCtrl(wx.TextCtrl):
 					{'label': _('Create new'), 'tooltip': _('Create new patient.')}
 				]
 			)
-			if dlg.ShowModal() == wx.ID_YES:
+			if dlg.ShowModal() != wx.ID_NO:
 				return
 
 			wiz = gmDemographicsWidgets.cNewPatientWizard(parent = self.GetParent())
-			self.person = wiz.RunWizard(activate = False)
+			result = wiz.RunWizard(activate = False)
+			if result is False:
+				return None
+			self.person = result
 			self._display_name()
 			return None
 
@@ -795,7 +913,6 @@ class cActivePatientSelector(cPersonSearchCtrl):
 			name = curr_pat['description']
 			if curr_pat.locked:
 				name = _('%(name)s (locked)') % {'name': name}
-#			name = '%s%s' % (name, gmTools.coalesce(self._prev_search_term, u'', u' [%s]'))
 
 		self.SetValue(name)
 	#--------------------------------------------------------
@@ -819,7 +936,7 @@ class cActivePatientSelector(cPersonSearchCtrl):
 			enc = gmI18N.get_encoding()
 			gmDispatcher.send(signal = 'statustext', msg = _(
 				'%(pat)s turns %(age)s on %(month)s %(day)s ! (today is %(month_now)s %(day_now)s)') % {
-					'pat': pat.get_description(),
+					'pat': pat.get_description_gender(),
 					'age': pat.get_medical_age().strip('y'),
 					'month': pat['dob'].strftime('%B').decode(enc),
 					'day': pat['dob'].strftime('%d'),
@@ -835,9 +952,15 @@ class cActivePatientSelector(cPersonSearchCtrl):
 	def __register_events(self):
 		# client internal signals
 		gmDispatcher.connect(signal = u'post_patient_selection', receiver = self._on_post_patient_selection)
+		gmDispatcher.connect(signal = u'name_mod_db', receiver = self._on_name_identity_change)
+		gmDispatcher.connect(signal = u'identity_mod_db', receiver = self._on_name_identity_change)
+
 		gmDispatcher.connect(signal = 'patient_locked', receiver = self._on_post_patient_selection)
 		gmDispatcher.connect(signal = 'patient_unlocked', receiver = self._on_post_patient_selection)
 	#----------------------------------------------
+	def _on_name_identity_change(self, **kwargs):
+		wx.CallAfter(self._display_name)
+	#----------------------------------------------
 	def _on_post_patient_selection(self, **kwargs):
 		if gmPerson.gmCurrentPatient().connected:
 			self.person = gmPerson.gmCurrentPatient().patient
@@ -865,18 +988,301 @@ class cActivePatientSelector(cPersonSearchCtrl):
 		if success:
 			self._set_person_as_active_patient(self.person)
 #============================================================
+class cWaitingZonePhraseWheel(gmPhraseWheel.cPhraseWheel):
+
+	def __init__(self, *args, **kwargs):
+
+		gmPhraseWheel.cPhraseWheel.__init__(self, *args, **kwargs)
+
+		mp = gmMatchProvider.cMatchProvider_FixedList(aSeq = [])
+		mp.setThresholds(1, 2, 2)
+		self.matcher = mp
+		self.selection_only = False
+
+	#--------------------------------------------------------
+	def update_matcher(self, items):
+		self.matcher.set_items([ {'data': i, 'label': i, 'weight': 1} for i in items ])
+
+#============================================================
+from Gnumed.wxGladeWidgets import wxgWaitingListEntryEditAreaPnl
+
+class cWaitingListEntryEditAreaPnl(wxgWaitingListEntryEditAreaPnl.wxgWaitingListEntryEditAreaPnl, gmEditArea.cGenericEditAreaMixin):
+
+	def __init__ (self, *args, **kwargs):
+
+		try:
+			self.patient = kwargs['patient']
+			del kwargs['patient']
+		except KeyError:
+			self.patient = None
+
+		try:
+			data = kwargs['entry']
+			del kwargs['entry']
+		except KeyError:
+			data = None
+
+		wxgWaitingListEntryEditAreaPnl.wxgWaitingListEntryEditAreaPnl.__init__(self, *args, **kwargs)
+		gmEditArea.cGenericEditAreaMixin.__init__(self)
+
+		if data is None:
+			self.mode = 'new'
+		else:
+			self.data = data
+			self.mode = 'edit'
+
+		praxis = gmSurgery.gmCurrentPractice()
+		pats = praxis.waiting_list_patients
+		zones = {}
+		zones.update([ [p['waiting_zone'], None] for p in pats if p['waiting_zone'] is not None ])
+		self._PRW_zone.update_matcher(items = zones.keys())
+	#--------------------------------------------------------
+	# edit area mixin API
+	#--------------------------------------------------------
+	def _refresh_as_new(self):
+		if self.patient is None:
+			self._PRW_patient.person = None
+			self._PRW_patient.Enable(True)
+			self._PRW_patient.SetFocus()
+		else:
+			self._PRW_patient.person = self.patient
+			self._PRW_patient.Enable(False)
+			self._PRW_comment.SetFocus()
+		self._PRW_patient._display_name()
+
+		self._PRW_comment.SetValue(u'')
+		self._PRW_zone.SetValue(u'')
+		self._SPCTRL_urgency.SetValue(0)
+	#--------------------------------------------------------
+	def _refresh_from_existing(self):
+		self._PRW_patient.person = gmPerson.cIdentity(aPK_obj = self.data['pk_identity'])
+		self._PRW_patient.Enable(False)
+		self._PRW_patient._display_name()
+
+		self._PRW_comment.SetValue(gmTools.coalesce(self.data['comment'], u''))
+		self._PRW_zone.SetValue(gmTools.coalesce(self.data['waiting_zone'], u''))
+		self._SPCTRL_urgency.SetValue(self.data['urgency'])
+
+		self._PRW_comment.SetFocus()
+	#--------------------------------------------------------
+	def _valid_for_save(self):
+		validity = True
+
+		self.display_tctrl_as_valid(tctrl = self._PRW_patient, valid = (self._PRW_patient.person is not None))
+		validity = (self._PRW_patient.person is not None)
+
+		if validity is False:
+			gmDispatcher.send(signal = 'statustext', msg = _('Cannot add to waiting list. Missing essential input.'))
+
+		return validity
+	#----------------------------------------------------------------
+	def _save_as_new(self):
+		# FIXME: filter out dupes
+		self._PRW_patient.person.put_on_waiting_list (
+			urgency = self._SPCTRL_urgency.GetValue(),
+			comment = gmTools.none_if(self._PRW_comment.GetValue().strip(), u''),
+			zone = gmTools.none_if(self._PRW_zone.GetValue().strip(), u'')
+		)
+		# dummy:
+		self.data = {'pk_identity': None, 'comment': None, 'waiting_zone': None, 'urgency': 0}
+		return True
+	#----------------------------------------------------------------
+	def _save_as_update(self):
+		gmSurgery.gmCurrentPractice().update_in_waiting_list (
+			pk = self.data['pk_waiting_list'],
+			urgency = self._SPCTRL_urgency.GetValue(),
+			comment = self._PRW_comment.GetValue().strip(),
+			zone = self._PRW_zone.GetValue().strip()
+		)
+		return True
+#============================================================
+from Gnumed.wxGladeWidgets import wxgWaitingListPnl
+
+class cWaitingListPnl(wxgWaitingListPnl.wxgWaitingListPnl, gmRegetMixin.cRegetOnPaintMixin):
+
+	def __init__ (self, *args, **kwargs):
+
+		wxgWaitingListPnl.wxgWaitingListPnl.__init__(self, *args, **kwargs)
+		gmRegetMixin.cRegetOnPaintMixin.__init__(self)
+
+		self.__current_zone = None
+
+		self.__init_ui()
+		self.__register_events()
+	#--------------------------------------------------------
+	# interal helpers
+	#--------------------------------------------------------
+	def __init_ui(self):
+		self._LCTRL_patients.set_columns ([
+			_('Zone'),
+			' ! ',
+			_('Waiting time'),
+			_('Patient'),
+			_('Born'),
+			_('Comment')
+		])
+		self._LCTRL_patients.set_column_widths(widths = [wx.LIST_AUTOSIZE, wx.LIST_AUTOSIZE_USEHEADER, wx.LIST_AUTOSIZE, wx.LIST_AUTOSIZE, wx.LIST_AUTOSIZE])
+		self._PRW_zone.add_callback_on_selection(callback = self._on_zone_selected)
+		self._PRW_zone.add_callback_on_lose_focus(callback = self._on_zone_selected)
+	#--------------------------------------------------------
+	def __register_events(self):
+		gmDispatcher.connect(signal = u'waiting_list_generic_mod_db', receiver = self._on_waiting_list_modified)
+	#--------------------------------------------------------
+	def __refresh_waiting_list(self):
+
+		praxis = gmSurgery.gmCurrentPractice()
+		pats = praxis.waiting_list_patients
+
+		# set matcher to all zones currently in use
+		zones = {}
+		zones.update([ [p['waiting_zone'], None] for p in pats if p['waiting_zone'] is not None ])
+		self._PRW_zone.update_matcher(items = zones.keys())
+		del zones
+
+		# filter patient list by zone and set waiting list
+		self.__current_zone = self._PRW_zone.GetValue().strip()
+		if self.__current_zone == u'':
+			pats = [ p for p in pats ]
+		else:
+			pats = [ p for p in pats if p['waiting_zone'] == self.__current_zone ]
+
+		self._LCTRL_patients.set_string_items (
+			[ [
+				gmTools.coalesce(p['waiting_zone'], u''),
+				p['urgency'],
+				p['waiting_time_formatted'].replace(u'00 ', u'', 1).replace('00:', u'').lstrip('0'),
+				u'%s, %s (%s)' % (p['lastnames'], p['firstnames'], p['l10n_gender']),
+				p['dob'].strftime('%x'),
+				gmTools.coalesce(p['comment'], u'')
+			  ] for p in pats
+			]
+		)
+		self._LCTRL_patients.set_column_widths()
+		self._LCTRL_patients.set_data(pats)
+		self._LCTRL_patients.Refresh()
+		self._LCTRL_patients.SetToolTipString ( _(
+			'%s patients are waiting.\n'
+			'\n'
+			'Doubleclick to activate (entry will stay in list).'
+		) % len(pats))
+
+		self._LBL_no_of_patients.SetLabel(_('(%s patients)') % len(pats))
+
+		if len(pats) == 0:
+			self._BTN_activate.Enable(False)
+			self._BTN_activateplus.Enable(False)
+			self._BTN_remove.Enable(False)
+			self._BTN_edit.Enable(False)
+			self._BTN_up.Enable(False)
+			self._BTN_down.Enable(False)
+		else:
+			self._BTN_activate.Enable(True)
+			self._BTN_activateplus.Enable(True)
+			self._BTN_remove.Enable(True)
+			self._BTN_edit.Enable(True)
+		if len(pats) > 1:
+			self._BTN_up.Enable(True)
+			self._BTN_down.Enable(True)
+	#--------------------------------------------------------
+	# event handlers
+	#--------------------------------------------------------
+	def _on_zone_selected(self, zone=None):
+		if self.__current_zone == self._PRW_zone.GetValue().strip():
+			return True
+		wx.CallAfter(self.__refresh_waiting_list)
+		return True
+	#--------------------------------------------------------
+	def _on_waiting_list_modified(self, *args, **kwargs):
+		wx.CallAfter(self._schedule_data_reget)
+	#--------------------------------------------------------
+	def _on_list_item_activated(self, evt):
+		item = self._LCTRL_patients.get_selected_item_data(only_one=True)
+		if item is None:
+			return
+		pat = gmPerson.cIdentity(aPK_obj = item['pk_identity'])
+		wx.CallAfter(gmPerson.set_active_patient, patient = pat)
+	#--------------------------------------------------------
+	def _on_activate_button_pressed(self, evt):
+		item = self._LCTRL_patients.get_selected_item_data(only_one=True)
+		if item is None:
+			return
+		pat = gmPerson.cIdentity(aPK_obj = item['pk_identity'])
+		wx.CallAfter(gmPerson.set_active_patient, patient = pat)
+	#--------------------------------------------------------
+	def _on_activateplus_button_pressed(self, evt):
+		item = self._LCTRL_patients.get_selected_item_data(only_one=True)
+		if item is None:
+			return
+		pat = gmPerson.cIdentity(aPK_obj = item['pk_identity'])
+		gmSurgery.gmCurrentPractice().remove_from_waiting_list(pk = item['pk_waiting_list'])
+		wx.CallAfter(gmPerson.set_active_patient, patient = pat)
+	#--------------------------------------------------------
+	def _on_add_patient_button_pressed(self, evt):
+
+		pat = None
+		if self._PRW_search_patient.person is not None:
+			pat = self._PRW_search_patient.person
+		else:
+			curr_pat = gmPerson.gmCurrentPatient()
+			if curr_pat.connected:
+				pat = curr_pat
+
+		ea = cWaitingListEntryEditAreaPnl(self, -1, patient = pat)
+		dlg = gmEditArea.cGenericEditAreaDlgSingle(self, -1, edit_area = ea)
+		dlg.ShowModal()
+
+		self._PRW_search_patient.person = None
+		self._PRW_search_patient._display_name()
+	#--------------------------------------------------------
+	def _on_edit_button_pressed(self, event):
+		item = self._LCTRL_patients.get_selected_item_data(only_one=True)
+		if item is None:
+			return
+		ea = cWaitingListEntryEditAreaPnl(self, -1, entry = item)
+		dlg = gmEditArea.cGenericEditAreaDlgSingle(self, -1, edit_area = ea)
+		dlg.ShowModal()
+	#--------------------------------------------------------
+	def _on_remove_button_pressed(self, evt):
+		item = self._LCTRL_patients.get_selected_item_data(only_one=True)
+		if item is None:
+			return
+		gmSurgery.gmCurrentPractice().remove_from_waiting_list(pk = item['pk_waiting_list'])
+	#--------------------------------------------------------
+	def _on_up_button_pressed(self, evt):
+		item = self._LCTRL_patients.get_selected_item_data(only_one=True)
+		if item is None:
+			return
+		gmSurgery.gmCurrentPractice().raise_in_waiting_list(current_position = item['list_position'])
+	#--------------------------------------------------------
+	def _on_down_button_pressed(self, evt):
+		item = self._LCTRL_patients.get_selected_item_data(only_one=True)
+		if item is None:
+			return
+		gmSurgery.gmCurrentPractice().lower_in_waiting_list(current_position = item['list_position'])
+	#--------------------------------------------------------
+	# edit
+	#--------------------------------------------------------
+	# reget-on-paint API
+	#--------------------------------------------------------
+	def _populate_with_data(self):
+		self.__refresh_waiting_list()
+		return True
+#============================================================
 # main
 #------------------------------------------------------------
 if __name__ == "__main__":
 
-	gmI18N.activate_locale()
-	gmI18N.install_domain()
+	if len(sys.argv) > 1:
+		if sys.argv[1] == 'test':
+			gmI18N.activate_locale()
+			gmI18N.install_domain()
 
-	app = wx.PyWidgetTester(size = (200, 40))
-#	app.SetWidget(cSelectPersonFromListDlg, -1)
-#	app.SetWidget(cPersonSearchCtrl, -1)
-	app.SetWidget(cActivePatientSelector, -1)
-	app.MainLoop()
+			app = wx.PyWidgetTester(size = (200, 40))
+#			app.SetWidget(cSelectPersonFromListDlg, -1)
+#			app.SetWidget(cPersonSearchCtrl, -1)
+#			app.SetWidget(cActivePatientSelector, -1)
+			app.SetWidget(cWaitingListPnl, -1)
+			app.MainLoop()
 
 #============================================================
 # docs
@@ -984,11 +1390,45 @@ if __name__ == "__main__":
 
 #============================================================
 # $Log: gmPatSearchWidgets.py,v $
-# Revision 1.110.2.2  2009/01/15 08:58:19  ncq
-# - do not hard code an initial patient plugin
+# Revision 1.122  2009/02/05 14:30:36  ncq
+# - only run new-patient-wizard if user explicitely said so
+# - do not try to set active patient if user cancelled new patient wizard
 #
-# Revision 1.110.2.1  2008/09/09 17:35:11  ncq
-# - don't crash on incomplete PracSoft profiles
+# Revision 1.121  2009/02/04 12:35:18  ncq
+# - support editing waiting list entries
+#
+# Revision 1.120  2009/01/30 12:11:43  ncq
+# - waiting list entry edit area
+#
+# Revision 1.119  2009/01/22 11:16:41  ncq
+# - implement moving waiting list entries
+#
+# Revision 1.118  2009/01/21 22:39:02  ncq
+# - waiting zones phrasewheel and use it
+#
+# Revision 1.117  2009/01/21 18:04:41  ncq
+# - implement most of waiting list
+#
+# Revision 1.116  2009/01/17 23:08:31  ncq
+# - waiting list
+#
+# Revision 1.115  2008/12/17 21:59:22  ncq
+# - add support for merging patients
+#
+# Revision 1.114  2008/12/09 23:43:27  ncq
+# - use description_gender
+# - no more hardcoded plugin raising after patient activation
+#
+# Revision 1.113  2008/10/12 16:26:46  ncq
+# - cleanup
+#
+# Revision 1.112  2008/09/01 20:28:51  ncq
+# - properly handle case when several option sources define AU PracSoft source
+#
+# Revision 1.111  2008/08/28 18:34:18  ncq
+# - make active patient selector react to patient activation,
+#   name/identity change all by itself with updating its display,
+#   don't let top panel do it for us
 #
 # Revision 1.110  2008/07/28 20:27:20  ncq
 # - do not try to activate None person
