@@ -8,8 +8,8 @@ This is based on seminal work by Ian Haywood <ihaywood@gnu.org>
 """
 ############################################################################
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gmPhraseWheel.py,v $
-# $Id: gmPhraseWheel.py,v 1.124.2.1 2008/09/09 17:36:24 ncq Exp $
-__version__ = "$Revision: 1.124.2.1 $"
+# $Id: gmPhraseWheel.py,v 1.128 2009/03/01 18:18:50 ncq Exp $
+__version__ = "$Revision: 1.128 $"
 __author__  = "K.Hilbert <Karsten.Hilbert@gmx.net>, I.Haywood, S.J.Tan <sjtan@bigpond.com>"
 __license__ = "GPL"
 
@@ -35,7 +35,10 @@ _log = logging.getLogger('macosx')
 
 color_prw_invalid = 'pink'
 color_prw_valid = None				# this is used by code outside this module
-#============================================================
+
+default_phrase_separators = '[;/|]+'
+default_spelling_word_separators = '[\W\d_]+'
+
 # those can be used by the <accepted_chars> phrasewheel parameter
 NUMERIC = '0-9'
 ALPHANUMERIC = 'a-zA-Z0-9'
@@ -191,10 +194,10 @@ class cPhraseWheel(wx.TextCtrl):
 		self.accepted_chars = None
 		self.final_regex = '.*'
 		self.final_regex_error_msg = _('The content is invalid. It must match the pattern: [%s]')
-		self.phrase_separators = '[;/|]+'
+		self.phrase_separators = default_phrase_separators
 		self.navigate_after_selection = False
 		self.speller = None
-		self.speller_word_separators = '[\W\d_]+'
+		self.speller_word_separators = default_spelling_word_separators
 		self.picklist_delay = 150		# milliseconds
 
 		# state tracking
@@ -439,7 +442,7 @@ class cPhraseWheel(wx.TextCtrl):
 		border_width = 4
 		extra_height = 25
 
-		self._hide_picklist()
+		self.__picklist_dropdown.Hide()
 
 		# this helps if the current input was already selected from the
 		# list but still is the substring of another pick list item
@@ -561,7 +564,13 @@ class cPhraseWheel(wx.TextCtrl):
 				# filter out the last word
 				word = regex.split(self.__speller_word_separators, self.input2match)[-1]
 				if word.strip() != u'':
-					if not self.speller.check(word):
+					success = False
+					try:
+						success = self.speller.check(word)
+					except:
+						_log.exception('had to disable enchant spell checker')
+						self.speller = None
+					if success:
 						spells = self.speller.suggest(word)
 						truncated_input2match = self.input2match[:self.input2match.rindex(word)]
 						for spell in spells:
@@ -845,7 +854,6 @@ class cPhraseWheel(wx.TextCtrl):
 			callback()
 
 		self.__timer.Start(oneShot = True, milliseconds = self.picklist_delay)
-
 		return True
 	#--------------------------------------------------------
 	def _on_lose_focus(self, event):
@@ -1026,9 +1034,17 @@ if __name__ == '__main__':
 
 #==================================================
 # $Log: gmPhraseWheel.py,v $
-# Revision 1.124.2.1  2008/09/09 17:36:24  ncq
-# - don't try to access the selected list item if there's no
-#   list - it seems IsShown() isn't really true all the time
+# Revision 1.128  2009/03/01 18:18:50  ncq
+# - factor out default phrase separators/spelling word separators
+#
+# Revision 1.127  2009/02/24 10:16:48  ncq
+# - don't hiccup when spell checker hiccups, simply disable it
+#
+# Revision 1.126  2009/02/04 21:47:54  ncq
+# - cleanup
+#
+# Revision 1.125  2008/10/12 16:32:40  ncq
+# - make more robust when getting data of selected item
 #
 # Revision 1.124  2008/08/15 15:57:37  ncq
 # - enchant doesn't like spellchecking '' anymore
