@@ -2,8 +2,8 @@
 """
 #============================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gmSOAPWidgets.py,v $
-# $Id: gmSOAPWidgets.py,v 1.105 2008/08/08 13:32:59 ncq Exp $
-__version__ = "$Revision: 1.105 $"
+# $Id: gmSOAPWidgets.py,v 1.109 2009/02/10 18:40:07 ncq Exp $
+__version__ = "$Revision: 1.109 $"
 __author__ = "Carlos Moro <cfmoro1976@yahoo.es>, K.Hilbert <Karsten.Hilbert@gmx.net>"
 __license__ = "GPL"
 
@@ -163,6 +163,7 @@ class cProgressNoteInputNotebook(wx.Notebook, gmRegetMixin.cRegetOnPaintMixin):
 			)
 			return result
 
+		# check for dupes
 		# new unassociated problem
 		if problem_to_add is None:
 			# check for dupes
@@ -192,7 +193,11 @@ class cProgressNoteInputNotebook(wx.Notebook, gmRegetMixin.cRegetOnPaintMixin):
 				continue
 			# editor is for episode
 			if problem_of_page['type'] == 'episode':
-				if problem_of_page['pk_episode'] == problem_to_add['pk_episode']:
+				if problem_to_add['type'] == 'issue':
+					is_equal = (problem_of_page['pk_health_issue'] == problem_to_add['pk_health_issue'])
+				else:
+					is_equal = (problem_of_page['pk_episode'] == problem_to_add['pk_episode'])
+				if is_equal:
 					self.SetSelection(page_idx)
 					return True
 				continue
@@ -421,7 +426,12 @@ class cNotebookedProgressNoteInputPanel(wx.Panel):
 		self.__soap_notebook = cProgressNoteInputNotebook(PNL_soap_editors, -1)
 		# - buttons
 		self.__BTN_add_unassociated = wx.Button(PNL_soap_editors, -1, _('&New'))
-		self.__BTN_add_unassociated.SetToolTipString(_('Add editor for a new unassociated progress note.'))
+		tt = _(
+			'Add editor for a new unassociated progress note.\n\n'
+			'There is a configuration option whether or not to\n'
+			'allow several new unassociated progress notes at once.'
+		)
+		self.__BTN_add_unassociated.SetToolTipString(tt)
 
 		self.__BTN_save = wx.Button(PNL_soap_editors, -1, _('&Save'))
 		self.__BTN_save.SetToolTipString(_('Save progress note into medical record and close this editor.'))
@@ -463,7 +473,7 @@ class cNotebookedProgressNoteInputPanel(wx.Panel):
 				continue
 			if problem['type'] == 'issue':
 				issue = emr.problem2issue(problem)
-				last_encounter = emr.get_last_encounter(issue_id = issue['pk'])
+				last_encounter = emr.get_last_encounter(issue_id = issue['pk_health_issue'])
 				if last_encounter is None:
 					last = issue['modified_when'].strftime('%m/%Y')
 				else:
@@ -536,7 +546,7 @@ class cNotebookedProgressNoteInputPanel(wx.Panel):
 		- if patient has no episodes:
 			- new patient
 			- always allow several NEWs
-		- of patient has episodes:
+		- if patient has episodes:
 			- allow several NEWs per configuration
 		"""
 		emr = self.__pat.get_emr()
@@ -1215,6 +1225,18 @@ if __name__ == "__main__":
 
 #============================================================
 # $Log: gmSOAPWidgets.py,v $
+# Revision 1.109  2009/02/10 18:40:07  ncq
+# - allow one editor per issue regardless of opening order
+#
+# Revision 1.108  2008/12/12 16:36:36  ncq
+# - better tooltip
+#
+# Revision 1.107  2008/11/20 20:17:50  ncq
+# - better docs
+#
+# Revision 1.106  2008/09/02 19:01:12  ncq
+# - adjust to clin health_issue fk_patient drop and related changes
+#
 # Revision 1.105  2008/08/08 13:32:59  ncq
 # - factor out save_unsaved_soap()
 # - register and act on pre-exit callback
