@@ -4,12 +4,12 @@ FIXME: store screen size
 """
 #============================================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gmSnellen.py,v $
-# $Id: gmSnellen.py,v 1.1.2.2 2008/06/25 10:18:08 ncq Exp $
-__version__ = "$Revision: 1.1.2.2 $"
+# $Id: gmSnellen.py,v 1.4 2008/06/26 17:01:57 ncq Exp $
+__version__ = "$Revision: 1.4 $"
 __author__ = "Ian Haywood, Karsten Hilbert <Karsten.Hilbert@gmx.net>"
 __license__ = "GPL (details at http://www.gnu.org)"
 
-import math, random, sys
+import math, random, sys, logging
 
 
 import wx
@@ -18,7 +18,7 @@ import wx
 if __name__ == '__main__':
 	sys.path.insert(0, '../../')
 	_ = lambda x:x
-from Gnumed.pycommon import gmLog, gmI18N
+from Gnumed.pycommon import gmI18N
 #from Gnumed.wxpython import gmPlugin
 
 ID_SNELLENMENU = wx.NewId()
@@ -263,7 +263,7 @@ class cSnellenChart(wx.Frame):
 		if self.screen_width_pixel == 0:
 			self.screen_width_pixel, self.screen_height_pixel = self.GetClientSizeTuple()
 			self.set_distance(2)
-#			gmLog.gmDefLog.Log (gmLog.lInfo, 'I think the screen size is %d x %d' % (self.screen_width_pixel, self.screen_height_pixel))
+#			_log.info('I think the screen size is %d x %d' % (self.screen_width_pixel, self.screen_height_pixel))
 
 #		self.setup_DC()
 		self.dc.SetFont(wx.Font (36, wx.ROMAN, wx.NORMAL, wx.NORMAL))
@@ -507,10 +507,10 @@ double-click ends""")), 0, wx.ALL, 15)
 #		self.parent = parent
 
 	def OnClose (self, event):
-		self.EndModal(wx.ID_CANCEL)
+		self.EndModal (wx.ID_CANCEL)
 
 	def OnCancel (self, event):
-		self.EndModal(wx.ID_CANCEL)
+		self.EndModal (wx.ID_CANCEL)
 
 	def OnOK (self, event):
 #		if self.Validate() and self.TransferDataFromWindow():
@@ -524,7 +524,9 @@ double-click ends""")), 0, wx.ALL, 15)
 		mirr = self.mirror_ctrl.GetValue()
 		self.vals = (width, height, alpha, mirr)
 		self.EndModal(wx.ID_OK)
-	
+
+#		self.EndModal(1)
+
 #============================================================================
 # FIXME needn't be a plugin, rewrite to not be one
 #class gmSnellen (gmPlugin.wx.BasePlugin):
@@ -578,12 +580,14 @@ if __name__ == '__main__':
 	main()
 #============================================================================
 # $Log: gmSnellen.py,v $
-# Revision 1.1.2.2  2008/06/25 10:18:08  ncq
-# - return wx.ID_* from Snellen cfg dialog and test for
-#   that from main GUI
+# Revision 1.4  2008/06/26 17:01:57  ncq
+# - be extra careful about returning distinct results from cfg
 #
-# Revision 1.1.2.1  2007/12/30 21:51:44  ncq
-# - fix MacOSX crash - clicking OK in Snellen cfg dlg
+# Revision 1.3  2008/03/05 22:30:15  ncq
+# - new style logging
+#
+# Revision 1.2  2008/01/05 22:31:20  ncq
+# - MacOSX don't seem to have default True on Validate() and TransferDataFromWindow()
 #
 # Revision 1.1  2007/10/19 09:37:56  ncq
 # - moved here
