@@ -2,8 +2,8 @@
 
 #===========================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gmTopPanel.py,v $
-# $Id: gmTopPanel.py,v 1.97 2008/08/05 16:22:44 ncq Exp $
-__version__ = "$Revision: 1.97 $"
+# $Id: gmTopPanel.py,v 1.101 2008/12/09 23:43:50 ncq Exp $
+__version__ = "$Revision: 1.101 $"
 __author__  = "R.Terry <rterry@gnumed.net>, I.Haywood <i.haywood@ugrad.unimelb.edu.au>, K.Hilbert <Karsten.Hilbert@gmx.net>"
 __license__ = "GPL"
 
@@ -44,9 +44,7 @@ class cMainTopPanel(wx.Panel):
 
 		self.__gb = gmGuiBroker.GuiBroker()
 
-#		self.__load_consultation_types()
 		self.__do_layout()
-#		del self.__consultation_types
 		self.__register_interests()
 
 		# init plugin toolbars dict
@@ -173,19 +171,6 @@ class cMainTopPanel(wx.Panel):
 #		)
 #		self.btn_preg.SetToolTip(wxToolTip(_("Pregnancy Calculator")))
 #		self.szr_bottom_row.Add(self.btn_preg, 0)
-		
-		# consultation type selector
-#		self.combo_consultation_type = wx.ComboBox (
-#			self,
-#			ID_CBOX_consult_type,
-#			self.DEF_CONSULT_TYPE,
-#			wx.DefaultPosition,
-#			wx.DefaultSize,
-#			self.__consultation_types,
-#			wx.CB_DROPDOWN | wx.CB_READONLY
-#		)
-#		self.combo_consultation_type.SetToolTip(wx.ToolTip(_('choose consultation type')))
-#		self.szr_bottom_row.Add(self.combo_consultation_type, 1)
 
 		# - stack them atop each other
 		self.szr_stacked_rows = wx.BoxSizer(wx.VERTICAL)
@@ -195,7 +180,7 @@ class cMainTopPanel(wx.Panel):
 			self.szr_stacked_rows.Add(1, 1, 0)
 		except:
 			self.szr_stacked_rows.Add((1, 1), 0)
-		
+
 		# 0 here indicates the sizer cannot change its heights - which is intended
 		self.szr_stacked_rows.Add(self.szr_top_row, 0, wx.EXPAND)
 		self.szr_stacked_rows.Add(self.szr_bottom_row, 1, wx.EXPAND|wx.TOP, 5)
@@ -219,10 +204,6 @@ class cMainTopPanel(wx.Panel):
 	#-------------------------------------------------------
 	# internal helpers
 	#-------------------------------------------------------
-#	def __load_consultation_types(self):
-#		self.__consultation_types = gmEMRStructItems.get_encounter_types()
-#		self.DEF_CONSULT_TYPE = self.__consultation_types[0]
-#		return 1
 	#-------------------------------------------------------
 	# event handling
 	#-------------------------------------------------------
@@ -287,8 +268,6 @@ class cMainTopPanel(wx.Panel):
 		wx.CallAfter(self.__on_name_identity_change)
 	#----------------------------------------------
 	def __on_name_identity_change(self):
-		self.patient_selector.SetValue(self.curr_pat['description'])
-
 		if self.curr_pat['dob'].strftime('%m-%d') == pyDT.datetime.now(tz = gmDateTime.gmCurrentLocalTimezone).strftime('%m-%d'):
 			template = _('%s  %s (%s today !)')
 		else:
@@ -308,8 +287,6 @@ class cMainTopPanel(wx.Panel):
 		wx.CallAfter(self.__on_post_patient_selection, **kwargs)
 	#----------------------------------------------
 	def __on_post_patient_selection(self, **kwargs):
-		self.patient_selector.SetValue(self.curr_pat['description'])
-
 		# FIXME: if the age is below, say, 2 hours we should fire
 		# a timer here that updates the age in increments of 1 minute ... :-)
 		if self.curr_pat['dob'].strftime('%m-%d') == pyDT.datetime.now(tz = gmDateTime.gmCurrentLocalTimezone).strftime('%m-%d'):
@@ -334,35 +311,50 @@ class cMainTopPanel(wx.Panel):
 		wx.CallAfter(self.__update_allergies)
 	#-------------------------------------------------------
 	def __update_allergies(self, **kwargs):
+
 		emr = self.curr_pat.get_emr()
-		allergies = emr.get_allergies()
+		state = emr.allergy_state
 
-		if len(allergies) == 0:
-			self.txt_allergies.SetValue('')
-			self.txt_allergies.SetToolTipString(gmAllergy.allergic_state2str(state = emr.allergic_state))
-			return True
+		# state in tooltip
+		if state['last_confirmed'] is None:
+			confirmed = _('never')
+		else:
+			confirmed = state['last_confirmed'].strftime('%x')
+		tt = (state.state_string + (90 * u' '))[:90] + u'\n'
+		tt += _('last confirmed %s\n') % confirmed
+		tt += gmTools.coalesce(state['comment'], u'', _('Comment (%s): %%s') % state['modified_by'])
+		tt += u'\n'
 
+		# allergies
 		tmp = []
-		tt = u'%-70s\n' % u' '
-		for allergy in allergies:
+		for allergy in emr.get_allergies():
+			# in field: "true" allergies only, not intolerances
 			if allergy['type'] == 'allergy':
-				tmp.append(allergy['descriptor'][:10])
+				tmp.append(allergy['descriptor'][:10] + gmTools.u_ellipsis)
+			# in tooltip
 			if allergy['definite']:
 				certainty = _('definite')
 			else:
-				certainty = _('likely')
+				certainty = _('suspected')
 			reaction = gmTools.coalesce(allergy['reaction'], _('reaction not recorded'))
 			if len(reaction) > 50:
 				reaction = reaction[:50] + gmTools.u_ellipsis
-			tt += u'%s - %s (%s): %s\n' % (
+			tt += u'%s (%s, %s): %s\n' % (
 				allergy['descriptor'],
 				allergy['l10n_type'],
 				certainty,
 				reaction
 			)
 
-		data = ','.join(tmp)
-		self.txt_allergies.SetValue(data)
+		if len(tmp) == 0:
+			tmp = state.state_symbol
+		else:
+			tmp = ','.join(tmp)
+
+		if state['last_confirmed'] is not None:
+			tmp += state['last_confirmed'].strftime(' (%x)')
+
+		self.txt_allergies.SetValue(tmp)
 		self.txt_allergies.SetToolTipString(tt)
 	#-------------------------------------------------------
 	# remote layout handling
@@ -455,6 +447,21 @@ if __name__ == "__main__":
 	app.MainLoop()
 #===========================================================
 # $Log: gmTopPanel.py,v $
+# Revision 1.101  2008/12/09 23:43:50  ncq
+# - cleanup
+#
+# Revision 1.100  2008/10/22 12:22:26  ncq
+# - improved allergies tooltip and display
+#
+# Revision 1.99  2008/10/12 16:36:45  ncq
+# - cleanup
+# - consultation -> encounter
+# - improved allergies handling
+#
+# Revision 1.98  2008/08/28 18:34:47  ncq
+# - pat search widget now takes care of updating
+#   its display itself when necessary
+#
 # Revision 1.97  2008/08/05 16:22:44  ncq
 # - improve dob display and allergies tooltip
 #
