@@ -13,6 +13,8 @@ care of all the pre- and post-GUI runtime environment setup.
 --slave
  Pre-set the [enable remote control] checkbox in the login
  dialog to enable the XML-RPC remote control feature.
+--hipaa
+ Enable HIPAA functionality which has user impact.
 --profile=<file>
  Activate profiling and write profile data to <file>.
 --text-domain=<text domain>
@@ -36,13 +38,15 @@ care of all the pre- and post-GUI runtime environment setup.
  and the client software version cannot be verified to be compatible.
 --local-import
  Adjust the PYTHONPATH such that GNUmed can be run from a local source tree.
+--version, -V
+ Show version information.
 --help, -h, or -?
  Show this help.
 """
 #==========================================================
 # $Source: /sources/gnumed/gnumed/gnumed/client/wxpython/gnumed.py,v $
-# $Id: gnumed.py,v 1.142.2.1 2008/08/31 14:25:41 ncq Exp $
-__version__ = "$Revision: 1.142.2.1 $"
+# $Id: gnumed.py,v 1.151.2.8 2009/08/04 14:48:21 ncq Exp $
+__version__ = "$Revision: 1.151.2.8 $"
 __author__  = "H. Herb <hherb@gnumed.net>, K. Hilbert <Karsten.Hilbert@gmx.net>, I. Haywood <i.haywood@ugrad.unimelb.edu.au>"
 __license__ = "GPL (details at http://www.gnu.org)"
 
@@ -71,10 +75,14 @@ against. Please run GNUmed as a non-root user.
 	sys.exit(1)
 
 #----------------------------------------------------------
+current_client_version = u'0.4.7'
+current_client_branch = u'0.4'
+
+
 _log = None
 _cfg = None
 _old_sig_term = None
-_known_short_options = u'h?'
+_known_short_options = u'h?V'
 _known_long_options = [
 	u'debug',
 	u'slave',
@@ -85,7 +93,9 @@ _known_long_options = [
 	u'lang-gettext=',
 	u'override-schema-check',
 	u'local-import',
-	u'help'
+	u'help',
+	u'version',
+	u'hipaa'
 ]
 
 import_error_sermon = """
@@ -112,7 +122,7 @@ requirements please ask on the mailing list.
 """
 
 
-missing_config_file = """
+missing_cli_config_file = u"""
 GNUmed startup: Missing configuration file.
 -------------------------------------------
 
@@ -123,6 +133,19 @@ on the command line:
 
 The file does not exist, however.
 """
+
+
+no_config_files = u"""
+GNUmed startup: Missing configuration files.
+--------------------------------------------
+
+None of the below candidate configuration
+files could be found:
+
+ %s
+
+Cannot run GNUmed without any of them.
+"""
 #==========================================================
 # convenience functions
 #==========================================================
@@ -139,14 +162,14 @@ def setup_python_path():
 	)
 
 	# does the path exist at all, physically ?
-	# note that broken links are reported as True
-	if not os.path.lexists(os.path.join(local_python_base_dir, 'Gnumed')):
-		src = os.path.join(local_python_base_dir, 'client')
-		dst = os.path.join(local_python_base_dir, 'Gnumed')
+	# (*broken* links are reported as False)
+	lnk = os.path.join(local_python_base_dir, 'Gnumed')
+	if not os.path.exists(lnk):
+		orig = os.path.join(local_python_base_dir, 'client')
 		print "Creating module import symlink ..."
-		print '', dst, '=>'
-		print '    =>', src
-		os.symlink(src, dst)
+		print ' original:', orig
+		print '     link:', lnk
+		os.symlink(orig, lnk)
 
 	print "Adjusting PYTHONPATH ..."
 	sys.path.insert(0, local_python_base_dir)
@@ -193,6 +216,25 @@ def setup_cli():
 		option = u'slave',
 		value = val
 	)
+
+	val = _cfg.get(option = '--hipaa', source_order = [('cli', 'return')])
+	if val is None:
+		val = False
+	_cfg.set_option (
+		option = u'hipaa',
+		value = val
+	)
+
+	_cfg.set_option (
+		option = u'client_version',
+		value = current_client_version
+	)
+
+	_cfg.set_option (
+		option = u'client_branch',
+		value = current_client_branch
+	)
+
 #==========================================================
 def handle_sig_term(signum, frame):
 	_log.critical('SIGTERM (SIG%s) received, shutting down ...' % signum)
@@ -212,9 +254,6 @@ def setup_signal_handlers():
 	global _old_sig_term
 	old_sig_term = signal.signal(signal.SIGTERM, handle_sig_term)
 #==========================================================
-#def setup_legacy_logging():
-#	gmLog.gmDefLog.SetAllLogLevels(gmLog.lData)
-#==========================================================
 def setup_locale():
 	gmI18N.activate_locale()
 	td = _cfg.get(option = '--text-domain', source_order = [('cli', 'return')])
@@ -225,7 +264,7 @@ def setup_locale():
 	# in case it changed
 	gmLog2.set_string_encoding()
 #==========================================================
-def check_help_request():
+def handle_help_request():
 	src = [(u'cli', u'return')]
 
 	help_requested = (
@@ -242,6 +281,26 @@ def check_help_request():
 		print __doc__
 		sys.exit(0)
 #==========================================================
+def handle_version_request():
+	src = [(u'cli', u'return')]
+
+	version_requested = (
+		_cfg.get(option = u'--version', source_order = src) or
+		_cfg.get(option = u'-V', source_order = src)
+	)
+
+	if version_requested:
+
+		from Gnumed.pycommon.gmPG2 import map_client_branch2required_db_version, known_schema_hashes
+
+		print 'GNUmed version information'
+		print '--------------------------'
+		print 'client     : %s on branch [%s]' % (current_client_version, current_client_branch)
+		print 'database   : %s' % map_client_branch2required_db_version[current_client_branch]
+		print 'schema hash: %s' % known_schema_hashes[map_client_branch2required_db_version[current_client_branch]]
+		sys.exit(0)
+
+#==========================================================
 def setup_paths_and_files():
 	"""Create needed paths in user home directory."""
 
@@ -262,54 +321,54 @@ def setup_date_time():
 	gmDateTime.init()
 #==========================================================
 def setup_cfg():
+	"""Detect and setup access to GNUmed config file.
+
+	Parts of this will have limited value due to
+	wxPython not yet being available.
+	"""
 
 	enc = gmI18N.get_encoding()
 	paths = gmTools.gmPaths(app_name = u'gnumed')
 
-	# the current working dir
-	_cfg.add_file_source (
-		source = u'workbase',
-		file = os.path.join(paths.working_dir, 'gnumed.conf'),
-		encoding = enc
-	)
-	# /etc/gnumed/
-	_cfg.add_file_source (
-		source = u'system',
-		file = os.path.join(paths.system_config_dir, 'gnumed-client.conf'),
-		encoding = enc
-	)
-	# ~/.gnumed/
-	_cfg.add_file_source (
-		source = u'user',
-		file = os.path.join(paths.user_config_dir, 'gnumed.conf'),
-		encoding = enc
-	)
-	# CVS/tgz tree .../gnumed/client/ (IOW a local installation)
-	_cfg.add_file_source (
-		source = u'local',
-		file = os.path.join(paths.local_base_dir, 'gnumed.conf'),
-		encoding = enc
-	)
+	candidates = [
+		# the current working dir
+		[u'workbase', os.path.join(paths.working_dir, 'gnumed.conf')],
+		# /etc/gnumed/
+		[u'system', os.path.join(paths.system_config_dir, 'gnumed-client.conf')],
+		# ~/.gnumed/
+		[u'user', os.path.join(paths.user_config_dir, 'gnumed.conf')],
+		# CVS/tgz tree .../gnumed/client/ (IOW a local installation)
+		[u'local', os.path.join(paths.local_base_dir, 'gnumed.conf')]
+	]
 	# --conf-file=
-	fname = _cfg.get(option = u'--conf-file', source_order = [(u'cli', u'return')])
-	if fname is None:
-		_cfg.add_file_source(source = u'explicit')
+	explicit_fname = _cfg.get(option = u'--conf-file', source_order = [(u'cli', u'return')])
+	if explicit_fname is None:
+		candidates.append([u'explicit', None])
 	else:
+		candidates.append([u'explicit', explicit_fname])
+
+	for candidate in candidates:
 		_cfg.add_file_source (
-			source = u'explicit',
-			file = fname,
+			source = candidate[0],
+			file = candidate[1],
 			encoding = enc
 		)
+
+	# --conf-file given but does not actually exist ?
+	if explicit_fname is not None:
 		if _cfg.source_files['explicit'] is None:
+			_log.error('--conf-file argument does not exist')
 			sys.exit(missing_config_file % fname)
 
+	# any config file found at all ?
 	found_any_file = False
 	for f in _cfg.source_files.values():
 		if f is not None:
 			found_any_file = True
 			break
 	if not found_any_file:
-		sys.exit('Cannot find any configuration files.')
+		_log.error('no config file found at all')
+		sys.exit(no_config_files % '\n '.join(candidates))
 
 	# mime type handling sources
 	fname = u'mime_type2file_extension.conf'
@@ -325,6 +384,8 @@ def setup_cfg():
 	)
 #==========================================================
 def setup_backend():
+	_log.info('client expects database version [%s]', gmPG2.map_client_branch2required_db_version[current_client_branch])
+
 	# set up database connection timezone
 	timezone = _cfg.get (
 		group = u'backend',
@@ -379,6 +440,8 @@ setup_logging()
 
 _log.info('Starting up as main module (%s).', __version__)
 _log.info('Python %s on %s (%s)', sys.version, sys.platform, os.name)
+_log.info('GNUmed client version [%s] on branch [%s]', current_client_version, current_client_branch)
+# FIXME: log output of lsb_release
 
 setup_console_exception_handler()
 setup_cli()
@@ -386,9 +449,9 @@ setup_signal_handlers()
 
 from Gnumed.pycommon import gmI18N, gmTools, gmDateTime, gmHooks
 
-#setup_legacy_logging()
 setup_locale()
-check_help_request()
+handle_help_request()
+handle_version_request()
 setup_paths_and_files()
 setup_date_time()
 setup_cfg()
@@ -418,8 +481,59 @@ shutdown_logging()
 
 #==========================================================
 # $Log: gnumed.py,v $
-# Revision 1.142.2.1  2008/08/31 14:25:41  ncq
-# - explicitely detect and fail when no config file whatsoever is found
+# Revision 1.151.2.8  2009/08/04 14:48:21  ncq
+# - bump version
+#
+# Revision 1.151.2.7  2009/06/11 14:49:22  ncq
+# - bump up version
+#
+# Revision 1.151.2.6  2009/05/18 10:23:40  ncq
+# - bump version
+#
+# Revision 1.151.2.5  2009/05/01 16:04:17  ncq
+# - bump version
+#
+# Revision 1.151.2.4  2009/04/20 12:10:20  ncq
+# - bump version
+#
+# Revision 1.151.2.3  2009/03/28 20:36:07  ncq
+# - bump version
+#
+# Revision 1.151.2.2  2009/03/24 10:41:34  ncq
+# - bump version
+#
+# Revision 1.151.2.1  2009/03/04 14:12:03  ncq
+# - bump version
+#
+# Revision 1.151  2009/03/04 13:50:00  ncq
+# - bump version
+#
+# Revision 1.150  2009/03/02 11:24:12  ncq
+# - bump version
+#
+# Revision 1.149  2009/02/27 12:40:44  ncq
+# - bump version
+#
+# Revision 1.148  2009/02/24 10:38:41  ncq
+# - improve python path manipulation
+#
+# Revision 1.147  2009/02/17 12:01:43  ncq
+# - bump version
+#
+# Revision 1.146  2008/12/17 21:59:46  ncq
+# - support --hipaa
+#
+# Revision 1.145  2008/11/23 12:47:27  ncq
+# - comment on lsb_release
+#
+# Revision 1.144  2008/10/22 12:23:13  ncq
+# - initiate version handling
+# - add -V/--version
+#
+# Revision 1.143  2008/08/31 14:52:58  ncq
+# - improved error messages
+# - streamline setup_cfg and properly handle no --conf-file
+# - detect and signal "no conf file at all"
 #
 # Revision 1.142  2008/08/05 12:47:14  ncq
 # - support --local-import
