@@ -3,14 +3,17 @@
 # ------------------------------------------------
 #
 # this plugin displays the list of patient problems
-# toghether whith a notebook container for progress notes
+# together whith a notebook container for progress notes
 #
 # @copyright: author
 #======================================================================
-__version__ = "$Revision: 1.12 $"
+__version__ = "$Revision: 1.16 $"
 __author__ = "Carlos Moro, Karsten Hilbert"
 __license__ = 'GPL (details at http://www.gnu.org)'
 
+import logging
+
+
 if __name__ == '__main__':
 	# stdlib
 	import sys
@@ -22,14 +25,14 @@ if __name__ == '__main__':
 
 # GNUmed
 from Gnumed.wxpython import gmPlugin, gmSOAPWidgets
-from Gnumed.pycommon import gmLog
 
-_log = gmLog.gmDefLog
-_log.Log(gmLog.lInfo, __version__)
+
+_log = logging.getLogger('gm.ui')
+_log.info(__version__)
 
 #======================================================================
 class gmNotebookedProgressNoteInputPlugin(gmPlugin.cNotebookPlugin):
-	"""Plugin to encapsulate multisash based progress note input window."""
+	"""Plugin to encapsulate notebook based progress note input window."""
 
 	tab_name = _('Progress notes')
 
@@ -41,7 +44,7 @@ class gmNotebookedProgressNoteInputPlugin(gmPlugin.cNotebookPlugin):
 		return self._widget
 
 	def MenuInfo (self):
-		return ('emr', _('Add progress notes'))
+		return ('emr', _('&Progress notes editor'))
 
 	def can_receive_focus(self):
 		# need patient
@@ -57,16 +60,9 @@ if __name__ == "__main__":
 	import wx
 
 	# GNUmed
-	from Gnumed.pycommon import gmCfg
 	from Gnumed.business import gmPerson
 
-	_cfg = gmCfg.gmDefCfgFile	
-		
-	_log.Log (gmLog.lInfo, "starting Notebooked progress notes input plugin...")
-
-	if _cfg is None:
-		_log.Log(gmLog.lErr, "Cannot run without config file.")
-		sys.exit("Cannot run without config file.")
+	_log.info("starting Notebooked progress notes input plugin...")
 
 	try:
 		# obtain patient
@@ -90,13 +86,25 @@ if __name__ == "__main__":
 			except:
 				print "error cleaning up patient"
 	except StandardError:
-		_log.LogException("unhandled exception caught !", sys.exc_info(), 1)
+		_log.exception("unhandled exception caught !")
 		# but re-raise them
 		raise
 
-	_log.Log (gmLog.lInfo, "closing Notebooked progress notes input plugin...")
+	_log.info("closing Notebooked progress notes input plugin...")
 #======================================================================
 # $Log: gmNotebookedProgressNoteInputPlugin.py,v $
+# Revision 1.16  2008/07/10 08:45:14  ncq
+# - fix spelling
+#
+# Revision 1.15  2008/06/24 14:01:02  ncq
+# - improved menu item label
+#
+# Revision 1.14  2008/03/06 18:32:31  ncq
+# - standard lib logging only
+#
+# Revision 1.13  2008/01/27 21:21:59  ncq
+# - no more gmCfg
+#
 # Revision 1.12  2006/12/18 12:12:27  ncq
 # - fix test suite
 #
